mst_town_default = 0
mst_conversation_encounter = 1
mst_town_center = 2
mst_village_center = 3
mst_bandits_at_night = 4
mst_village_training = 5
mst_visit_town_castle = 6
mst_back_alley_kill_local_merchant = 7
mst_back_alley_revolt = 8
mst_lead_charge = 9
mst_village_attack_bandits = 10
mst_village_raid = 11
mst_besiege_inner_battle_castle = 12
mst_besiege_inner_battle_town_center = 13
mst_castle_attack_walls_defenders_sally = 14
mst_castle_attack_walls_belfry = 15
mst_castle_attack_walls_ladder = 16
mst_castle_visit = 17
mst_training_ground_trainer_talk = 18
mst_training_ground_trainer_training = 19
mst_training_ground_training = 20
mst_sneak_caught_fight = 21
mst_ai_training = 22
mst_camera_test = 23
mst_arena_melee_fight = 24
mst_arena_challenge_fight = 25
mst_duel_with_lord = 26
mst_wedding = 27
mst_tutorial_training_ground = 28
mst_tutorial_1 = 29
mst_tutorial_2 = 30
mst_tutorial_3 = 31
mst_tutorial_3_2 = 32
mst_tutorial_4 = 33
mst_tutorial_5 = 34
mst_quick_battle_battle = 35
mst_quick_battle_siege = 36
mst_multiplayer_dm = 37
mst_multiplayer_tdm = 38
mst_multiplayer_hq = 39
mst_multiplayer_cf = 40
mst_multiplayer_sg = 41
mst_multiplayer_bt = 42
mst_multiplayer_fd = 43
mst_bandit_lair = 44
mst_alley_fight = 45
mst_meeting_merchant = 46
mst_town_fight = 47
mst_multiplayer_duel = 48
