imod_plain = 0
imod_cracked = 1
imod_rusty = 2
imod_bent = 3
imod_chipped = 4
imod_battered = 5
imod_poor = 6
imod_crude = 7
imod_old = 8
imod_cheap = 9
imod_fine = 10
imod_well_made = 11
imod_sharp = 12
imod_balanced = 13
imod_tempered = 14
imod_deadly = 15
imod_exquisite = 16
imod_masterwork = 17
imod_heavy = 18
imod_strong = 19
imod_powerful = 20
imod_tattered = 21
imod_ragged = 22
imod_rough = 23
imod_sturdy = 24
imod_thick = 25
imod_hardened = 26
imod_reinforced = 27
imod_superb = 28
imod_lordly = 29
imod_lame = 30
imod_swaybacked = 31
imod_stubborn = 32
imod_timid = 33
imod_meek = 34
imod_spirited = 35
imod_champion = 36
imod_fresh = 37
imod_day_old = 38
imod_two_day_old = 39
imod_smelling = 40
imod_rotten = 41
imod_large_bag = 42


imodbit_plain = 1
imodbit_cracked = 2
imodbit_rusty = 4
imodbit_bent = 8
imodbit_chipped = 16
imodbit_battered = 32
imodbit_poor = 64
imodbit_crude = 128
imodbit_old = 256
imodbit_cheap = 512
imodbit_fine = 1024
imodbit_well_made = 2048
imodbit_sharp = 4096
imodbit_balanced = 8192
imodbit_tempered = 16384
imodbit_deadly = 32768
imodbit_exquisite = 65536
imodbit_masterwork = 131072
imodbit_heavy = 262144
imodbit_strong = 524288
imodbit_powerful = 1048576
imodbit_tattered = 2097152
imodbit_ragged = 4194304
imodbit_rough = 8388608
imodbit_sturdy = 16777216
imodbit_thick = 33554432
imodbit_hardened = 67108864
imodbit_reinforced = 134217728
imodbit_superb = 268435456
imodbit_lordly = 536870912
imodbit_lame = 1073741824
imodbit_swaybacked = 2147483648
imodbit_stubborn = 4294967296
imodbit_timid = 8589934592
imodbit_meek = 17179869184
imodbit_spirited = 34359738368
imodbit_champion = 68719476736
imodbit_fresh = 137438953472
imodbit_day_old = 274877906944
imodbit_two_day_old = 549755813888
imodbit_smelling = 1099511627776
imodbit_rotten = 2199023255552
imodbit_large_bag = 4398046511104
