prsnt_game_credits = 0
prsnt_game_profile_banner_selection = 1
prsnt_game_custom_battle_designer = 2
prsnt_game_multiplayer_admin_panel = 3
prsnt_multiplayer_welcome_message = 4
prsnt_multiplayer_team_select = 5
prsnt_multiplayer_troop_select = 6
prsnt_multiplayer_item_select = 7
prsnt_multiplayer_message_1 = 8
prsnt_multiplayer_message_2 = 9
prsnt_multiplayer_message_3 = 10
prsnt_multiplayer_round_time_counter = 11
prsnt_multiplayer_team_score_display = 12
prsnt_multiplayer_flag_projection_display = 13
prsnt_multiplayer_flag_projection_display_bt = 14
prsnt_multiplayer_destructible_targets_display = 15
prsnt_multiplayer_respawn_time_counter = 16
prsnt_multiplayer_stats_chart = 17
prsnt_multiplayer_stats_chart_deathmatch = 18
prsnt_multiplayer_escape_menu = 19
prsnt_multiplayer_poll_menu = 20
prsnt_multiplayer_show_players_list = 21
prsnt_multiplayer_show_maps_list = 22
prsnt_multiplayer_show_factions_list = 23
prsnt_multiplayer_show_number_of_bots_list = 24
prsnt_multiplayer_poll = 25
prsnt_tutorial_show_mouse_movement = 26
prsnt_name_kingdom = 27
prsnt_banner_selection = 28
prsnt_custom_banner = 29
prsnt_banner_charge_positioning = 30
prsnt_banner_charge_selection = 31
prsnt_banner_background_selection = 32
prsnt_banner_flag_type_selection = 33
prsnt_banner_flag_map_type_selection = 34
prsnt_color_selection = 35
prsnt_marshall_selection = 36
prsnt_battle = 37
prsnt_sliders = 38
prsnt_arena_training = 39
prsnt_retirement = 40
prsnt_budget_report = 41
prsnt_game_before_quit = 42
prsnt_multiplayer_duel_start_counter = 43
