trp_player = 0
trp_multiplayer_profile_troop_male = 1
trp_multiplayer_profile_troop_female = 2
trp_temp_troop = 3
trp_find_item_cheat = 4
trp_random_town_sequence = 5
trp_tournament_participants = 6
trp_tutorial_maceman = 7
trp_tutorial_archer = 8
trp_tutorial_swordsman = 9
trp_novice_fighter = 10
trp_regular_fighter = 11
trp_veteran_fighter = 12
trp_champion_fighter = 13
trp_arena_training_fighter_1 = 14
trp_arena_training_fighter_2 = 15
trp_arena_training_fighter_3 = 16
trp_arena_training_fighter_4 = 17
trp_arena_training_fighter_5 = 18
trp_arena_training_fighter_6 = 19
trp_arena_training_fighter_7 = 20
trp_arena_training_fighter_8 = 21
trp_arena_training_fighter_9 = 22
trp_arena_training_fighter_10 = 23
trp_cattle = 24
trp_farmer = 25
trp_townsman = 26
trp_watchman = 27
trp_caravan_guard = 28
trp_mercenary_swordsman = 29
trp_hired_blade = 30
trp_mercenary_crossbowman = 31
trp_mercenary_horseman = 32
trp_mercenary_cavalry = 33
trp_mercenaries_end = 34
trp_swadian_recruit = 35
trp_swadian_militia = 36
trp_swadian_footman = 37
trp_swadian_infantry = 38
trp_swadian_sergeant = 39
trp_swadian_skirmisher = 40
trp_swadian_crossbowman = 41
trp_swadian_sharpshooter = 42
trp_swadian_man_at_arms = 43
trp_swadian_knight = 44
trp_swadian_messenger = 45
trp_swadian_deserter = 46
trp_swadian_prison_guard = 47
trp_swadian_castle_guard = 48
trp_vaegir_recruit = 49
trp_vaegir_footman = 50
trp_vaegir_skirmisher = 51
trp_vaegir_archer = 52
trp_vaegir_marksman = 53
trp_vaegir_veteran = 54
trp_vaegir_infantry = 55
trp_vaegir_guard = 56
trp_vaegir_horseman = 57
trp_vaegir_knight = 58
trp_vaegir_messenger = 59
trp_vaegir_deserter = 60
trp_vaegir_prison_guard = 61
trp_vaegir_castle_guard = 62
trp_khergit_tribesman = 63
trp_khergit_skirmisher = 64
trp_khergit_horseman = 65
trp_khergit_horse_archer = 66
trp_khergit_veteran_horse_archer = 67
trp_khergit_lancer = 68
trp_khergit_messenger = 69
trp_khergit_deserter = 70
trp_khergit_prison_guard = 71
trp_khergit_castle_guard = 72
trp_nord_recruit = 73
trp_nord_footman = 74
trp_nord_trained_footman = 75
trp_nord_warrior = 76
trp_nord_veteran = 77
trp_nord_champion = 78
trp_nord_huntsman = 79
trp_nord_archer = 80
trp_nord_veteran_archer = 81
trp_nord_messenger = 82
trp_nord_deserter = 83
trp_nord_prison_guard = 84
trp_nord_castle_guard = 85
trp_rhodok_tribesman = 86
trp_rhodok_spearman = 87
trp_rhodok_trained_spearman = 88
trp_rhodok_veteran_spearman = 89
trp_rhodok_sergeant = 90
trp_rhodok_crossbowman = 91
trp_rhodok_trained_crossbowman = 92
trp_rhodok_veteran_crossbowman = 93
trp_rhodok_sharpshooter = 94
trp_rhodok_messenger = 95
trp_rhodok_deserter = 96
trp_rhodok_prison_guard = 97
trp_rhodok_castle_guard = 98
trp_sarranid_recruit = 99
trp_sarranid_footman = 100
trp_sarranid_veteran_footman = 101
trp_sarranid_infantry = 102
trp_sarranid_guard = 103
trp_sarranid_skirmisher = 104
trp_sarranid_archer = 105
trp_sarranid_master_archer = 106
trp_sarranid_horseman = 107
trp_sarranid_mamluke = 108
trp_sarranid_messenger = 109
trp_sarranid_deserter = 110
trp_sarranid_prison_guard = 111
trp_sarranid_castle_guard = 112
trp_looter = 113
trp_bandit = 114
trp_brigand = 115
trp_mountain_bandit = 116
trp_forest_bandit = 117
trp_sea_raider = 118
trp_steppe_bandit = 119
trp_taiga_bandit = 120
trp_desert_bandit = 121
trp_black_khergit_horseman = 122
trp_manhunter = 123
trp_slave_driver = 124
trp_slave_hunter = 125
trp_slave_crusher = 126
trp_slaver_chief = 127
trp_follower_woman = 128
trp_hunter_woman = 129
trp_fighter_woman = 130
trp_sword_sister = 131
trp_refugee = 132
trp_peasant_woman = 133
trp_caravan_master = 134
trp_kidnapped_girl = 135
trp_town_walker_1 = 136
trp_town_walker_2 = 137
trp_khergit_townsman = 138
trp_khergit_townswoman = 139
trp_sarranid_townsman = 140
trp_sarranid_townswoman = 141
trp_village_walker_1 = 142
trp_village_walker_2 = 143
trp_spy_walker_1 = 144
trp_spy_walker_2 = 145
trp_tournament_master = 146
trp_trainer = 147
trp_constable_hareck = 148
trp_ramun_the_slave_trader = 149
trp_guide = 150
trp_xerina = 151
trp_dranton = 152
trp_kradus = 153
trp_tutorial_trainer = 154
trp_tutorial_student_1 = 155
trp_tutorial_student_2 = 156
trp_tutorial_student_3 = 157
trp_tutorial_student_4 = 158
trp_galeas = 159
trp_farmer_from_bandit_village = 160
trp_trainer_1 = 161
trp_trainer_2 = 162
trp_trainer_3 = 163
trp_trainer_4 = 164
trp_trainer_5 = 165
trp_ransom_broker_1 = 166
trp_ransom_broker_2 = 167
trp_ransom_broker_3 = 168
trp_ransom_broker_4 = 169
trp_ransom_broker_5 = 170
trp_ransom_broker_6 = 171
trp_ransom_broker_7 = 172
trp_ransom_broker_8 = 173
trp_ransom_broker_9 = 174
trp_ransom_broker_10 = 175
trp_tavern_traveler_1 = 176
trp_tavern_traveler_2 = 177
trp_tavern_traveler_3 = 178
trp_tavern_traveler_4 = 179
trp_tavern_traveler_5 = 180
trp_tavern_traveler_6 = 181
trp_tavern_traveler_7 = 182
trp_tavern_traveler_8 = 183
trp_tavern_traveler_9 = 184
trp_tavern_traveler_10 = 185
trp_tavern_bookseller_1 = 186
trp_tavern_bookseller_2 = 187
trp_tavern_minstrel_1 = 188
trp_tavern_minstrel_2 = 189
trp_tavern_minstrel_3 = 190
trp_tavern_minstrel_4 = 191
trp_tavern_minstrel_5 = 192
trp_kingdom_heroes_including_player_begin = 193
trp_npc1 = 194
trp_npc2 = 195
trp_npc3 = 196
trp_npc4 = 197
trp_npc5 = 198
trp_npc6 = 199
trp_npc7 = 200
trp_npc8 = 201
trp_npc9 = 202
trp_npc10 = 203
trp_npc11 = 204
trp_npc12 = 205
trp_npc13 = 206
trp_npc14 = 207
trp_npc15 = 208
trp_npc16 = 209
trp_kingdom_1_lord = 210
trp_kingdom_2_lord = 211
trp_kingdom_3_lord = 212
trp_kingdom_4_lord = 213
trp_kingdom_5_lord = 214
trp_kingdom_6_lord = 215
trp_knight_1_1 = 216
trp_knight_1_2 = 217
trp_knight_1_3 = 218
trp_knight_1_4 = 219
trp_knight_1_5 = 220
trp_knight_1_6 = 221
trp_knight_1_7 = 222
trp_knight_1_8 = 223
trp_knight_1_9 = 224
trp_knight_1_10 = 225
trp_knight_1_11 = 226
trp_knight_1_12 = 227
trp_knight_1_13 = 228
trp_knight_1_14 = 229
trp_knight_1_15 = 230
trp_knight_1_16 = 231
trp_knight_1_17 = 232
trp_knight_1_18 = 233
trp_knight_1_19 = 234
trp_knight_1_20 = 235
trp_knight_2_1 = 236
trp_knight_2_2 = 237
trp_knight_2_3 = 238
trp_knight_2_4 = 239
trp_knight_2_5 = 240
trp_knight_2_6 = 241
trp_knight_2_7 = 242
trp_knight_2_8 = 243
trp_knight_2_9 = 244
trp_knight_2_10 = 245
trp_knight_2_11 = 246
trp_knight_2_12 = 247
trp_knight_2_13 = 248
trp_knight_2_14 = 249
trp_knight_2_15 = 250
trp_knight_2_16 = 251
trp_knight_2_17 = 252
trp_knight_2_18 = 253
trp_knight_2_19 = 254
trp_knight_2_20 = 255
trp_knight_3_1 = 256
trp_knight_3_2 = 257
trp_knight_3_3 = 258
trp_knight_3_4 = 259
trp_knight_3_5 = 260
trp_knight_3_6 = 261
trp_knight_3_7 = 262
trp_knight_3_8 = 263
trp_knight_3_9 = 264
trp_knight_3_10 = 265
trp_knight_3_11 = 266
trp_knight_3_12 = 267
trp_knight_3_13 = 268
trp_knight_3_14 = 269
trp_knight_3_15 = 270
trp_knight_3_16 = 271
trp_knight_3_17 = 272
trp_knight_3_18 = 273
trp_knight_3_19 = 274
trp_knight_3_20 = 275
trp_knight_4_1 = 276
trp_knight_4_2 = 277
trp_knight_4_3 = 278
trp_knight_4_4 = 279
trp_knight_4_5 = 280
trp_knight_4_6 = 281
trp_knight_4_7 = 282
trp_knight_4_8 = 283
trp_knight_4_9 = 284
trp_knight_4_10 = 285
trp_knight_4_11 = 286
trp_knight_4_12 = 287
trp_knight_4_13 = 288
trp_knight_4_14 = 289
trp_knight_4_15 = 290
trp_knight_4_16 = 291
trp_knight_4_17 = 292
trp_knight_4_18 = 293
trp_knight_4_19 = 294
trp_knight_4_20 = 295
trp_knight_5_1 = 296
trp_knight_5_2 = 297
trp_knight_5_3 = 298
trp_knight_5_4 = 299
trp_knight_5_5 = 300
trp_knight_5_6 = 301
trp_knight_5_7 = 302
trp_knight_5_8 = 303
trp_knight_5_9 = 304
trp_knight_5_10 = 305
trp_knight_5_11 = 306
trp_knight_5_12 = 307
trp_knight_5_13 = 308
trp_knight_5_14 = 309
trp_knight_5_15 = 310
trp_knight_5_16 = 311
trp_knight_5_17 = 312
trp_knight_5_18 = 313
trp_knight_5_19 = 314
trp_knight_5_20 = 315
trp_knight_6_1 = 316
trp_knight_6_2 = 317
trp_knight_6_3 = 318
trp_knight_6_4 = 319
trp_knight_6_5 = 320
trp_knight_6_6 = 321
trp_knight_6_7 = 322
trp_knight_6_8 = 323
trp_knight_6_9 = 324
trp_knight_6_10 = 325
trp_knight_6_11 = 326
trp_knight_6_12 = 327
trp_knight_6_13 = 328
trp_knight_6_14 = 329
trp_knight_6_15 = 330
trp_knight_6_16 = 331
trp_knight_6_17 = 332
trp_knight_6_18 = 333
trp_knight_6_19 = 334
trp_knight_6_20 = 335
trp_kingdom_1_pretender = 336
trp_kingdom_2_pretender = 337
trp_kingdom_3_pretender = 338
trp_kingdom_4_pretender = 339
trp_kingdom_5_pretender = 340
trp_kingdom_6_pretender = 341
trp_knight_1_1_wife = 342
trp_kingdom_1_lady_1 = 343
trp_kingdom_1_lady_2 = 344
trp_knight_1_lady_3 = 345
trp_knight_1_lady_4 = 346
trp_kingdom_l_lady_5 = 347
trp_kingdom_1_lady_6 = 348
trp_kingdom_1_lady_7 = 349
trp_kingdom_1_lady_8 = 350
trp_kingdom_1_lady_9 = 351
trp_kingdom_1_lady_10 = 352
trp_kingdom_1_lady_11 = 353
trp_kingdom_1_lady_12 = 354
trp_kingdom_l_lady_13 = 355
trp_kingdom_1_lady_14 = 356
trp_kingdom_1_lady_15 = 357
trp_kingdom_1_lady_16 = 358
trp_kingdom_1_lady_17 = 359
trp_kingdom_1_lady_18 = 360
trp_kingdom_1_lady_19 = 361
trp_kingdom_1_lady_20 = 362
trp_kingdom_2_lady_1 = 363
trp_kingdom_2_lady_2 = 364
trp_kingdom_2_lady_3 = 365
trp_kingdom_2_lady_4 = 366
trp_kingdom_2_lady_5 = 367
trp_kingdom_2_lady_6 = 368
trp_kingdom_2_lady_7 = 369
trp_kingdom_2_lady_8 = 370
trp_kingdom_2_lady_9 = 371
trp_kingdom_2_lady_10 = 372
trp_kingdom_2_lady_11 = 373
trp_kingdom_2_lady_12 = 374
trp_kingdom_2_lady_13 = 375
trp_kingdom_2_lady_14 = 376
trp_kingdom_2_lady_15 = 377
trp_kingdom_2_lady_16 = 378
trp_kingdom_2_lady_17 = 379
trp_kingdom_2_lady_18 = 380
trp_kingdom_2_lady_19 = 381
trp_kingdom_2_lady_20 = 382
trp_kingdom_3_lady_1 = 383
trp_kingdom_3_lady_2 = 384
trp_kingdom_3_lady_3 = 385
trp_kingdom_3_lady_4 = 386
trp_kingdom_3_lady_5 = 387
trp_kingdom_3_lady_6 = 388
trp_kingdom_3_lady_7 = 389
trp_kingdom_3_lady_8 = 390
trp_kingdom_3_lady_9 = 391
trp_kingdom_3_lady_10 = 392
trp_kingdom_3_lady_11 = 393
trp_kingdom_3_lady_12 = 394
trp_kingdom_3_lady_13 = 395
trp_kingdom_3_lady_14 = 396
trp_kingdom_3_lady_15 = 397
trp_kingdom_3_lady_16 = 398
trp_kingdom_3_lady_17 = 399
trp_kingdom_3_lady_18 = 400
trp_kingdom_3_lady_19 = 401
trp_kingdom_3_lady_20 = 402
trp_kingdom_4_lady_1 = 403
trp_kingdom_4_lady_2 = 404
trp_kingdom_4_lady_3 = 405
trp_kingdom_4_lady_4 = 406
trp_kingdom_4_lady_5 = 407
trp_kingdom_4_lady_6 = 408
trp_kingdom_4_lady_7 = 409
trp_knight_4_2b_daughter_1 = 410
trp_kingdom_4_lady_9 = 411
trp_knight_4_2c_wife_1 = 412
trp_kingdom_4_lady_11 = 413
trp_knight_4_2c_daughter = 414
trp_knight_4_1b_wife = 415
trp_kingdom_4_lady_14 = 416
trp_knight_4_1b_daughter = 417
trp_knight_4_2b_daughter_2 = 418
trp_kingdom_4_lady_17 = 419
trp_knight_4_2c_wife_2 = 420
trp_knight_4_1c_daughter = 421
trp_kingdom_4_lady_20 = 422
trp_kingdom_5_lady_1 = 423
trp_kingdom_5_lady_2 = 424
trp_kingdom_5_lady_3 = 425
trp_kingdom_5_lady_4 = 426
trp_kingdom_5_5_wife = 427
trp_kingdom_5_2b_wife_1 = 428
trp_kingdom_5_1c_daughter_1 = 429
trp_kingdom_5_2c_daughter_1 = 430
trp_kingdom_5_1c_wife_1 = 431
trp_kingdom_5_2c_wife_1 = 432
trp_kingdom_5_1c_daughter_2 = 433
trp_kingdom_5_2c_daughter_2 = 434
trp_kingdom_5_1b_wife = 435
trp_kingdom_5_2b_wife_2 = 436
trp_kingdom_5_1c_daughter_3 = 437
trp_kingdom_5_lady_16 = 438
trp_kingdom_5_1c_wife_2 = 439
trp_kingdom_5_2c_wife_2 = 440
trp_kingdom_5_1c_daughter_4 = 441
trp_kingdom_5_lady_20 = 442
trp_kingdom_6_lady_1 = 443
trp_kingdom_6_lady_2 = 444
trp_kingdom_6_lady_3 = 445
trp_kingdom_6_lady_4 = 446
trp_kingdom_6_lady_5 = 447
trp_kingdom_6_lady_6 = 448
trp_kingdom_6_lady_7 = 449
trp_kingdom_6_lady_8 = 450
trp_kingdom_6_lady_9 = 451
trp_kingdom_6_lady_10 = 452
trp_kingdom_6_lady_11 = 453
trp_kingdom_6_lady_12 = 454
trp_kingdom_6_lady_13 = 455
trp_kingdom_6_lady_14 = 456
trp_kingdom_6_lady_15 = 457
trp_kingdom_6_lady_16 = 458
trp_kingdom_6_lady_17 = 459
trp_kingdom_6_lady_18 = 460
trp_kingdom_6_lady_19 = 461
trp_kingdom_6_lady_20 = 462
trp_heroes_end = 463
trp_town_1_seneschal = 464
trp_town_2_seneschal = 465
trp_town_3_seneschal = 466
trp_town_4_seneschal = 467
trp_town_5_seneschal = 468
trp_town_6_seneschal = 469
trp_town_7_seneschal = 470
trp_town_8_seneschal = 471
trp_town_9_seneschal = 472
trp_town_10_seneschal = 473
trp_town_11_seneschal = 474
trp_town_12_seneschal = 475
trp_town_13_seneschal = 476
trp_town_14_seneschal = 477
trp_town_15_seneschal = 478
trp_town_16_seneschal = 479
trp_town_17_seneschal = 480
trp_town_18_seneschal = 481
trp_town_19_seneschal = 482
trp_town_20_seneschal = 483
trp_town_21_seneschal = 484
trp_town_22_seneschal = 485
trp_castle_1_seneschal = 486
trp_castle_2_seneschal = 487
trp_castle_3_seneschal = 488
trp_castle_4_seneschal = 489
trp_castle_5_seneschal = 490
trp_castle_6_seneschal = 491
trp_castle_7_seneschal = 492
trp_castle_8_seneschal = 493
trp_castle_9_seneschal = 494
trp_castle_10_seneschal = 495
trp_castle_11_seneschal = 496
trp_castle_12_seneschal = 497
trp_castle_13_seneschal = 498
trp_castle_14_seneschal = 499
trp_castle_15_seneschal = 500
trp_castle_16_seneschal = 501
trp_castle_17_seneschal = 502
trp_castle_18_seneschal = 503
trp_castle_19_seneschal = 504
trp_castle_20_seneschal = 505
trp_castle_21_seneschal = 506
trp_castle_22_seneschal = 507
trp_castle_23_seneschal = 508
trp_castle_24_seneschal = 509
trp_castle_25_seneschal = 510
trp_castle_26_seneschal = 511
trp_castle_27_seneschal = 512
trp_castle_28_seneschal = 513
trp_castle_29_seneschal = 514
trp_castle_30_seneschal = 515
trp_castle_31_seneschal = 516
trp_castle_32_seneschal = 517
trp_castle_33_seneschal = 518
trp_castle_34_seneschal = 519
trp_castle_35_seneschal = 520
trp_castle_36_seneschal = 521
trp_castle_37_seneschal = 522
trp_castle_38_seneschal = 523
trp_castle_39_seneschal = 524
trp_castle_40_seneschal = 525
trp_castle_41_seneschal = 526
trp_castle_42_seneschal = 527
trp_castle_43_seneschal = 528
trp_castle_44_seneschal = 529
trp_castle_45_seneschal = 530
trp_castle_46_seneschal = 531
trp_castle_47_seneschal = 532
trp_castle_48_seneschal = 533
trp_town_1_arena_master = 534
trp_town_2_arena_master = 535
trp_town_3_arena_master = 536
trp_town_4_arena_master = 537
trp_town_5_arena_master = 538
trp_town_6_arena_master = 539
trp_town_7_arena_master = 540
trp_town_8_arena_master = 541
trp_town_9_arena_master = 542
trp_town_10_arena_master = 543
trp_town_11_arena_master = 544
trp_town_12_arena_master = 545
trp_town_13_arena_master = 546
trp_town_14_arena_master = 547
trp_town_15_arena_master = 548
trp_town_16_arena_master = 549
trp_town_17_arena_master = 550
trp_town_18_arena_master = 551
trp_town_19_arena_master = 552
trp_town_20_arena_master = 553
trp_town_21_arena_master = 554
trp_town_22_arena_master = 555
trp_town_1_armorer = 556
trp_town_2_armorer = 557
trp_town_3_armorer = 558
trp_town_4_armorer = 559
trp_town_5_armorer = 560
trp_town_6_armorer = 561
trp_town_7_armorer = 562
trp_town_8_armorer = 563
trp_town_9_armorer = 564
trp_town_10_armorer = 565
trp_town_11_armorer = 566
trp_town_12_armorer = 567
trp_town_13_armorer = 568
trp_town_14_armorer = 569
trp_town_15_armorer = 570
trp_town_16_armorer = 571
trp_town_17_armorer = 572
trp_town_18_armorer = 573
trp_town_19_armorer = 574
trp_town_20_armorer = 575
trp_town_21_armorer = 576
trp_town_22_armorer = 577
trp_town_1_weaponsmith = 578
trp_town_2_weaponsmith = 579
trp_town_3_weaponsmith = 580
trp_town_4_weaponsmith = 581
trp_town_5_weaponsmith = 582
trp_town_6_weaponsmith = 583
trp_town_7_weaponsmith = 584
trp_town_8_weaponsmith = 585
trp_town_9_weaponsmith = 586
trp_town_10_weaponsmith = 587
trp_town_11_weaponsmith = 588
trp_town_12_weaponsmith = 589
trp_town_13_weaponsmith = 590
trp_town_14_weaponsmith = 591
trp_town_15_weaponsmith = 592
trp_town_16_weaponsmith = 593
trp_town_17_weaponsmith = 594
trp_town_18_weaponsmith = 595
trp_town_19_weaponsmith = 596
trp_town_20_weaponsmith = 597
trp_town_21_weaponsmith = 598
trp_town_22_weaponsmith = 599
trp_town_1_tavernkeeper = 600
trp_town_2_tavernkeeper = 601
trp_town_3_tavernkeeper = 602
trp_town_4_tavernkeeper = 603
trp_town_5_tavernkeeper = 604
trp_town_6_tavernkeeper = 605
trp_town_7_tavernkeeper = 606
trp_town_8_tavernkeeper = 607
trp_town_9_tavernkeeper = 608
trp_town_10_tavernkeeper = 609
trp_town_11_tavernkeeper = 610
trp_town_12_tavernkeeper = 611
trp_town_13_tavernkeeper = 612
trp_town_14_tavernkeeper = 613
trp_town_15_tavernkeeper = 614
trp_town_16_tavernkeeper = 615
trp_town_17_tavernkeeper = 616
trp_town_18_tavernkeeper = 617
trp_town_19_tavernkeeper = 618
trp_town_20_tavernkeeper = 619
trp_town_21_tavernkeeper = 620
trp_town_22_tavernkeeper = 621
trp_town_1_merchant = 622
trp_town_2_merchant = 623
trp_town_3_merchant = 624
trp_town_4_merchant = 625
trp_town_5_merchant = 626
trp_town_6_merchant = 627
trp_town_7_merchant = 628
trp_town_8_merchant = 629
trp_town_9_merchant = 630
trp_town_10_merchant = 631
trp_town_11_merchant = 632
trp_town_12_merchant = 633
trp_town_13_merchant = 634
trp_town_14_merchant = 635
trp_town_15_merchant = 636
trp_town_16_merchant = 637
trp_town_17_merchant = 638
trp_town_18_merchant = 639
trp_town_19_merchant = 640
trp_town_20_merchant = 641
trp_town_21_merchant = 642
trp_town_22_merchant = 643
trp_salt_mine_merchant = 644
trp_town_1_horse_merchant = 645
trp_town_2_horse_merchant = 646
trp_town_3_horse_merchant = 647
trp_town_4_horse_merchant = 648
trp_town_5_horse_merchant = 649
trp_town_6_horse_merchant = 650
trp_town_7_horse_merchant = 651
trp_town_8_horse_merchant = 652
trp_town_9_horse_merchant = 653
trp_town_10_horse_merchant = 654
trp_town_11_horse_merchant = 655
trp_town_12_horse_merchant = 656
trp_town_13_horse_merchant = 657
trp_town_14_horse_merchant = 658
trp_town_15_horse_merchant = 659
trp_town_16_horse_merchant = 660
trp_town_17_horse_merchant = 661
trp_town_18_horse_merchant = 662
trp_town_19_horse_merchant = 663
trp_town_20_horse_merchant = 664
trp_town_21_horse_merchant = 665
trp_town_22_horse_merchant = 666
trp_town_1_mayor = 667
trp_town_2_mayor = 668
trp_town_3_mayor = 669
trp_town_4_mayor = 670
trp_town_5_mayor = 671
trp_town_6_mayor = 672
trp_town_7_mayor = 673
trp_town_8_mayor = 674
trp_town_9_mayor = 675
trp_town_10_mayor = 676
trp_town_11_mayor = 677
trp_town_12_mayor = 678
trp_town_13_mayor = 679
trp_town_14_mayor = 680
trp_town_15_mayor = 681
trp_town_16_mayor = 682
trp_town_17_mayor = 683
trp_town_18_mayor = 684
trp_town_19_mayor = 685
trp_town_20_mayor = 686
trp_town_21_mayor = 687
trp_town_22_mayor = 688
trp_village_1_elder = 689
trp_village_2_elder = 690
trp_village_3_elder = 691
trp_village_4_elder = 692
trp_village_5_elder = 693
trp_village_6_elder = 694
trp_village_7_elder = 695
trp_village_8_elder = 696
trp_village_9_elder = 697
trp_village_10_elder = 698
trp_village_11_elder = 699
trp_village_12_elder = 700
trp_village_13_elder = 701
trp_village_14_elder = 702
trp_village_15_elder = 703
trp_village_16_elder = 704
trp_village_17_elder = 705
trp_village_18_elder = 706
trp_village_19_elder = 707
trp_village_20_elder = 708
trp_village_21_elder = 709
trp_village_22_elder = 710
trp_village_23_elder = 711
trp_village_24_elder = 712
trp_village_25_elder = 713
trp_village_26_elder = 714
trp_village_27_elder = 715
trp_village_28_elder = 716
trp_village_29_elder = 717
trp_village_30_elder = 718
trp_village_31_elder = 719
trp_village_32_elder = 720
trp_village_33_elder = 721
trp_village_34_elder = 722
trp_village_35_elder = 723
trp_village_36_elder = 724
trp_village_37_elder = 725
trp_village_38_elder = 726
trp_village_39_elder = 727
trp_village_40_elder = 728
trp_village_41_elder = 729
trp_village_42_elder = 730
trp_village_43_elder = 731
trp_village_44_elder = 732
trp_village_45_elder = 733
trp_village_46_elder = 734
trp_village_47_elder = 735
trp_village_48_elder = 736
trp_village_49_elder = 737
trp_village_50_elder = 738
trp_village_51_elder = 739
trp_village_52_elder = 740
trp_village_53_elder = 741
trp_village_54_elder = 742
trp_village_55_elder = 743
trp_village_56_elder = 744
trp_village_57_elder = 745
trp_village_58_elder = 746
trp_village_59_elder = 747
trp_village_60_elder = 748
trp_village_61_elder = 749
trp_village_62_elder = 750
trp_village_63_elder = 751
trp_village_64_elder = 752
trp_village_65_elder = 753
trp_village_66_elder = 754
trp_village_67_elder = 755
trp_village_68_elder = 756
trp_village_69_elder = 757
trp_village_70_elder = 758
trp_village_71_elder = 759
trp_village_72_elder = 760
trp_village_73_elder = 761
trp_village_74_elder = 762
trp_village_75_elder = 763
trp_village_76_elder = 764
trp_village_77_elder = 765
trp_village_78_elder = 766
trp_village_79_elder = 767
trp_village_80_elder = 768
trp_village_81_elder = 769
trp_village_82_elder = 770
trp_village_83_elder = 771
trp_village_84_elder = 772
trp_village_85_elder = 773
trp_village_86_elder = 774
trp_village_87_elder = 775
trp_village_88_elder = 776
trp_village_89_elder = 777
trp_village_90_elder = 778
trp_village_91_elder = 779
trp_village_92_elder = 780
trp_village_93_elder = 781
trp_village_94_elder = 782
trp_village_95_elder = 783
trp_village_96_elder = 784
trp_village_97_elder = 785
trp_village_98_elder = 786
trp_village_99_elder = 787
trp_village_100_elder = 788
trp_village_101_elder = 789
trp_village_102_elder = 790
trp_village_103_elder = 791
trp_village_104_elder = 792
trp_village_105_elder = 793
trp_village_106_elder = 794
trp_village_107_elder = 795
trp_village_108_elder = 796
trp_village_109_elder = 797
trp_village_110_elder = 798
trp_merchants_end = 799
trp_town_1_master_craftsman = 800
trp_town_2_master_craftsman = 801
trp_town_3_master_craftsman = 802
trp_town_4_master_craftsman = 803
trp_town_5_master_craftsman = 804
trp_town_6_master_craftsman = 805
trp_town_7_master_craftsman = 806
trp_town_8_master_craftsman = 807
trp_town_9_master_craftsman = 808
trp_town_10_master_craftsman = 809
trp_town_11_master_craftsman = 810
trp_town_12_master_craftsman = 811
trp_town_13_master_craftsman = 812
trp_town_14_master_craftsman = 813
trp_town_15_master_craftsman = 814
trp_town_16_master_craftsman = 815
trp_town_17_master_craftsman = 816
trp_town_18_master_craftsman = 817
trp_town_19_master_craftsman = 818
trp_town_20_master_craftsman = 819
trp_town_21_master_craftsman = 820
trp_town_22_master_craftsman = 821
trp_zendar_chest = 822
trp_tutorial_chest_1 = 823
trp_tutorial_chest_2 = 824
trp_bonus_chest_1 = 825
trp_bonus_chest_2 = 826
trp_bonus_chest_3 = 827
trp_household_possessions = 828
trp_temp_array_a = 829
trp_temp_array_b = 830
trp_temp_array_c = 831
trp_stack_selection_amounts = 832
trp_stack_selection_ids = 833
trp_notification_menu_types = 834
trp_notification_menu_var1 = 835
trp_notification_menu_var2 = 836
trp_banner_background_color_array = 837
trp_multiplayer_data = 838
trp_local_merchant = 839
trp_tax_rebel = 840
trp_trainee_peasant = 841
trp_fugitive = 842
trp_belligerent_drunk = 843
trp_hired_assassin = 844
trp_fight_promoter = 845
trp_spy = 846
trp_spy_partner = 847
trp_nurse_for_lady = 848
trp_temporary_minister = 849
trp_quick_battle_6_player = 850
trp_swadian_crossbowman_multiplayer_ai = 851
trp_swadian_infantry_multiplayer_ai = 852
trp_swadian_man_at_arms_multiplayer_ai = 853
trp_vaegir_archer_multiplayer_ai = 854
trp_vaegir_spearman_multiplayer_ai = 855
trp_vaegir_horseman_multiplayer_ai = 856
trp_khergit_dismounted_lancer_multiplayer_ai = 857
trp_khergit_veteran_horse_archer_multiplayer_ai = 858
trp_khergit_lancer_multiplayer_ai = 859
trp_nord_veteran_multiplayer_ai = 860
trp_nord_scout_multiplayer_ai = 861
trp_nord_archer_multiplayer_ai = 862
trp_rhodok_veteran_crossbowman_multiplayer_ai = 863
trp_rhodok_veteran_spearman_multiplayer_ai = 864
trp_rhodok_scout_multiplayer_ai = 865
trp_sarranid_infantry_multiplayer_ai = 866
trp_sarranid_archer_multiplayer_ai = 867
trp_sarranid_horseman_multiplayer_ai = 868
trp_swadian_crossbowman_multiplayer = 869
trp_swadian_infantry_multiplayer = 870
trp_swadian_man_at_arms_multiplayer = 871
trp_vaegir_archer_multiplayer = 872
trp_vaegir_spearman_multiplayer = 873
trp_vaegir_horseman_multiplayer = 874
trp_khergit_veteran_horse_archer_multiplayer = 875
trp_khergit_lancer_multiplayer = 876
trp_nord_archer_multiplayer = 877
trp_nord_veteran_multiplayer = 878
trp_nord_scout_multiplayer = 879
trp_rhodok_veteran_crossbowman_multiplayer = 880
trp_rhodok_sergeant_multiplayer = 881
trp_rhodok_horseman_multiplayer = 882
trp_sarranid_archer_multiplayer = 883
trp_sarranid_footman_multiplayer = 884
trp_sarranid_mamluke_multiplayer = 885
trp_multiplayer_end = 886
trp_nurse = 887
trp_log_array_entry_type = 888
trp_log_array_entry_time = 889
trp_log_array_actor = 890
trp_log_array_center_object = 891
trp_log_array_center_object_lord = 892
trp_log_array_center_object_faction = 893
trp_log_array_troop_object = 894
trp_log_array_troop_object_faction = 895
trp_log_array_faction_object = 896
trp_quick_battle_troop_1 = 897
trp_quick_battle_troop_2 = 898
trp_quick_battle_troop_3 = 899
trp_quick_battle_troop_4 = 900
trp_quick_battle_troop_5 = 901
trp_quick_battle_troop_6 = 902
trp_quick_battle_troop_7 = 903
trp_quick_battle_troop_8 = 904
trp_quick_battle_troop_9 = 905
trp_quick_battle_troop_10 = 906
trp_quick_battle_troop_11 = 907
trp_quick_battle_troops_end = 908
trp_tutorial_fighter_1 = 909
trp_tutorial_fighter_2 = 910
trp_tutorial_fighter_3 = 911
trp_tutorial_fighter_4 = 912
trp_tutorial_archer_1 = 913
trp_tutorial_master_archer = 914
trp_tutorial_rider_1 = 915
trp_tutorial_rider_2 = 916
trp_tutorial_master_horseman = 917
trp_swadian_merchant = 918
trp_vaegir_merchant = 919
trp_khergit_merchant = 920
trp_nord_merchant = 921
trp_rhodok_merchant = 922
trp_sarranid_merchant = 923
trp_startup_merchants_end = 924
trp_sea_raider_leader = 925
trp_looter_leader = 926
trp_bandit_leaders_end = 927
trp_relative_of_merchant = 928
trp_relative_of_merchants_end = 929
trp_workshop_list = 930
trp_product_list = 931
