skill_str_begin = "str_skl_trade"
skill_str_end = "str_skl_end"

stringBaseScripts = {
    "name": "StringBaseScripts",
    "enable": True,
    "version": "v2.0.0",
    "desc": "与字符串相关的操作",
    "actions": [
        ("Append@strings", [
            ## 代码功能
            ("skl_trade", "trade"),
            ("skl_trade_desc", "trade_desc"),
            ("skl_leadership", "leadership"),
            ("skl_leadership_desc", "leadership_desc"),
            ("skl_prisoner_management", "prisoner_management"),
            ("skl_prisoner_management_desc", "prisoner_management_desc"),
            ("skl_reserved_1", "reserved_1"),
            ("skl_reserved_1_desc", "reserved_1_desc"),
            ("skl_reserved_2", "reserved_2"),
            ("skl_reserved_2_desc", "reserved_2_desc"),
            ("skl_reserved_3", "reserved_3"),
            ("skl_reserved_3_desc", "reserved_3_desc"),
            ("skl_reserved_4", "reserved_4"),
            ("skl_reserved_4_desc", "reserved_4_desc"),
            ("skl_persuasion", "persuasion"),
            ("skl_persuasion_desc", "persuasion_desc"),
            ("skl_engineer", "engineer"),
            ("skl_engineer_desc", "engineer_desc"),
            ("skl_first_aid", "first_aid"),
            ("skl_first_aid_desc", "first_aid_desc"),
            ("skl_surgery", "surgery"),
            ("skl_surgery_desc", "surgery_desc"),
            ("skl_wound_treatment", "wound_treatment"),
            ("skl_wound_treatment_desc", "wound_treatment_desc"),
            ("skl_inventory_management", "inventory_management"),
            ("skl_inventory_management_desc", "inventory_management_desc"),
            ("skl_spotting", "spotting"),
            ("skl_spotting_desc", "spotting_desc"),
            ("skl_pathfinding", "pathfinding"),
            ("skl_pathfinding_desc", "pathfinding_desc"),
            ("skl_tactics", "tactics"),
            ("skl_tactics_desc", "tactics_desc"),
            ("skl_tracking", "tracking"),
            ("skl_tracking_desc", "tracking_desc"),
            ("skl_trainer", "trainer"),
            ("skl_trainer_desc", "trainer_desc"),
            ("skl_reserved_5", "reserved_5"),
            ("skl_reserved_5_desc", "reserved_5_desc"),
            ("skl_reserved_6", "reserved_6"),
            ("skl_reserved_6_desc", "reserved_6_desc"),
            ("skl_reserved_7", "reserved_7"),
            ("skl_reserved_7_desc", "reserved_7_desc"),
            ("skl_reserved_8", "reserved_8"),
            ("skl_reserved_8_desc", "reserved_8_desc"),
            ("skl_looting", "looting"),
            ("skl_looting_desc", "looting_desc"),
            ("skl_horse_archery", "horse_archery"),
            ("skl_horse_archery_desc", "horse_archery_desc"),
            ("skl_riding", "riding"),
            ("skl_riding_desc", "riding_desc"),
            ("skl_athletics", "athletics"),
            ("skl_athletics_desc", "athletics_desc"),
            ("skl_shield", "shield"),
            ("skl_shield_desc", "shield_desc"),
            ("skl_weapon_master", "weapon_master"),
            ("skl_weapon_master_desc", "weapon_master_desc"),
            ("skl_reserved_9", "reserved_9"),
            ("skl_reserved_9_desc", "reserved_9_desc"),
            ("skl_reserved_10", "reserved_10"),
            ("skl_reserved_10_desc", "reserved_10_desc"),
            ("skl_reserved_11", "reserved_11"),
            ("skl_reserved_11_desc", "reserved_11_desc"),
            ("skl_reserved_12", "reserved_12"),
            ("skl_reserved_12_desc", "reserved_12_desc"),
            ("skl_reserved_13", "reserved_13"),
            ("skl_reserved_13_desc", "reserved_13_desc"),
            ("skl_power_draw", "power_draw"),
            ("skl_power_draw_desc", "power_draw_desc"),
            ("skl_power_throw", "power_throw"),
            ("skl_power_throw_desc", "power_throw_desc"),
            ("skl_power_strike", "power_strike"),
            ("skl_power_strike_desc", "power_strike_desc"),
            ("skl_ironflesh", "ironflesh"),
            ("skl_ironflesh_desc", "ironflesh_desc"),
            ("skl_reserved_14", "reserved_14"),
            ("skl_reserved_14_desc", "reserved_14_desc"),
            ("skl_reserved_15", "reserved_15"),
            ("skl_reserved_15_desc", "reserved_15_desc"),
            ("skl_reserved_16", "reserved_16"),
            ("skl_reserved_16_desc", "reserved_16_desc"),
            ("skl_reserved_17", "reserved_17"),
            ("skl_reserved_17_desc", "reserved_17_desc"),
            ("skl_reserved_18", "reserved_18"),
            ("skl_reserved_18_desc", "reserved_18_desc"),
            ("skl_end", "skill end")
        ]),
    ],
    "internationals": {
        "cns": {
            "game_strings": [
                "str_skl_trade|交 易 ",
                "str_skl_trade_desc|每 点 技 能 减 少 5%%的 交 易 损 失。（队 伍 技 能）",
                "str_skl_leadership|统 御 ",
                "str_skl_leadership_desc|每 点 增 加 部 队 命 令 上 限 5人， 提 高 部 队 士 气， 减 少 部 队 开 销 和 工 资 5%%。（领 袖 技 能）",
                "str_skl_prisoner_management|俘 虏 管 理 ",
                "str_skl_prisoner_management_desc|每 点 增 加 俘 虏 上 限 %d。（领 袖 技 能）",
                "str_skl_reserved_1|Reserved Skill 1",
                "str_skl_reserved_1_desc|This is a reserved skill.",
                "str_skl_reserved_2|Reserved Skill 2",
                "str_skl_reserved_2_desc|This is a reserved skill.",
                "str_skl_reserved_3|Reserved Skill 3",
                "str_skl_reserved_3_desc|This is a reserved skill.",
                "str_skl_reserved_4|Reserved Skill 4",
                "str_skl_reserved_4_desc|This is a reserved skill.",
                "str_skl_persuasion|说 服 力 ",
                "str_skl_persuasion_desc|此 技 能 帮 助 你， 使 你 的 观 点 更 容 易 让 人 接 受。 同 时 还 能 降 低 让 NPC 按 照 你 所 说 的 去 做 所 需 的 最 低 关 系 值。 （个 人 技 能）",
                "str_skl_engineer|工 程 学 ",
                "str_skl_engineer_desc|此 技 能 使 你 更 有 效 地 建 造 攻 城 器 械 和 加 快 封 地 建 设。（队 伍 技 能）",
                "str_skl_first_aid|急 救 ",
                "str_skl_first_aid_desc|每 点 返 还 给 英 雄 们 5%%在 上 次 战 斗 中 损 失 的 生 命 值。（队 伍 技 能）",
                "str_skl_surgery|手 术 ",
                "str_skl_surgery_desc|每 点 增 加 4%%的 机 会， 使 得 本 来 会 死 亡 的 队 伍 成 员 保 住 性 命。（队 伍 技 能）",
                "str_skl_wound_treatment|疗 伤 ",
                "str_skl_wound_treatment_desc|每 点 增 加 队 伍 生 命 值 回 复 速 度 20%%。（队 伍 技 能）",
                "str_skl_inventory_management|物 品 管 理 ",
                "str_skl_inventory_management_desc|每 点 增 加 物 品 栏 容 量 6格。（领 袖 技 能）",
                "str_skl_spotting|侦 察 ",
                "str_skl_spotting_desc|每 点 增 加 队 伍 侦 察 范 围 10%%。（队 伍 技 能）",
                "str_skl_pathfinding|向 导 ",
                "str_skl_pathfinding_desc|每 点 增 加 队 伍 地 图 移 动 速 度 3%%。（队 伍 技 能）",
                "str_skl_tactics|战 术 ",
                "str_skl_tactics_desc|每 2点 增 加 1点 战 斗 优 势。（敌 我 上 场 人 数）（队 伍 技 能）",
                "str_skl_tracking|跟 踪 ",
                "str_skl_tracking_desc|从 脚 印 和 其 它 印 迹 中 发 现 更 多 信 息。（队 伍 技 能）",
                "str_skl_trainer|教 练 ",
                "str_skl_trainer_desc|每 天 每 位 有 该 项 技 能 的 英 雄 会 增 加 经 验 值 给 其 它 级 别 较 低 的 队 伍 成 员。 传 授 的 经 验 值 依 次 为： {0, 4, 10, 16, 23, 30, 38, 46, 55, 65, 80}。（个 人 技 能）",
                "str_skl_reserved_5|Reserved Skill 5",
                "str_skl_reserved_5_desc|This is a reserved skill.",
                "str_skl_reserved_6|Reserved Skill 6",
                "str_skl_reserved_6_desc|This is a reserved skill.",
                "str_skl_reserved_7|Reserved Skill 7",
                "str_skl_reserved_7_desc|This is a reserved skill.",
                "str_skl_reserved_8|Reserved Skill 8",
                "str_skl_reserved_8_desc|This is a reserved skill.",
                "str_skl_looting|掠 夺 ",
                "str_skl_looting_desc|每 点 提 高 获 得 战 利 品 的 数 量 10%%。（队 伍 技 能）",
                "str_skl_horse_archery|骑 射 ",
                "str_skl_horse_archery_desc|减 少 在 马 背 上 射 箭 与 投 掷 的 精 度 和 伤 害 损 失。（个 人 技 能）",
                "str_skl_riding|骑 术 ",
                "str_skl_riding_desc|可 以 骑 更 好 的 马， 提 高 骑 行 速 度 和 操 纵。（个 人 技 能）",
                "str_skl_athletics|跑 动 ",
                "str_skl_athletics_desc|提 高 跑 动 速 度。（个 人 技 能）",
                "str_skl_shield|盾 防 ",
                "str_skl_shield_desc|减 少 盾 的 损 坏 程 度（每 点 减 少 8%%） 和 提 高 盾 的 格 挡 速 度， 以 及 覆 盖 范 围。（个 人 技 能）",
                "str_skl_weapon_master|武 器 掌 握 ",
                "str_skl_weapon_master_desc|让 武 器 熟 练 度 提 升 的 更 快 并 且 提 高 武 器 熟 练 度 的 上 限。 上 限 依 次 为： 60, 100, 140, 180, 220, 260, 300, 340, 380, 420。（个 人 技 能）",
                "str_skl_reserved_9|Reserved Skill 9",
                "str_skl_reserved_9_desc|This is a reserved skill.",
                "str_skl_reserved_10|Reserved Skill 10",
                "str_skl_reserved_10_desc|This is a reserved skill.",
                "str_skl_reserved_11|Reserved Skill 11",
                "str_skl_reserved_11_desc|This is a reserved skill.",
                "str_skl_reserved_12|Reserved Skill 12",
                "str_skl_reserved_12_desc|This is a reserved skill.",
                "str_skl_reserved_13|Reserved Skill 13",
                "str_skl_reserved_13_desc|This is a reserved skill.",
                "str_skl_power_draw|强 弓 ",
                "str_skl_power_draw_desc|角 色 可 以 使 用 更 强 力 的 弓。 每 点 增 加 弓 箭 伤 害 14%%， 最 高 有 效 等 级 不 超 过 弓 的 等 级 加 四。（个 人 技 能）",
                "str_skl_power_throw|强 掷 ",
                "str_skl_power_throw_desc|每 点 增 加 10%%的 投 掷 伤 害。（个 人 技 能）",
                "str_skl_power_strike|强 击 ",
                "str_skl_power_strike_desc|每 点 增 加 8%%的 格 斗 伤 害。（个 人 技 能）",
                "str_skl_ironflesh|铁 骨 ",
                "str_skl_ironflesh_desc|每 点 增 加 2点 生 命 值。（个 人 技 能）",
                "str_skl_reserved_14|Reserved Skill 14",
                "str_skl_reserved_14_desc|This is a reserved skill.",
                "str_skl_reserved_15|Reserved Skill 15",
                "str_skl_reserved_15_desc|This is a reserved skill.",
                "str_skl_reserved_16|Reserved Skill 16",
                "str_skl_reserved_16_desc|This is a reserved skill.",
                "str_skl_reserved_17|Reserved Skill 17",
                "str_skl_reserved_17_desc|This is a reserved skill.",
                "str_skl_reserved_18|Reserved Skill 18",
                "str_skl_reserved_18_desc|This is a reserved skill.",
                "str_skl_end|skill end.",
            ]
        }
    }
}
