script_game_start = 0
script_game_get_use_string = 1
script_game_quick_start = 2
script_get_army_size_from_slider_value = 3
script_spawn_quick_battle_army = 4
script_player_arrived = 5
script_game_set_multiplayer_mission_end = 6
script_game_enable_cheat_menu = 7
script_game_get_console_command = 8
script_game_event_party_encounter = 9
script_game_event_simulate_battle = 10
script_game_event_battle_end = 11
script_order_best_besieger_party_to_guard_center = 12
script_game_get_item_buy_price_factor = 13
script_game_get_item_sell_price_factor = 14
script_get_trade_penalty = 15
script_game_event_buy_item = 16
script_game_event_sell_item = 17
script_start_wedding_cutscene = 18
script_game_get_troop_wage = 19
script_game_get_total_wage = 20
script_game_get_join_cost = 21
script_game_get_upgrade_xp = 22
script_game_get_upgrade_cost = 23
script_game_get_prisoner_price = 24
script_game_check_prisoner_can_be_sold = 25
script_game_get_morale_of_troops_from_faction = 26
script_game_event_detect_party = 27
script_game_event_undetect_party = 28
script_game_get_statistics_line = 29
script_game_get_date_text = 30
script_game_get_money_text = 31
script_game_get_party_companion_limit = 32
script_game_reset_player_party_name = 33
script_game_get_troop_note = 34
script_game_get_center_note = 35
script_game_get_faction_note = 36
script_game_get_quest_note = 37
script_game_get_info_page_note = 38
script_game_get_scene_name = 39
script_game_get_mission_template_name = 40
script_add_kill_death_counts = 41
script_warn_player_about_auto_team_balance = 42
script_check_team_balance = 43
script_check_creating_ladder_dust_effect = 44
script_money_management_after_agent_death = 45
script_initialize_aristocracy = 46
script_initialize_trade_routes = 47
script_initialize_faction_troop_types = 48
script_initialize_item_info = 49
script_initialize_town_arena_info = 50
script_initialize_banner_info = 51
script_initialize_economic_information = 52
script_initialize_all_scene_prop_slots = 53
script_initialize_scene_prop_slots = 54
script_use_item = 55
script_determine_team_flags = 56
script_calculate_flag_move_time = 57
script_move_death_mode_flags_down = 58
script_move_flag = 59
script_move_headquarters_flags = 60
script_set_num_agents_around_flag = 61
script_change_flag_owner = 62
script_move_object_to_nearest_entry_point = 63
script_multiplayer_server_on_agent_spawn_common = 64
script_multiplayer_server_player_joined_common = 65
script_multiplayer_server_before_mission_start_common = 66
script_multiplayer_server_on_agent_killed_or_wounded_common = 67
script_multiplayer_close_gate_if_it_is_open = 68
script_multiplayer_move_moveable_objects_initial_positions = 69
script_move_belfries_to_their_first_entry_point = 70
script_team_set_score = 71
script_player_set_score = 72
script_player_set_kill_count = 73
script_player_set_death_count = 74
script_set_attached_scene_prop = 75
script_set_team_flag_situation = 76
script_start_death_mode = 77
script_calculate_new_death_waiting_time_at_death_mod = 78
script_calculate_number_of_targets_destroyed = 79
script_initialize_objects = 80
script_initialize_objects_clients = 81
script_show_multiplayer_message = 82
script_get_headquarters_scores = 83
script_draw_this_round = 84
script_check_achievement_last_man_standing = 85
script_find_most_suitable_bot_to_control = 86
script_game_receive_url_response = 87
script_game_get_cheat_mode = 88
script_game_receive_network_message = 89
script_cf_multiplayer_evaluate_poll = 90
script_multiplayer_accept_duel = 91
script_game_get_multiplayer_server_option_for_mission_template = 92
script_game_multiplayer_server_option_for_mission_template_to_string = 93
script_cf_multiplayer_team_is_available = 94
script_find_number_of_agents_constant = 95
script_game_multiplayer_event_duel_offered = 96
script_game_get_multiplayer_game_type_enum = 97
script_game_multiplayer_get_game_type_mission_template = 98
script_multiplayer_get_mission_template_game_type = 99
script_multiplayer_fill_available_factions_combo_button = 100
script_multiplayer_get_troop_class = 101
script_multiplayer_clear_player_selected_items = 102
script_multiplayer_init_player_slots = 103
script_multiplayer_initialize_belfry_wheel_rotations = 104
script_send_open_close_information_of_object = 105
script_multiplayer_send_initial_information = 106
script_multiplayer_remove_headquarters_flags = 107
script_multiplayer_remove_destroy_mod_targets = 108
script_multiplayer_init_mission_variables = 109
script_multiplayer_event_mission_end = 110
script_multiplayer_event_agent_killed_or_wounded = 111
script_multiplayer_get_item_value_for_troop = 112
script_multiplayer_get_previous_item_for_item_and_troop = 113
script_cf_multiplayer_is_item_default_for_troop = 114
script_multiplayer_calculate_cur_selected_items_cost = 115
script_multiplayer_set_item_available_for_troop = 116
script_multiplayer_send_item_selections = 117
script_multiplayer_set_default_item_selections_for_troop = 118
script_multiplayer_display_available_items_for_troop_and_item_classes = 119
script_multiplayer_fill_map_game_types = 120
script_multiplayer_count_players_bots = 121
script_multiplayer_find_player_leader_for_bot = 122
script_multiplayer_find_bot_troop_and_group_for_spawn = 123
script_multiplayer_change_leader_of_bot = 124
script_multiplayer_find_spawn_point = 125
script_multiplayer_find_spawn_point_2 = 126
script_multiplayer_buy_agent_equipment = 127
script_party_get_ideal_size = 128
script_game_get_party_prisoner_limit = 129
script_game_get_item_extra_text = 130
script_game_on_disembark = 131
script_game_context_menu_get_buttons = 132
script_game_event_context_menu_button_clicked = 133
script_game_get_skill_modifier_for_troop = 134
script_npc_get_troop_wage = 135
script_setup_talk_info = 136
script_setup_talk_info_companions = 137
script_update_party_creation_random_limits = 138
script_set_trade_route_between_centers = 139
script_average_trade_good_prices = 140
script_average_trade_good_prices_2 = 141
script_average_trade_good_productions = 142
script_normalize_trade_good_productions = 143
script_update_trade_good_prices = 144
script_update_trade_good_price_for_party = 145
script_center_get_production = 146
script_center_get_consumption = 147
script_get_enterprise_name = 148
script_do_merchant_town_trade = 149
script_party_calculate_regular_strength = 150
script_party_calculate_strength = 151
script_loot_player_items = 152
script_party_calculate_loot = 153
script_calculate_main_party_shares = 154
script_party_give_xp_and_gold = 155
script_setup_troop_meeting = 156
script_setup_party_meeting = 157
script_get_meeting_scene = 158
script_party_remove_all_companions = 159
script_party_remove_all_prisoners = 160
script_party_add_party_companions = 161
script_party_add_party_prisoners = 162
script_party_prisoners_add_party_companions = 163
script_party_prisoners_add_party_prisoners = 164
script_party_add_party = 165
script_party_copy = 166
script_clear_party_group = 167
script_party_add_wounded_members_as_prisoners = 168
script_get_nonempty_party_in_group = 169
script_collect_prisoners_from_empty_parties = 170
script_change_party_morale = 171
script_count_casualties_and_adjust_morale = 172
script_print_casualties_to_s0 = 173
script_write_fit_party_members_to_stack_selection = 174
script_remove_fit_party_member_from_stack_selection = 175
script_remove_random_fit_party_member_from_stack_selection = 176
script_add_routed_party = 177
script_cf_training_ground_sub_routine_1_for_melee_details = 178
script_training_ground_sub_routine_2_for_melee_details = 179
script_cf_training_ground_sub_routine_for_training_result = 180
script_print_troop_owned_centers_in_numbers_to_s0 = 181
script_get_random_melee_training_weapon = 182
script_start_training_at_training_ground = 183
script_party_count_fit_regulars = 184
script_party_count_fit_for_battle = 185
script_party_count_members_with_full_health = 186
script_get_stack_with_rank = 187
script_inflict_casualties_to_party = 188
script_move_members_with_ratio = 189
script_count_parties_of_faction_and_party_type = 190
script_faction_get_number_of_armies = 191
script_faction_recalculate_strength = 192
script_cf_select_random_town_with_faction = 193
script_cf_select_random_village_with_faction = 194
script_cf_select_random_walled_center_with_faction = 195
script_cf_select_random_walled_center_with_faction_and_owner_priority_no_siege = 196
script_cf_select_random_walled_center_with_faction_and_less_strength_priority = 197
script_cf_select_random_town_at_peace_with_faction = 198
script_cf_select_random_town_at_peace_with_faction_in_trade_route = 199
script_cf_select_most_profitable_town_at_peace_with_faction_in_trade_route = 200
script_shuffle_troop_slots = 201
script_get_quest = 202
script_get_dynamic_quest = 203
script_get_political_quest = 204
script_npc_find_quest_for_player_to_s11 = 205
script_cf_get_random_enemy_center_within_range = 206
script_cf_faction_get_random_enemy_faction = 207
script_cf_faction_get_random_friendly_faction = 208
script_cf_troop_get_random_enemy_troop_with_occupation = 209
script_cf_get_random_lord_in_a_center_with_faction = 210
script_cf_get_random_lord_except_king_with_faction = 211
script_cf_get_random_lord_from_another_faction_in_a_center = 212
script_get_closest_walled_center = 213
script_get_closest_center = 214
script_get_closest_center_of_faction = 215
script_get_closest_walled_center_of_faction = 216
script_let_nearby_parties_join_current_battle = 217
script_party_wound_all_members_aux = 218
script_party_wound_all_members = 219
script_calculate_battle_advantage = 220
script_cf_check_enemies_nearby = 221
script_get_heroes_attached_to_center_aux = 222
script_get_heroes_attached_to_center = 223
script_get_heroes_attached_to_center_as_prisoner_aux = 224
script_get_heroes_attached_to_center_as_prisoner = 225
script_give_center_to_faction = 226
script_give_center_to_faction_aux = 227
script_change_troop_faction = 228
script_troop_set_title_according_to_faction = 229
script_give_center_to_lord = 230
script_get_number_of_hero_centers = 231
script_cf_get_random_enemy_center = 232
script_find_travel_location = 233
script_get_relation_between_parties = 234
script_calculate_weekly_party_wage = 235
script_calculate_player_faction_wage = 236
script_calculate_hero_weekly_net_income_and_add_to_wealth = 237
script_cf_reinforce_party = 238
script_hire_men_to_kingdom_hero_party = 239
script_get_percentage_with_randomized_round = 240
script_create_cattle_herd = 241
script_buy_cattle_from_village = 242
script_kill_cattle_from_herd = 243
script_create_kingdom_hero_party = 244
script_create_kingdom_party_if_below_limit = 245
script_cf_create_kingdom_party = 246
script_get_troop_attached_party = 247
script_center_get_food_consumption = 248
script_center_get_food_store_limit = 249
script_refresh_village_merchant_inventory = 250
script_refresh_village_defenders = 251
script_village_set_state = 252
script_process_village_raids = 253
script_process_sieges = 254
script_lift_siege = 255
script_process_alarms = 256
script_allow_vassals_to_join_indoor_battle = 257
script_party_set_ai_state = 258
script_cf_party_under_player_suggestion = 259
script_troop_does_business_in_center = 260
script_process_kingdom_parties_ai = 261
script_process_hero_ai = 262
script_begin_assault_on_center = 263
script_select_faction_marshall = 264
script_get_center_faction_relation_including_player = 265
script_update_report_to_army_quest_note = 266
script_decide_faction_ai = 267
script_check_and_finish_active_army_quests_for_faction = 268
script_troop_get_player_relation = 269
script_change_troop_renown = 270
script_change_player_relation_with_troop = 271
script_change_player_relation_with_center = 272
script_change_player_relation_with_faction = 273
script_set_player_relation_with_faction = 274
script_change_player_relation_with_faction_ex = 275
script_cf_get_random_active_faction_except_player_faction_and_faction = 276
script_make_kingdom_hostile_to_player = 277
script_change_player_honor = 278
script_change_player_party_morale = 279
script_cf_player_has_item_without_modifier = 280
script_get_player_party_morale_values = 281
script_diplomacy_start_war_between_kingdoms = 282
script_diplomacy_party_attacks_neutral = 283
script_party_calculate_and_set_nearby_friend_enemy_follower_strengths = 284
script_init_ai_calculation = 285
script_recalculate_ais = 286
script_calculate_troop_ai = 287
script_diplomacy_start_peace_between_kingdoms = 288
script_event_kingdom_make_peace_with_kingdom = 289
script_randomly_start_war_peace_new = 290
script_exchange_prisoners_between_factions = 291
script_add_notification_menu = 292
script_finish_quest = 293
script_get_information_about_troops_position = 294
script_recruit_troop_as_companion = 295
script_setup_random_scene = 296
script_enter_dungeon = 297
script_enter_court = 298
script_setup_meet_lady = 299
script_find_high_ground_around_pos1 = 300
script_select_battle_tactic = 301
script_select_battle_tactic_aux = 302
script_battle_tactic_init = 303
script_battle_tactic_init_aux = 304
script_calculate_team_powers = 305
script_apply_effect_of_other_people_on_courage_scores = 306
script_apply_death_effect_on_courage_scores = 307
script_decide_run_away_or_not = 308
script_battle_tactic_apply = 309
script_battle_tactic_apply_aux = 310
script_team_get_class_percentages = 311
script_get_closest3_distance_of_enemies_at_pos1 = 312
script_team_get_average_position_of_enemies = 313
script_search_troop_prisoner_of_party = 314
script_change_debt_to_troop = 315
script_abort_quest = 316
script_cf_is_quest_troop = 317
script_check_friendly_kills = 318
script_simulate_retreat = 319
script_simulate_battle_with_agents_aux = 320
script_map_get_random_position_around_position_within_range = 321
script_get_number_of_unclaimed_centers_by_player = 322
script_cf_troop_check_troop_is_enemy = 323
script_troop_get_leaded_center_with_index = 324
script_cf_troop_get_random_leaded_walled_center_with_less_strength_priority = 325
script_cf_troop_get_random_leaded_town_or_village_except_center = 326
script_troop_write_owned_centers_to_s2 = 327
script_troop_write_family_relations_to_s1 = 328
script_troop_get_family_relation_to_troop = 329
script_collect_friendly_parties = 330
script_encounter_calculate_fit = 331
script_encounter_init_variables = 332
script_calculate_renown_value = 333
script_cf_get_first_agent_with_troop_id = 334
script_cf_team_get_average_position_of_agents_with_type_to_pos1 = 335
script_cf_turn_windmill_fans = 336
script_print_party_members = 337
script_round_value = 338
script_change_banners_and_chest = 339
script_remove_siege_objects = 340
script_describe_relation_to_s63 = 341
script_describe_center_relation_to_s3 = 342
script_center_ambiance_sounds = 343
script_center_set_walker_to_type = 344
script_cf_center_get_free_walker = 345
script_center_remove_walker_type_from_walkers = 346
script_init_town_walkers = 347
script_cf_enter_center_location_bandit_check = 348
script_init_town_agent = 349
script_init_town_walker_agents = 350
script_agent_get_town_walker_details = 351
script_town_walker_occupation_string_to_s14 = 352
script_tick_town_walkers = 353
script_set_town_walker_destination = 354
script_town_init_doors = 355
script_siege_init_ai_and_belfry = 356
script_cf_siege_move_belfry = 357
script_cf_siege_rotate_belfry_platform = 358
script_cf_siege_assign_men_to_belfry = 359
script_siege_move_archers_to_archer_positions = 360
script_store_movement_order_name_to_s1 = 361
script_store_riding_order_name_to_s1 = 362
script_store_weapon_usage_order_name_to_s1 = 363
script_team_give_order_from_order_panel = 364
script_update_order_panel = 365
script_update_agent_position_on_map = 366
script_convert_3d_pos_to_map_pos = 367
script_update_order_flags_on_map = 368
script_update_order_panel_checked_classes = 369
script_update_order_panel_statistics_and_map = 370
script_set_town_picture = 371
script_consume_food = 372
script_calculate_troop_score_for_center = 373
script_assign_lords_to_empty_centers = 374
script_create_village_farmer_party = 375
script_do_party_center_trade = 376
script_player_join_faction = 377
script_player_leave_faction = 378
script_deactivate_player_faction = 379
script_activate_player_faction = 380
script_agent_reassign_team = 381
script_start_quest = 382
script_conclude_quest = 383
script_succeed_quest = 384
script_fail_quest = 385
script_report_quest_troop_positions = 386
script_end_quest = 387
script_cancel_quest = 388
script_update_village_market_towns = 389
script_update_mercenary_units_of_towns = 390
script_update_volunteer_troops_in_village = 391
script_update_npc_volunteer_troops_in_village = 392
script_update_companion_candidates_in_taverns = 393
script_update_ransom_brokers = 394
script_update_tavern_travellers = 395
script_update_villages_infested_by_bandits = 396
script_update_booksellers = 397
script_update_tavern_minstrels = 398
script_update_other_taverngoers = 399
script_update_faction_notes = 400
script_update_faction_political_notes = 401
script_update_faction_traveler_notes = 402
script_update_troop_notes = 403
script_update_troop_location_notes = 404
script_update_troop_location_notes_prisoned = 405
script_update_troop_political_notes = 406
script_update_center_notes = 407
script_update_center_recon_notes = 408
script_update_all_notes = 409
script_agent_troop_get_banner_mesh = 410
script_shield_item_set_banner = 411
script_troop_agent_set_banner = 412
script_add_troop_to_cur_tableau = 413
script_add_troop_to_cur_tableau_for_character = 414
script_add_troop_to_cur_tableau_for_inventory = 415
script_add_troop_to_cur_tableau_for_profile = 416
script_add_troop_to_cur_tableau_for_retirement = 417
script_add_troop_to_cur_tableau_for_party = 418
script_get_prosperity_text_to_s50 = 419
script_spawn_bandits = 420
script_count_mission_casualties_from_agents = 421
script_get_max_skill_of_player_party = 422
script_upgrade_hero_party = 423
script_get_improvement_details = 424
script_cf_troop_agent_is_alive = 425
script_cf_village_recruit_volunteers_cond = 426
script_village_recruit_volunteers_recruit = 427
script_get_troop_item_amount = 428
script_get_name_from_dna_to_s50 = 429
script_change_center_prosperity = 430
script_get_center_ideal_prosperity = 431
script_good_price_affects_good_production = 432
script_get_poorest_village_of_faction = 433
script_troop_add_gold = 434
script_initialize_npcs = 435
script_objectionable_action = 436
script_post_battle_personality_clash_check = 437
script_event_player_defeated_enemy_party = 438
script_event_player_captured_as_prisoner = 439
script_npc_morale = 440
script_retire_companion = 441
script_reduce_companion_morale_for_clash = 442
script_calculate_ransom_amount_for_troop = 443
script_offer_ransom_amount_to_player_for_prisoners_in_party = 444
script_event_hero_taken_prisoner_by_player = 445
script_cf_check_hero_can_escape_from_player = 446
script_cf_party_remove_random_regular_troop = 447
script_place_player_banner_near_inventory = 448
script_place_player_banner_near_inventory_bms = 449
script_stay_captive_for_hours = 450
script_set_parties_around_player_ignore_player = 451
script_randomly_make_prisoner_heroes_escape_from_party = 452
script_fill_tournament_participants_troop = 453
script_get_num_tournament_participants = 454
script_get_random_tournament_participant = 455
script_add_tournament_participant = 456
script_get_random_tournament_team_amount_and_size = 457
script_get_troop_priority_point_for_tournament = 458
script_sort_tournament_participant_troops = 459
script_remove_tournament_participants_randomly = 460
script_end_tournament_fight = 461
script_get_win_amount_for_tournament_bet = 462
script_tournament_place_bet = 463
script_calculate_amount_of_cattle_can_be_stolen = 464
script_draw_banner_to_region = 465
script_get_troop_custom_banner_num_positionings = 466
script_get_custom_banner_charge_type_position_scale_color = 467
script_get_random_custom_banner = 468
script_get_custom_banner_color_from_index = 469
script_cf_check_color_visibility = 470
script_get_next_active_kingdom = 471
script_remove_cattles_if_herd_is_close_to_party = 472
script_get_rumor_to_s61 = 473
script_lord_comment_to_s43 = 474
script_add_log_entry = 475
script_get_relevant_comment_for_log_entry = 476
script_get_relevant_comment_to_s42 = 477
script_merchant_road_info_to_s42 = 478
script_get_manhunt_information_to_s15 = 479
script_rebellion_arguments = 480
script_get_culture_with_party_faction_for_music = 481
script_get_culture_with_faction_for_music = 482
script_music_set_situation_with_culture = 483
script_combat_music_set_situation_with_culture = 484
script_play_victorious_sound = 485
script_set_items_for_tournament = 486
script_custom_battle_end = 487
script_remove_troop_from_prison = 488
script_debug_variables = 489
script_troop_describes_troop_to_s15 = 490
script_troop_describes_quarrel_with_troop_to_s14 = 491
script_cf_test_lord_incompatibility_to_s17 = 492
script_troop_get_romantic_chemistry_with_troop = 493
script_cf_troop_get_romantic_attraction_to_troop = 494
script_cf_random_political_event = 495
script_evaluate_realm_stability = 496
script_battle_political_consequences = 497
script_faction_inflict_war_damage_on_faction = 498
script_calculate_troop_political_factors_for_liege = 499
script_cf_troop_can_intrigue = 500
script_troop_change_relation_with_troop = 501
script_troop_get_relation_with_troop = 502
script_appoint_faction_marshall = 503
script_center_get_item_consumption = 504
script_locate_player_minister = 505
script_lord_get_home_center = 506
script_get_kingdom_lady_social_determinants = 507
script_age_troop_one_year = 508
script_add_lady_items = 509
script_init_troop_age = 510
script_assign_troop_love_interests = 511
script_faction_conclude_feast = 512
script_lady_evaluate_troop_as_suitor = 513
script_courtship_event_troop_court_lady = 514
script_courtship_event_lady_break_relation_with_suitor = 515
script_courtship_event_bride_marry_groom = 516
script_npc_decision_checklist_party_ai = 517
script_npc_decision_checklist_troop_follow_or_not = 518
script_find_total_prosperity_score = 519
script_calculate_center_assailability_score = 520
script_find_center_to_defend = 521
script_npc_decision_checklist_peace_or_war = 522
script_npc_decision_checklist_male_guardian_assess_suitor = 523
script_npc_decision_checklist_marry_female_pc = 524
script_courtship_poem_reactions = 525
script_diplomacy_faction_get_diplomatic_status_with_faction = 526
script_faction_follows_controversial_policy = 527
script_internal_politics_rate_feast_to_s9 = 528
script_faction_get_adjective_to_s10 = 529
script_setup_tavern_attacker = 530
script_activate_tavern_attackers = 531
script_deactivate_tavern_attackers = 532
script_activate_town_guard = 533
script_cf_prisoner_offered_parole = 534
script_neutral_behavior_in_fight = 535
script_party_inflict_attrition = 536
script_add_rumor_string_to_troop_notes = 537
script_character_can_wed_character = 538
script_troop_change_career = 539
script_center_get_goods_availability = 540
script_lord_find_alternative_faction = 541
script_set_up_duel_with_troop = 542
script_test_player_for_career_and_marriage_incompatability = 543
script_deduct_casualties_from_garrison = 544
script_npc_decision_checklist_take_stand_on_issue = 545
script_npc_decision_checklist_evaluate_faction_strategy = 546
script_process_player_enterprise = 547
script_replace_scene_items_with_spawn_items_before_ms = 548
script_replace_scene_items_with_spawn_items_after_ms = 549
script_cf_is_melee_weapon_for_tutorial = 550
script_iterate_pointer_arrow = 551
script_find_center_to_attack_alt = 552
script_npc_decision_checklist_evaluate_enemy_center_for_attack = 553
script_npc_decision_checklist_faction_ai_alt = 554
script_faction_last_reconnoitered_center = 555
script_reduce_exact_number_to_estimate = 556
script_calculate_castle_prosperities_by_using_its_villages = 557
script_initialize_tavern_variables = 558
script_prepare_alley_to_fight = 559
script_prepare_town_to_fight = 560
script_change_player_right_to_rule = 561
script_indict_lord_for_treason = 562
script_give_center_to_faction_while_maintaining_lord = 563
script_check_concilio_calradi_achievement = 564
script_refresh_center_inventories = 565
script_refresh_center_armories = 566
script_refresh_center_weaponsmiths = 567
script_refresh_center_stables = 568
script_set_party_ai_go_to_center = 569
script_set_party_ai_patrol_center = 570
script_create_party = 571
script_party_add_members = 572
script_party_add_xp_and_upgrade = 573
script_party_change_ai_state = 574
script_get_prisoner_prices = 575
script_update_center_wealth = 576
script_party_handle_prisoners = 577
script_get_the_nearby_center = 578
script_get_all_center_arr_of_faction = 579
script_add_party_as_companions = 580
script_get_loard_all_centers = 581
script_get_center_of_lord = 582
script_get_party_max_skill = 583
script_get_num_of_enemy_state = 584
script_troop_leave_home = 585
script_troop_go_home = 586
script_set_random_name = 587
script_get_random_first_name = 588
script_get_random_second_name = 589
script_set_name_for_son = 590
script_display_troop_info = 591
script_set_age_in_range = 592
script_set_son_age = 593
script_troop_clear_items = 594
script_get_troop_all_items = 595
script_get_troop_all_wealth = 596
script_player_cosplay_anyone = 597
script_get_lord_strength = 598
script_update_lord_wealth = 599
script_get_troop_inventory_free_amount = 600
script_create_battle_for_player = 601
script_go_to_center = 602
script_update_prisperity_for_all_center = 603
script_ladies_go_out = 604
script_init_building_when_game_start = 605
script_get_patrol_center_strength = 606
script_get_patrol_ideal_size = 607
script_get_patrol_ideal_party_count = 608
script_get_patrol_center_need_create_num = 609
script_get_patrol_party_need_size = 610
script_update_patrol_partys_for_all = 611
script_update_all_patrol_party_faction = 612
script_init_village_base_basic_business_data = 613
script_get_current_center_workshop_admin = 614
script_start_work_at_wild = 615
script_start_work_at_field = 616
script_update_field_work = 617


