qst_deliver_message = 0
qst_deliver_message_to_enemy_lord = 1
qst_raise_troops = 2
qst_escort_lady = 3
qst_deal_with_bandits_at_lords_village = 4
qst_collect_taxes = 5
qst_hunt_down_fugitive = 6
qst_kill_local_merchant = 7
qst_bring_back_runaway_serfs = 8
qst_follow_spy = 9
qst_capture_enemy_hero = 10
qst_lend_companion = 11
qst_collect_debt = 12
qst_incriminate_loyal_commander = 13
qst_meet_spy_in_enemy_town = 14
qst_capture_prisoners = 15
qst_lend_surgeon = 16
qst_follow_army = 17
qst_report_to_army = 18
qst_deliver_cattle_to_army = 19
qst_join_siege_with_army = 20
qst_screen_army = 21
qst_scout_waypoints = 22
qst_rescue_lord_by_replace = 23
qst_deliver_message_to_prisoner_lord = 24
qst_duel_for_lady = 25
qst_duel_courtship_rival = 26
qst_duel_avenge_insult = 27
qst_move_cattle_herd = 28
qst_escort_merchant_caravan = 29
qst_deliver_wine = 30
qst_troublesome_bandits = 31
qst_kidnapped_girl = 32
qst_persuade_lords_to_make_peace = 33
qst_deal_with_looters = 34
qst_deal_with_night_bandits = 35
qst_deliver_grain = 36
qst_deliver_cattle = 37
qst_train_peasants_against_bandits = 38
qst_eliminate_bandits_infesting_village = 39
qst_visit_lady = 40
qst_formal_marriage_proposal = 41
qst_obtain_liege_blessing = 42
qst_wed_betrothed = 43
qst_wed_betrothed_female = 44
qst_join_faction = 45
qst_rebel_against_kingdom = 46
qst_consult_with_minister = 47
qst_organize_feast = 48
qst_resolve_dispute = 49
qst_offer_gift = 50
qst_denounce_lord = 51
qst_intrigue_against_lord = 52
qst_track_down_bandits = 53
qst_track_down_provocateurs = 54
qst_retaliate_for_border_incident = 55
qst_raid_caravan_to_start_war = 56
qst_cause_provocation = 57
qst_rescue_prisoner = 58
qst_destroy_bandit_lair = 59
qst_blank_quest_2 = 60
qst_blank_quest_3 = 61
qst_blank_quest_4 = 62
qst_blank_quest_5 = 63
qst_blank_quest_6 = 64
qst_blank_quest_7 = 65
qst_blank_quest_8 = 66
qst_blank_quest_9 = 67
qst_blank_quest_10 = 68
qst_blank_quest_11 = 69
qst_blank_quest_12 = 70
qst_blank_quest_13 = 71
qst_blank_quest_14 = 72
qst_blank_quest_15 = 73
qst_blank_quest_16 = 74
qst_blank_quest_17 = 75
qst_blank_quest_18 = 76
qst_blank_quest_19 = 77
qst_blank_quest_20 = 78
qst_blank_quest_21 = 79
qst_blank_quest_22 = 80
qst_blank_quest_23 = 81
qst_blank_quest_24 = 82
qst_blank_quest_25 = 83
qst_blank_quest_26 = 84
qst_blank_quest_27 = 85
qst_collect_men = 86
qst_learn_where_merchant_brother_is = 87
qst_save_relative_of_merchant = 88
qst_save_town_from_bandits = 89
qst_quests_end = 90
qsttag_deliver_message = 504403158265495552
qsttag_deliver_message_to_enemy_lord = 504403158265495553
qsttag_raise_troops = 504403158265495554
qsttag_escort_lady = 504403158265495555
qsttag_deal_with_bandits_at_lords_village = 504403158265495556
qsttag_collect_taxes = 504403158265495557
qsttag_hunt_down_fugitive = 504403158265495558
qsttag_kill_local_merchant = 504403158265495559
qsttag_bring_back_runaway_serfs = 504403158265495560
qsttag_follow_spy = 504403158265495561
qsttag_capture_enemy_hero = 504403158265495562
qsttag_lend_companion = 504403158265495563
qsttag_collect_debt = 504403158265495564
qsttag_incriminate_loyal_commander = 504403158265495565
qsttag_meet_spy_in_enemy_town = 504403158265495566
qsttag_capture_prisoners = 504403158265495567
qsttag_lend_surgeon = 504403158265495568
qsttag_follow_army = 504403158265495569
qsttag_report_to_army = 504403158265495570
qsttag_deliver_cattle_to_army = 504403158265495571
qsttag_join_siege_with_army = 504403158265495572
qsttag_screen_army = 504403158265495573
qsttag_scout_waypoints = 504403158265495574
qsttag_rescue_lord_by_replace = 504403158265495575
qsttag_deliver_message_to_prisoner_lord = 504403158265495576
qsttag_duel_for_lady = 504403158265495577
qsttag_duel_courtship_rival = 504403158265495578
qsttag_duel_avenge_insult = 504403158265495579
qsttag_move_cattle_herd = 504403158265495580
qsttag_escort_merchant_caravan = 504403158265495581
qsttag_deliver_wine = 504403158265495582
qsttag_troublesome_bandits = 504403158265495583
qsttag_kidnapped_girl = 504403158265495584
qsttag_persuade_lords_to_make_peace = 504403158265495585
qsttag_deal_with_looters = 504403158265495586
qsttag_deal_with_night_bandits = 504403158265495587
qsttag_deliver_grain = 504403158265495588
qsttag_deliver_cattle = 504403158265495589
qsttag_train_peasants_against_bandits = 504403158265495590
qsttag_eliminate_bandits_infesting_village = 504403158265495591
qsttag_visit_lady = 504403158265495592
qsttag_formal_marriage_proposal = 504403158265495593
qsttag_obtain_liege_blessing = 504403158265495594
qsttag_wed_betrothed = 504403158265495595
qsttag_wed_betrothed_female = 504403158265495596
qsttag_join_faction = 504403158265495597
qsttag_rebel_against_kingdom = 504403158265495598
qsttag_consult_with_minister = 504403158265495599
qsttag_organize_feast = 504403158265495600
qsttag_resolve_dispute = 504403158265495601
qsttag_offer_gift = 504403158265495602
qsttag_denounce_lord = 504403158265495603
qsttag_intrigue_against_lord = 504403158265495604
qsttag_track_down_bandits = 504403158265495605
qsttag_track_down_provocateurs = 504403158265495606
qsttag_retaliate_for_border_incident = 504403158265495607
qsttag_raid_caravan_to_start_war = 504403158265495608
qsttag_cause_provocation = 504403158265495609
qsttag_rescue_prisoner = 504403158265495610
qsttag_destroy_bandit_lair = 504403158265495611
qsttag_blank_quest_2 = 504403158265495612
qsttag_blank_quest_3 = 504403158265495613
qsttag_blank_quest_4 = 504403158265495614
qsttag_blank_quest_5 = 504403158265495615
qsttag_blank_quest_6 = 504403158265495616
qsttag_blank_quest_7 = 504403158265495617
qsttag_blank_quest_8 = 504403158265495618
qsttag_blank_quest_9 = 504403158265495619
qsttag_blank_quest_10 = 504403158265495620
qsttag_blank_quest_11 = 504403158265495621
qsttag_blank_quest_12 = 504403158265495622
qsttag_blank_quest_13 = 504403158265495623
qsttag_blank_quest_14 = 504403158265495624
qsttag_blank_quest_15 = 504403158265495625
qsttag_blank_quest_16 = 504403158265495626
qsttag_blank_quest_17 = 504403158265495627
qsttag_blank_quest_18 = 504403158265495628
qsttag_blank_quest_19 = 504403158265495629
qsttag_blank_quest_20 = 504403158265495630
qsttag_blank_quest_21 = 504403158265495631
qsttag_blank_quest_22 = 504403158265495632
qsttag_blank_quest_23 = 504403158265495633
qsttag_blank_quest_24 = 504403158265495634
qsttag_blank_quest_25 = 504403158265495635
qsttag_blank_quest_26 = 504403158265495636
qsttag_blank_quest_27 = 504403158265495637
qsttag_collect_men = 504403158265495638
qsttag_learn_where_merchant_brother_is = 504403158265495639
qsttag_save_relative_of_merchant = 504403158265495640
qsttag_save_town_from_bandits = 504403158265495641
qsttag_quests_end = 504403158265495642


