menu_start_game_0 = 0
menu_start_phase_2 = 1
menu_start_game_3 = 2
menu_tutorial = 3
menu_reports = 4
menu_custom_battle_scene = 5
menu_custom_battle_end = 6
menu_start_game_1 = 7
menu_start_character_1 = 8
menu_start_character_2 = 9
menu_start_character_3 = 10
menu_start_character_4 = 11
menu_choose_skill = 12
menu_past_life_explanation = 13
menu_auto_return = 14
menu_morale_report = 15
menu_courtship_relations = 16
menu_lord_relations = 17
menu_companion_report = 18
menu_faction_orders = 19
menu_character_report = 20
menu_party_size_report = 21
menu_faction_relations_report = 22
menu_camp = 23
menu_camp_cheat = 24
menu_cheat_find_item = 25
menu_cheat_change_weather = 26
menu_camp_action = 27
menu_camp_recruit_prisoners = 28
menu_camp_no_prisoners = 29
menu_camp_action_read_book = 30
menu_camp_action_read_book_start = 31
menu_retirement_verify = 32
menu_end_game = 33
menu_cattle_herd = 34
menu_cattle_herd_kill = 35
menu_cattle_herd_kill_end = 36
menu_arena_duel_fight = 37
menu_arena_duel_conclusion = 38
menu_simple_encounter = 39
menu_encounter_retreat_confirm = 40
menu_encounter_retreat = 41
menu_order_attack_begin = 42
menu_order_attack_2 = 43
menu_battle_debrief = 44
menu_total_victory = 45
menu_enemy_slipped_away = 46
menu_total_defeat = 47
menu_permanent_damage = 48
menu_pre_join = 49
menu_join_battle = 50
menu_join_order_attack = 51
menu_zendar = 52
menu_salt_mine = 53
menu_four_ways_inn = 54
menu_test_scene = 55
menu_battlefields = 56
menu_dhorak_keep = 57
menu_join_siege_outside = 58
menu_cut_siege_without_fight = 59
menu_besiegers_camp_with_allies = 60
menu_castle_outside = 61
menu_castle_guard = 62
menu_castle_entry_granted = 63
menu_castle_entry_denied = 64
menu_castle_meeting = 65
menu_castle_meeting_selected = 66
menu_castle_besiege = 67
menu_siege_attack_meets_sally = 68
menu_castle_besiege_inner_battle = 69
menu_construct_ladders = 70
menu_construct_siege_tower = 71
menu_castle_attack_walls_simulate = 72
menu_castle_attack_walls_with_allies_simulate = 73
menu_castle_taken_by_friends = 74
menu_castle_taken = 75
menu_castle_taken_2 = 76
menu_requested_castle_granted_to_player = 77
menu_requested_castle_granted_to_player_husband = 78
menu_requested_castle_granted_to_another = 79
menu_requested_castle_granted_to_another_female = 80
menu_leave_faction = 81
menu_give_center_to_player = 82
menu_give_center_to_player_2 = 83
menu_oath_fulfilled = 84
menu_siege_started_defender = 85
menu_siege_join_defense = 86
menu_enter_your_own_castle = 87
menu_village = 88
menu_village_hostile_action = 89
menu_recruit_volunteers = 90
menu_village_hunt_down_fugitive_defeated = 91
menu_village_infest_bandits_result = 92
menu_village_infestation_removed = 93
menu_center_manage = 94
menu_center_improve = 95
menu_town_bandits_failed = 96
menu_town_bandits_succeeded = 97
menu_village_steal_cattle_confirm = 98
menu_village_steal_cattle = 99
menu_village_take_food_confirm = 100
menu_village_take_food = 101
menu_village_start_attack = 102
menu_village_loot_no_resist = 103
menu_village_loot_complete = 104
menu_village_loot_defeat = 105
menu_village_loot_continue = 106
menu_close = 107
menu_town = 108
menu_cannot_enter_court = 109
menu_lady_visit = 110
menu_town_tournament_lost = 111
menu_town_tournament_won = 112
menu_town_tournament_won_by_another = 113
menu_town_tournament = 114
menu_tournament_withdraw_verify = 115
menu_tournament_bet = 116
menu_tournament_bet_confirm = 117
menu_tournament_participants = 118
menu_collect_taxes = 119
menu_collect_taxes_complete = 120
menu_collect_taxes_rebels_killed = 121
menu_collect_taxes_failed = 122
menu_collect_taxes_revolt_warning = 123
menu_collect_taxes_revolt = 124
menu_train_peasants_against_bandits = 125
menu_train_peasants_against_bandits_ready = 126
menu_train_peasants_against_bandits_training_result = 127
menu_train_peasants_against_bandits_attack = 128
menu_train_peasants_against_bandits_attack_result = 129
menu_train_peasants_against_bandits_success = 130
menu_disembark = 131
menu_ship_reembark = 132
menu_center_reports = 133
menu_price_and_production = 134
menu_town_trade = 135
menu_town_trade_assessment_begin = 136
menu_town_trade_assessment = 137
menu_sneak_into_town_suceeded = 138
menu_sneak_into_town_caught = 139
menu_sneak_into_town_caught_dispersed_guards = 140
menu_sneak_into_town_caught_ran_away = 141
menu_enemy_offer_ransom_for_prisoner = 142
menu_training_ground = 143
menu_training_ground_selection_details_melee_1 = 144
menu_training_ground_selection_details_melee_2 = 145
menu_training_ground_selection_details_mounted = 146
menu_training_ground_selection_details_ranged_1 = 147
menu_training_ground_selection_details_ranged_2 = 148
menu_training_ground_description = 149
menu_training_ground_training_result = 150
menu_marshall_selection_candidate_ask = 151
menu_captivity_avoid_wilderness = 152
menu_captivity_start_wilderness = 153
menu_captivity_start_wilderness_surrender = 154
menu_captivity_start_wilderness_defeat = 155
menu_captivity_start_castle_surrender = 156
menu_captivity_start_castle_defeat = 157
menu_captivity_start_under_siege_defeat = 158
menu_captivity_wilderness_taken_prisoner = 159
menu_captivity_wilderness_check = 160
menu_captivity_end_wilderness_escape = 161
menu_captivity_castle_taken_prisoner = 162
menu_captivity_rescue_lord_taken_prisoner = 163
menu_captivity_castle_check = 164
menu_captivity_end_exchanged_with_prisoner = 165
menu_captivity_end_propose_ransom = 166
menu_captivity_castle_remain = 167
menu_kingdom_army_quest_report_to_army = 168
menu_kingdom_army_quest_messenger = 169
menu_kingdom_army_quest_join_siege_order = 170
menu_kingdom_army_follow_failed = 171
menu_invite_player_to_faction_without_center = 172
menu_invite_player_to_faction = 173
menu_invite_player_to_faction_accepted = 174
menu_question_peace_offer = 175
menu_notification_truce_expired = 176
menu_notification_feast_quest_expired = 177
menu_notification_sortie_possible = 178
menu_notification_casus_belli_expired = 179
menu_notification_lord_defects = 180
menu_notification_treason_indictment = 181
menu_notification_border_incident = 182
menu_notification_player_faction_active = 183
menu_minister_confirm = 184
menu_notification_court_lost = 185
menu_notification_player_faction_deactive = 186
menu_notification_player_wedding_day = 187
menu_notification_player_kingdom_holds_feast = 188
menu_notification_center_under_siege = 189
menu_notification_village_raided = 190
menu_notification_village_raid_started = 191
menu_notification_one_faction_left = 192
menu_notification_oath_renounced_faction_defeated = 193
menu_notification_center_lost = 194
menu_notification_troop_left_players_faction = 195
menu_notification_troop_joined_players_faction = 196
menu_notification_war_declared = 197
menu_notification_peace_declared = 198
menu_notification_faction_defeated = 199
menu_notification_rebels_switched_to_faction = 200
menu_notification_player_should_consult = 201
menu_notification_player_feast_in_progress = 202
menu_notification_lady_requests_visit = 203
menu_garden = 204
menu_kill_local_merchant_begin = 205
menu_debug_alert_from_s65 = 206
menu_auto_return_to_map = 207
menu_bandit_lair = 208
menu_notification_player_faction_political_issue_resolved = 209
menu_notification_player_faction_political_issue_resolved_for_player = 210
menu_start_phase_2_5 = 211
menu_start_phase_3 = 212
menu_start_phase_4 = 213
menu_lost_tavern_duel = 214
menu_establish_court = 215
menu_notification_relieved_as_marshal = 216
menu_survival_wild = 217
menu_land_manage_options = 218
menu_farmer_change_seed_list = 219
