# -*- coding: utf-8 -*-
# Point export_dir to the folder you will be keeping your module
# Make sure you use forward slashes (/) and NOT backward slashes (\)
# import os
# path = os.path.abspath("../..");

## 编译到项目目录
##export_dir = path + "/build/"

# ## 编译到mod中
# export_dir = "D:\\Program Files (x86)\\Mount&Blade Warband\\Modules\\Native\\"
#
# ## 脚本所在目录
# src_dir = path + "/src/smart_module/module_system/"
