track_bogus = 0
track_mount_and_blade_title_screen = 1
track_ambushed_by_neutral = 2
track_ambushed_by_khergit = 3
track_ambushed_by_nord = 4
track_ambushed_by_rhodok = 5
track_ambushed_by_swadian = 6
track_ambushed_by_vaegir = 7
track_ambushed_by_sarranid = 8
track_arena_1 = 9
track_armorer = 10
track_bandit_fight = 11
track_calm_night_1 = 12
track_captured = 13
track_defeated_by_neutral = 14
track_defeated_by_neutral_2 = 15
track_defeated_by_neutral_3 = 16
track_empty_village = 17
track_encounter_hostile_nords = 18
track_escape = 19
track_fight_1 = 20
track_fight_2 = 21
track_fight_3 = 22
track_fight_as_khergit = 23
track_fight_4 = 24
track_fight_as_nord = 25
track_fight_as_rhodok = 26
track_fight_as_vaegir = 27
track_fight_while_mounted_1 = 28
track_fight_while_mounted_2 = 29
track_fight_while_mounted_3 = 30
track_infiltration_khergit = 31
track_killed_by_khergit = 32
track_killed_by_swadian = 33
track_lords_hall_khergit = 34
track_lords_hall_nord = 35
track_lords_hall_swadian = 36
track_lords_hall_rhodok = 37
track_lords_hall_vaegir = 38
track_mounted_snow_terrain_calm = 39
track_neutral_infiltration = 40
track_outdoor_beautiful_land = 41
track_retreat = 42
track_seige_neutral = 43
track_enter_the_juggernaut = 44
track_siege_attempt = 45
track_crazy_battle_music = 46
track_tavern_1 = 47
track_tavern_2 = 48
track_town_neutral = 49
track_town_khergit = 50
track_town_nord = 51
track_town_rhodok = 52
track_town_swadian = 53
track_town_vaegir = 54
track_travel_khergit = 55
track_travel_neutral = 56
track_travel_nord = 57
track_travel_rhodok = 58
track_travel_swadian = 59
track_travel_vaegir = 60
track_travel_sarranid = 61
track_uncertain_homestead = 62
track_hearth_and_brotherhood = 63
track_tragic_village = 64
track_victorious_evil = 65
track_victorious_neutral_1 = 66
track_victorious_neutral_2 = 67
track_victorious_neutral_3 = 68
track_victorious_swadian = 69
track_victorious_vaegir = 70
track_victorious_vaegir_2 = 71
track_wedding = 72
track_coronation = 73


