# from smart_module.smart_modules.center.village.VillageBasicBusiness import initWorkShop, workShopPropertyCount, \
#     productPropertyCount
#
# if __name__ == '__main__':
#     aaa = initWorkShop()