fac_no_faction = 0
fac_commoners = 1
fac_outlaws = 2
fac_neutral = 3
fac_innocents = 4
fac_merchants = 5
fac_dark_knights = 6
fac_culture_1 = 7
fac_culture_2 = 8
fac_culture_3 = 9
fac_culture_4 = 10
fac_culture_5 = 11
fac_culture_6 = 12
fac_player_faction = 13
fac_player_supporters_faction = 14
fac_kingdom_1 = 15
fac_kingdom_2 = 16
fac_kingdom_3 = 17
fac_kingdom_4 = 18
fac_kingdom_5 = 19
fac_kingdom_6 = 20
fac_kingdoms_end = 21
fac_robber_knights = 22
fac_khergits = 23
fac_black_khergits = 24
fac_manhunters = 25
fac_deserters = 26
fac_mountain_bandits = 27
fac_forest_bandits = 28
fac_undeads = 29
fac_slavers = 30
fac_peasant_rebels = 31
fac_noble_refugees = 32


