###################################################
# header_quests.py
# This file contains declarations for quests
# DO NOT EDIT THIS FILE!
###################################################

from smart_module.module_system.header_common import *

#quest flags
qf_show_progression      = 0x00000001
qf_random_quest          = 0x00000002

