pt_none = 0
pt_rescued_prisoners = 1
pt_enemy = 2
pt_hero_party = 3
pt_village_defenders = 4
pt_cattle_herd = 5
pt_looters = 6
pt_manhunters = 7
pt_steppe_bandits = 8
pt_taiga_bandits = 9
pt_desert_bandits = 10
pt_forest_bandits = 11
pt_mountain_bandits = 12
pt_sea_raiders = 13
pt_deserters = 14
pt_merchant_caravan = 15
pt_troublesome_bandits = 16
pt_bandits_awaiting_ransom = 17
pt_kidnapped_girl = 18
pt_village_farmers = 19
pt_spy_partners = 20
pt_runaway_serfs = 21
pt_spy = 22
pt_sacrificed_messenger = 23
pt_forager_party = 24
pt_scout_party = 25
pt_patrol_party = 26
pt_messenger_party = 27
pt_raider_party = 28
pt_raider_captives = 29
pt_kingdom_caravan_party = 30
pt_prisoner_train_party = 31
pt_default_prisoners = 32
pt_routed_warriors = 33
pt_center_reinforcements = 34
pt_kingdom_hero_party = 35
pt_kingdom_1_reinforcements_a = 36
pt_kingdom_1_reinforcements_b = 37
pt_kingdom_1_reinforcements_c = 38
pt_kingdom_2_reinforcements_a = 39
pt_kingdom_2_reinforcements_b = 40
pt_kingdom_2_reinforcements_c = 41
pt_kingdom_3_reinforcements_a = 42
pt_kingdom_3_reinforcements_b = 43
pt_kingdom_3_reinforcements_c = 44
pt_kingdom_4_reinforcements_a = 45
pt_kingdom_4_reinforcements_b = 46
pt_kingdom_4_reinforcements_c = 47
pt_kingdom_5_reinforcements_a = 48
pt_kingdom_5_reinforcements_b = 49
pt_kingdom_5_reinforcements_c = 50
pt_kingdom_6_reinforcements_a = 51
pt_kingdom_6_reinforcements_b = 52
pt_kingdom_6_reinforcements_c = 53
pt_steppe_bandit_lair = 54
pt_taiga_bandit_lair = 55
pt_desert_bandit_lair = 56
pt_forest_bandit_lair = 57
pt_mountain_bandit_lair = 58
pt_sea_raider_lair = 59
pt_looter_lair = 60
pt_bandit_lair_templates_end = 61
pt_leaded_looters = 62
