spr_invalid_object = 0
spr_inventory = 1
spr_empty = 2
spr_chest_a = 3
spr_container_small_chest = 4
spr_container_chest_b = 5
spr_container_chest_c = 6
spr_player_chest = 7
spr_locked_player_chest = 8
spr_light_sun = 9
spr_light = 10
spr_light_red = 11
spr_light_night = 12
spr_torch = 13
spr_torch_night = 14
spr_barrier_20m = 15
spr_barrier_16m = 16
spr_barrier_8m = 17
spr_barrier_4m = 18
spr_barrier_2m = 19
spr_exit_4m = 20
spr_exit_8m = 21
spr_exit_16m = 22
spr_ai_limiter_2m = 23
spr_ai_limiter_4m = 24
spr_ai_limiter_8m = 25
spr_ai_limiter_16m = 26
spr_Shield = 27
spr_shelves = 28
spr_table_tavern = 29
spr_table_castle_a = 30
spr_chair_castle_a = 31
spr_pillow_a = 32
spr_pillow_b = 33
spr_pillow_c = 34
spr_interior_castle_g_square_keep_b = 35
spr_carpet_with_pillows_a = 36
spr_carpet_with_pillows_b = 37
spr_table_round_a = 38
spr_table_round_b = 39
spr_fireplace_b = 40
spr_fireplace_c = 41
spr_sofa_a = 42
spr_sofa_b = 43
spr_ewer_a = 44
spr_end_table_a = 45
spr_fake_houses_steppe_a = 46
spr_fake_houses_steppe_b = 47
spr_fake_houses_steppe_c = 48
spr_boat_destroy = 49
spr_destroy_house_a = 50
spr_destroy_house_b = 51
spr_destroy_house_c = 52
spr_destroy_heap = 53
spr_destroy_castle_a = 54
spr_destroy_castle_b = 55
spr_destroy_castle_c = 56
spr_destroy_castle_d = 57
spr_destroy_windmill = 58
spr_destroy_tree_a = 59
spr_destroy_tree_b = 60
spr_destroy_bridge_a = 61
spr_destroy_bridge_b = 62
spr_catapult = 63
spr_catapult_destructible = 64
spr_broom = 65
spr_garlic = 66
spr_garlic_b = 67
spr_destroy_a = 68
spr_destroy_b = 69
spr_bridge_wooden = 70
spr_bridge_wooden_snowy = 71
spr_grave_a = 72
spr_village_house_e = 73
spr_village_house_f = 74
spr_village_house_g = 75
spr_village_house_h = 76
spr_village_house_i = 77
spr_village_house_j = 78
spr_village_wall_a = 79
spr_village_wall_b = 80
spr_village_snowy_house_a = 81
spr_village_snowy_house_b = 82
spr_village_snowy_house_c = 83
spr_village_snowy_house_d = 84
spr_village_snowy_house_e = 85
spr_village_snowy_house_f = 86
spr_town_house_steppe_a = 87
spr_town_house_steppe_b = 88
spr_town_house_steppe_c = 89
spr_town_house_steppe_d = 90
spr_town_house_steppe_e = 91
spr_town_house_steppe_f = 92
spr_town_house_steppe_g = 93
spr_town_house_steppe_h = 94
spr_town_house_steppe_i = 95
spr_carpet_a = 96
spr_carpet_b = 97
spr_carpet_c = 98
spr_carpet_d = 99
spr_carpet_e = 100
spr_carpet_f = 101
spr_awning_a = 102
spr_awning_b = 103
spr_awning_c = 104
spr_awning_long = 105
spr_awning_long_b = 106
spr_awning_d = 107
spr_ship = 108
spr_ship_b = 109
spr_ship_c = 110
spr_ship_d = 111
spr_snowy_barrel_a = 112
spr_snowy_fence = 113
spr_snowy_wood_heap = 114
spr_village_snowy_stable_a = 115
spr_village_straw_house_a = 116
spr_village_stable_a = 117
spr_village_shed_a = 118
spr_village_shed_b = 119
spr_dungeon_door_cell_a = 120
spr_dungeon_door_cell_b = 121
spr_dungeon_door_entry_a = 122
spr_dungeon_door_entry_b = 123
spr_dungeon_door_entry_c = 124
spr_dungeon_door_direction_a = 125
spr_dungeon_door_direction_b = 126
spr_dungeon_door_stairs_a = 127
spr_dungeon_door_stairs_b = 128
spr_dungeon_bed_a = 129
spr_dungeon_bed_b = 130
spr_torture_tool_a = 131
spr_torture_tool_b = 132
spr_torture_tool_c = 133
spr_skeleton_head = 134
spr_skeleton_bone = 135
spr_skeleton_a = 136
spr_dungeon_stairs_a = 137
spr_dungeon_stairs_b = 138
spr_dungeon_torture_room_a = 139
spr_dungeon_entry_a = 140
spr_dungeon_entry_b = 141
spr_dungeon_entry_c = 142
spr_dungeon_cell_a = 143
spr_dungeon_cell_b = 144
spr_dungeon_cell_c = 145
spr_dungeon_corridor_a = 146
spr_dungeon_corridor_b = 147
spr_dungeon_corridor_c = 148
spr_dungeon_corridor_d = 149
spr_dungeon_direction_a = 150
spr_dungeon_direction_b = 151
spr_dungeon_room_a = 152
spr_dungeon_tower_stairs_a = 153
spr_dungeon_tower_cell_a = 154
spr_tunnel_a = 155
spr_tunnel_salt = 156
spr_salt_a = 157
spr_door_destructible = 158
spr_tutorial_door_a = 159
spr_tutorial_door_b = 160
spr_tutorial_flag_yellow = 161
spr_tutorial_flag_red = 162
spr_tutorial_flag_blue = 163
spr_interior_prison_a = 164
spr_interior_prison_b = 165
spr_interior_prison_cell_a = 166
spr_interior_prison_d = 167
spr_arena_archery_target_a = 168
spr_archery_butt_a = 169
spr_archery_target_with_hit_a = 170
spr_dummy_a = 171
spr_band_a = 172
spr_arena_sign = 173
spr_castle_h_battlement_a = 174
spr_castle_h_battlement_b = 175
spr_castle_h_battlement_c = 176
spr_castle_h_battlement_a2 = 177
spr_castle_h_battlement_b2 = 178
spr_castle_h_corner_a = 179
spr_castle_h_corner_c = 180
spr_castle_h_stairs_a = 181
spr_castle_h_stairs_b = 182
spr_castle_h_gatehouse_a = 183
spr_castle_h_keep_a = 184
spr_castle_h_keep_b = 185
spr_castle_h_house_a = 186
spr_castle_h_house_b = 187
spr_castle_h_house_c = 188
spr_castle_h_battlement_barrier = 189
spr_full_keep_b = 190
spr_castle_f_keep_a = 191
spr_castle_f_battlement_a = 192
spr_castle_f_battlement_a_destroyed = 193
spr_castle_f_battlement_b = 194
spr_castle_f_battlement_c = 195
spr_castle_f_battlement_d = 196
spr_castle_f_battlement_e = 197
spr_castle_f_sally_port_elevation = 198
spr_castle_f_battlement_corner_a = 199
spr_castle_f_battlement_corner_b = 200
spr_castle_f_battlement_corner_c = 201
spr_castle_f_door_a = 202
spr_castle_f_doors_top_a = 203
spr_castle_f_sally_door_a = 204
spr_castle_f_stairs_a = 205
spr_castle_f_tower_a = 206
spr_castle_f_wall_stairs_a = 207
spr_castle_f_wall_stairs_b = 208
spr_castle_f_wall_way_a = 209
spr_castle_f_wall_way_b = 210
spr_castle_f_gatehouse_a = 211
spr_castle_g_battlement_a = 212
spr_castle_g_battlement_a1 = 213
spr_castle_g_battlement_c = 214
spr_castle_g_corner_a = 215
spr_castle_g_corner_c = 216
spr_castle_g_tower_a = 217
spr_castle_g_gate_house = 218
spr_castle_g_gate_house_door_a = 219
spr_castle_g_gate_house_door_b = 220
spr_castle_g_square_keep_a = 221
spr_castle_i_battlement_a = 222
spr_castle_i_battlement_a1 = 223
spr_castle_i_battlement_c = 224
spr_castle_i_corner_a = 225
spr_castle_i_corner_c = 226
spr_castle_i_tower_a = 227
spr_castle_i_gate_house = 228
spr_castle_i_gate_house_door_a = 229
spr_castle_i_gate_house_door_b = 230
spr_castle_i_square_keep_a = 231
spr_mosque_a = 232
spr_stone_minaret_a = 233
spr_stone_house_a = 234
spr_stone_house_b = 235
spr_stone_house_c = 236
spr_stone_house_d = 237
spr_stone_house_e = 238
spr_stone_house_f = 239
spr_banner_pole = 240
spr_custom_banner_01 = 241
spr_custom_banner_02 = 242
spr_banner_a = 243
spr_banner_b = 244
spr_banner_c = 245
spr_banner_d = 246
spr_banner_e = 247
spr_banner_f = 248
spr_banner_g = 249
spr_banner_h = 250
spr_banner_i = 251
spr_banner_j = 252
spr_banner_k = 253
spr_banner_l = 254
spr_banner_m = 255
spr_banner_n = 256
spr_banner_o = 257
spr_banner_p = 258
spr_banner_q = 259
spr_banner_r = 260
spr_banner_s = 261
spr_banner_t = 262
spr_banner_u = 263
spr_banner_ba = 264
spr_banner_bb = 265
spr_banner_bc = 266
spr_banner_bd = 267
spr_banner_be = 268
spr_banner_bf = 269
spr_banner_bg = 270
spr_banner_bh = 271
spr_banner_bi = 272
spr_banner_bj = 273
spr_banner_bk = 274
spr_banner_bl = 275
spr_banner_bm = 276
spr_banner_bn = 277
spr_banner_bo = 278
spr_banner_bp = 279
spr_banner_bq = 280
spr_banner_br = 281
spr_banner_bs = 282
spr_banner_bt = 283
spr_banner_bu = 284
spr_banner_ca = 285
spr_banner_cb = 286
spr_banner_cc = 287
spr_banner_cd = 288
spr_banner_ce = 289
spr_banner_cf = 290
spr_banner_cg = 291
spr_banner_ch = 292
spr_banner_ci = 293
spr_banner_cj = 294
spr_banner_ck = 295
spr_banner_cl = 296
spr_banner_cm = 297
spr_banner_cn = 298
spr_banner_co = 299
spr_banner_cp = 300
spr_banner_cq = 301
spr_banner_cr = 302
spr_banner_cs = 303
spr_banner_ct = 304
spr_banner_cu = 305
spr_banner_da = 306
spr_banner_db = 307
spr_banner_dc = 308
spr_banner_dd = 309
spr_banner_de = 310
spr_banner_df = 311
spr_banner_dg = 312
spr_banner_dh = 313
spr_banner_di = 314
spr_banner_dj = 315
spr_banner_dk = 316
spr_banner_dl = 317
spr_banner_dm = 318
spr_banner_dn = 319
spr_banner_do = 320
spr_banner_dp = 321
spr_banner_dq = 322
spr_banner_dr = 323
spr_banner_ds = 324
spr_banner_dt = 325
spr_banner_du = 326
spr_banner_ea = 327
spr_banner_eb = 328
spr_banner_ec = 329
spr_banner_ed = 330
spr_banner_ee = 331
spr_banner_ef = 332
spr_banner_eg = 333
spr_banner_eh = 334
spr_banner_ei = 335
spr_banner_ej = 336
spr_banner_ek = 337
spr_banner_el = 338
spr_banner_em = 339
spr_banner_en = 340
spr_banner_eo = 341
spr_banner_ep = 342
spr_banner_eq = 343
spr_banner_er = 344
spr_banner_es = 345
spr_banner_et = 346
spr_banner_eu = 347
spr_banner_f01 = 348
spr_banner_f02 = 349
spr_banner_f03 = 350
spr_banner_f04 = 351
spr_banner_f05 = 352
spr_banner_f06 = 353
spr_banner_f07 = 354
spr_banner_f08 = 355
spr_banner_f09 = 356
spr_banner_f10 = 357
spr_banner_f11 = 358
spr_banner_f12 = 359
spr_banner_f13 = 360
spr_banner_f14 = 361
spr_banner_f15 = 362
spr_banner_f16 = 363
spr_banner_f17 = 364
spr_banner_f18 = 365
spr_banner_f19 = 366
spr_banner_f20 = 367
spr_banner_g01 = 368
spr_banner_g02 = 369
spr_banner_g03 = 370
spr_banner_g04 = 371
spr_banner_g05 = 372
spr_banner_g06 = 373
spr_banner_g07 = 374
spr_banner_g08 = 375
spr_banner_g09 = 376
spr_banner_g10 = 377
spr_banner_kingdom_a = 378
spr_banner_kingdom_b = 379
spr_banner_kingdom_c = 380
spr_banner_kingdom_d = 381
spr_banner_kingdom_e = 382
spr_banner_kingdom_f = 383
spr_banner_f21 = 384
spr_tavern_chair_a = 385
spr_tavern_chair_b = 386
spr_tavern_table_a = 387
spr_tavern_table_b = 388
spr_fireplace_a = 389
spr_barrel = 390
spr_bench_tavern = 391
spr_bench_tavern_b = 392
spr_bowl_wood = 393
spr_chandelier_table = 394
spr_chandelier_tavern = 395
spr_chest_gothic = 396
spr_chest_b = 397
spr_chest_c = 398
spr_counter_tavern = 399
spr_cup = 400
spr_dish_metal = 401
spr_gothic_chair = 402
spr_gothic_stool = 403
spr_grate = 404
spr_jug = 405
spr_potlamp = 406
spr_weapon_rack = 407
spr_weapon_rack_big = 408
spr_tavern_barrel = 409
spr_tavern_barrel_b = 410
spr_merchant_sign = 411
spr_tavern_sign = 412
spr_sack = 413
spr_skull_a = 414
spr_skull_b = 415
spr_skull_c = 416
spr_skull_d = 417
spr_skeleton_cow = 418
spr_cupboard_a = 419
spr_box_a = 420
spr_bucket_a = 421
spr_straw_a = 422
spr_straw_b = 423
spr_straw_c = 424
spr_cloth_a = 425
spr_cloth_b = 426
spr_mat_a = 427
spr_mat_b = 428
spr_mat_c = 429
spr_mat_d = 430
spr_wood_a = 431
spr_wood_b = 432
spr_wood_heap = 433
spr_wood_heap_b = 434
spr_water_well_a = 435
spr_net_a = 436
spr_net_b = 437
spr_meat_hook = 438
spr_cooking_pole = 439
spr_bowl_a = 440
spr_bucket_b = 441
spr_washtub_a = 442
spr_washtub_b = 443
spr_table_trunk_a = 444
spr_chair_trunk_a = 445
spr_chair_trunk_b = 446
spr_chair_trunk_c = 447
spr_table_trestle_long = 448
spr_table_trestle_small = 449
spr_chair_trestle = 450
spr_wheel = 451
spr_ladder = 452
spr_cart = 453
spr_village_stand = 454
spr_wooden_stand = 455
spr_table_small = 456
spr_table_small_b = 457
spr_small_timber_frame_house_a = 458
spr_timber_frame_house_b = 459
spr_timber_frame_house_c = 460
spr_timber_frame_extension_a = 461
spr_timber_frame_extension_b = 462
spr_stone_stairs_a = 463
spr_stone_stairs_b = 464
spr_railing_a = 465
spr_side_building_a = 466
spr_battlement_a = 467
spr_battlement_a_destroyed = 468
spr_round_tower_a = 469
spr_small_round_tower_a = 470
spr_small_round_tower_roof_a = 471
spr_square_keep_a = 472
spr_square_tower_roof_a = 473
spr_gate_house_a = 474
spr_gate_house_b = 475
spr_small_wall_a = 476
spr_small_wall_b = 477
spr_small_wall_c = 478
spr_small_wall_c_destroy = 479
spr_small_wall_d = 480
spr_small_wall_e = 481
spr_small_wall_f = 482
spr_small_wall_f2 = 483
spr_town_house_a = 484
spr_town_house_b = 485
spr_town_house_c = 486
spr_town_house_d = 487
spr_town_house_e = 488
spr_town_house_f = 489
spr_town_house_g = 490
spr_town_house_h = 491
spr_town_house_i = 492
spr_town_house_j = 493
spr_town_house_l = 494
spr_town_house_m = 495
spr_town_house_n = 496
spr_town_house_o = 497
spr_town_house_p = 498
spr_town_house_q = 499
spr_passage_house_a = 500
spr_passage_house_b = 501
spr_passage_house_c = 502
spr_passage_house_d = 503
spr_passage_house_c_door = 504
spr_house_extension_a = 505
spr_house_extension_b = 506
spr_house_extension_c = 507
spr_house_extension_d = 508
spr_house_extension_e = 509
spr_house_extension_f = 510
spr_house_extension_f2 = 511
spr_house_extension_g = 512
spr_house_extension_g2 = 513
spr_house_extension_h = 514
spr_house_extension_i = 515
spr_house_roof_door = 516
spr_door_extension_a = 517
spr_stairs_arch_a = 518
spr_town_house_r = 519
spr_town_house_s = 520
spr_town_house_t = 521
spr_town_house_u = 522
spr_town_house_v = 523
spr_town_house_w = 524
spr_town_house_y = 525
spr_town_house_z = 526
spr_town_house_za = 527
spr_windmill = 528
spr_windmill_fan_turning = 529
spr_windmill_fan = 530
spr_fake_house_a = 531
spr_fake_house_b = 532
spr_fake_house_c = 533
spr_fake_house_d = 534
spr_fake_house_e = 535
spr_fake_house_f = 536
spr_fake_house_snowy_a = 537
spr_fake_house_snowy_b = 538
spr_fake_house_snowy_c = 539
spr_fake_house_snowy_d = 540
spr_fake_house_far_a = 541
spr_fake_house_far_b = 542
spr_fake_house_far_c = 543
spr_fake_house_far_d = 544
spr_fake_house_far_e = 545
spr_fake_house_far_f = 546
spr_fake_house_far_snowycrude_a = 547
spr_fake_house_far_snowy_b = 548
spr_fake_house_far_snowy_c = 549
spr_fake_house_far_snowy_d = 550
spr_earth_wall_a = 551
spr_earth_wall_a2 = 552
spr_earth_wall_b = 553
spr_earth_wall_b2 = 554
spr_earth_stairs_a = 555
spr_earth_stairs_b = 556
spr_earth_tower_small_a = 557
spr_earth_gate_house_a = 558
spr_earth_gate_a = 559
spr_earth_square_keep_a = 560
spr_earth_house_a = 561
spr_earth_house_b = 562
spr_earth_house_c = 563
spr_earth_house_d = 564
spr_village_steppe_a = 565
spr_village_steppe_b = 566
spr_village_steppe_c = 567
spr_village_steppe_d = 568
spr_village_steppe_e = 569
spr_village_steppe_f = 570
spr_town_house_aa = 571
spr_snowy_house_a = 572
spr_snowy_house_b = 573
spr_snowy_house_c = 574
spr_snowy_house_d = 575
spr_snowy_house_e = 576
spr_snowy_house_f = 577
spr_snowy_house_g = 578
spr_snowy_house_h = 579
spr_snowy_house_i = 580
spr_snowy_wall_a = 581
spr_snowy_stand = 582
spr_snowy_heap_a = 583
spr_snowy_trunks_a = 584
spr_snowy_castle_tower_a = 585
spr_snowy_castle_battlement_a = 586
spr_snowy_castle_battlement_a_destroyed = 587
spr_snowy_castle_battlement_b = 588
spr_snowy_castle_battlement_corner_a = 589
spr_snowy_castle_battlement_corner_b = 590
spr_snowy_castle_battlement_corner_c = 591
spr_snowy_castle_battlement_stairs_a = 592
spr_snowy_castle_battlement_stairs_b = 593
spr_snowy_castle_gate_house_a = 594
spr_snowy_castle_round_tower_a = 595
spr_snowy_castle_square_keep_a = 596
spr_snowy_castle_stairs_a = 597
spr_square_keep_b = 598
spr_square_keep_c = 599
spr_square_keep_d = 600
spr_square_keep_e = 601
spr_square_keep_f = 602
spr_square_extension_a = 603
spr_square_stairs_a = 604
spr_castle_courtyard_house_a = 605
spr_castle_courtyard_house_b = 606
spr_castle_courtyard_house_c = 607
spr_castle_courtyard_a = 608
spr_gatehouse_b = 609
spr_castle_gaillard = 610
spr_castle_e_battlement_a = 611
spr_castle_e_battlement_c = 612
spr_castle_e_battlement_a_destroyed = 613
spr_castle_e_sally_door_a = 614
spr_castle_e_corner = 615
spr_castle_e_corner_b = 616
spr_castle_e_corner_c = 617
spr_castle_e_stairs_a = 618
spr_castle_e_tower = 619
spr_castle_e_gate_house_a = 620
spr_castle_e_keep_a = 621
spr_stand_thatched = 622
spr_stand_cloth = 623
spr_castle_e_house_a = 624
spr_castle_e_house_b = 625
spr_arena_block_a = 626
spr_arena_block_b = 627
spr_arena_block_c = 628
spr_arena_block_d = 629
spr_arena_block_e = 630
spr_arena_block_f = 631
spr_arena_block_g = 632
spr_arena_block_h = 633
spr_arena_block_i = 634
spr_arena_block_j = 635
spr_arena_block_j_awning = 636
spr_arena_palisade_a = 637
spr_arena_wall_a = 638
spr_arena_wall_b = 639
spr_arena_barrier_a = 640
spr_arena_barrier_b = 641
spr_arena_barrier_c = 642
spr_arena_tower_a = 643
spr_arena_tower_b = 644
spr_arena_tower_c = 645
spr_arena_spectator_a = 646
spr_arena_spectator_b = 647
spr_arena_spectator_c = 648
spr_arena_spectator_sitting_a = 649
spr_arena_spectator_sitting_b = 650
spr_arena_spectator_sitting_c = 651
spr_courtyard_gate_a = 652
spr_courtyard_gate_b = 653
spr_courtyard_gate_c = 654
spr_courtyard_gate_snowy = 655
spr_castle_tower_a = 656
spr_castle_battlement_a = 657
spr_castle_battlement_b = 658
spr_castle_battlement_c = 659
spr_castle_battlement_a_destroyed = 660
spr_castle_battlement_b_destroyed = 661
spr_castle_battlement_corner_a = 662
spr_castle_battlement_corner_b = 663
spr_castle_battlement_corner_c = 664
spr_castle_battlement_stairs_a = 665
spr_castle_battlement_stairs_b = 666
spr_castle_gate_house_a = 667
spr_castle_round_tower_a = 668
spr_castle_square_keep_a = 669
spr_castle_stairs_a = 670
spr_castle_drawbridge_open = 671
spr_castle_drawbridge_closed = 672
spr_spike_group_a = 673
spr_spike_a = 674
spr_belfry_a = 675
spr_belfry_b = 676
spr_belfry_b_platform_a = 677
spr_belfry_old = 678
spr_belfry_platform_a = 679
spr_belfry_platform_b = 680
spr_belfry_platform_old = 681
spr_belfry_wheel = 682
spr_belfry_wheel_old = 683
spr_mangonel = 684
spr_trebuchet_old = 685
spr_trebuchet_new = 686
spr_trebuchet_destructible = 687
spr_stone_ball = 688
spr_village_house_a = 689
spr_village_house_b = 690
spr_village_house_c = 691
spr_village_house_d = 692
spr_farm_house_a = 693
spr_farm_house_b = 694
spr_farm_house_c = 695
spr_mountain_house_a = 696
spr_mountain_house_b = 697
spr_village_hut_a = 698
spr_crude_fence = 699
spr_crude_fence_small = 700
spr_crude_fence_small_b = 701
spr_ramp_12m = 702
spr_ramp_14m = 703
spr_siege_ladder_6m = 704
spr_siege_ladder_8m = 705
spr_siege_ladder_10m = 706
spr_siege_ladder_12m = 707
spr_siege_ladder_14m = 708
spr_siege_ladder_move_6m = 709
spr_siege_ladder_move_8m = 710
spr_siege_ladder_move_10m = 711
spr_siege_ladder_move_12m = 712
spr_siege_ladder_move_14m = 713
spr_portcullis = 714
spr_bed_a = 715
spr_bed_b = 716
spr_bed_c = 717
spr_bed_d = 718
spr_bed_e = 719
spr_bed_f = 720
spr_towngate_door_left = 721
spr_towngate_door_right = 722
spr_towngate_rectangle_door_left = 723
spr_towngate_rectangle_door_right = 724
spr_door_screen = 725
spr_door_a = 726
spr_door_b = 727
spr_door_c = 728
spr_door_d = 729
spr_tavern_door_a = 730
spr_tavern_door_b = 731
spr_door_e_left = 732
spr_door_e_right = 733
spr_door_f_left = 734
spr_door_f_right = 735
spr_door_h_left = 736
spr_door_h_right = 737
spr_draw_bridge_a = 738
spr_chain_1m = 739
spr_chain_2m = 740
spr_chain_5m = 741
spr_chain_10m = 742
spr_bridge_modular_a = 743
spr_bridge_modular_b = 744
spr_church_a = 745
spr_church_tower_a = 746
spr_stone_step_a = 747
spr_stone_step_b = 748
spr_stone_step_c = 749
spr_stone_heap = 750
spr_stone_heap_b = 751
spr_panel_door_a = 752
spr_panel_door_b = 753
spr_smoke_stain = 754
spr_brazier_with_fire = 755
spr_cooking_fire = 756
spr_cauldron_a = 757
spr_fry_pan_a = 758
spr_tripod_cauldron_a = 759
spr_tripod_cauldron_b = 760
spr_open_stable_a = 761
spr_open_stable_b = 762
spr_plate_a = 763
spr_plate_b = 764
spr_plate_c = 765
spr_lettuce = 766
spr_hanger = 767
spr_knife_eating = 768
spr_colander = 769
spr_ladle = 770
spr_spoon = 771
spr_skewer = 772
spr_grape_a = 773
spr_grape_b = 774
spr_apple_a = 775
spr_apple_b = 776
spr_maize_a = 777
spr_maize_b = 778
spr_cabbage = 779
spr_flax_bundle = 780
spr_olive_plane = 781
spr_grapes_plane = 782
spr_date_fruit_plane = 783
spr_bowl = 784
spr_bowl_small = 785
spr_dye_blue = 786
spr_dye_red = 787
spr_dye_yellow = 788
spr_basket = 789
spr_basket_big = 790
spr_basket_big_green = 791
spr_leatherwork_frame = 792
spr_cabbage_b = 793
spr_bean = 794
spr_basket_a = 795
spr_feeding_trough_a = 796
spr_marrow_a = 797
spr_marrow_b = 798
spr_squash_plant = 799
spr_gatehouse_new_a = 800
spr_gatehouse_new_b = 801
spr_gatehouse_new_snowy_a = 802
spr_winch = 803
spr_winch_b = 804
spr_drawbridge = 805
spr_gatehouse_door_left = 806
spr_gatehouse_door_right = 807
spr_cheese_a = 808
spr_cheese_b = 809
spr_cheese_slice_a = 810
spr_bread_a = 811
spr_bread_b = 812
spr_bread_slice_a = 813
spr_fish_a = 814
spr_fish_roasted_a = 815
spr_chicken_roasted = 816
spr_food_steam = 817
spr_city_smoke = 818
spr_city_fire_fly_night = 819
spr_city_fly_day = 820
spr_flue_smoke_tall = 821
spr_flue_smoke_short = 822
spr_moon_beam = 823
spr_fire_small = 824
spr_fire_big = 825
spr_battle_field_smoke = 826
spr_Village_fire_big = 827
spr_candle_a = 828
spr_candle_b = 829
spr_candle_c = 830
spr_lamp_a = 831
spr_lamp_b = 832
spr_hook_a = 833
spr_window_night = 834
spr_fried_pig = 835
spr_village_oven = 836
spr_dungeon_water_drops = 837
spr_shadow_circle_1 = 838
spr_shadow_circle_2 = 839
spr_shadow_square_1 = 840
spr_shadow_square_2 = 841
spr_wheelbarrow = 842
spr_gourd = 843
spr_gourd_spike = 844
spr_obstacle_fence_1 = 845
spr_obstacle_fallen_tree_a = 846
spr_obstacle_fallen_tree_b = 847
spr_siege_wall_a = 848
spr_siege_large_shield_a = 849
spr_granary_a = 850
spr_small_wall_connect_a = 851
spr_full_stable_a = 852
spr_full_stable_b = 853
spr_full_stable_c = 854
spr_full_stable_d = 855
spr_arabian_house_a = 856
spr_arabian_house_b = 857
spr_arabian_house_c = 858
spr_arabian_house_d = 859
spr_arabian_house_e = 860
spr_arabian_house_f = 861
spr_arabian_house_g = 862
spr_arabian_house_h = 863
spr_arabian_house_i = 864
spr_arabian_square_keep_a = 865
spr_arabian_passage_house_a = 866
spr_arabian_wall_a = 867
spr_arabian_wall_b = 868
spr_arabian_ground_a = 869
spr_arabian_parterre_a = 870
spr_well_shaft = 871
spr_horse_mill = 872
spr_horse_mill_collar = 873
spr_arabian_stable = 874
spr_arabian_tent = 875
spr_arabian_tent_b = 876
spr_desert_plant_a = 877
spr_arabian_castle_battlement_a = 878
spr_arabian_castle_battlement_b_destroyed = 879
spr_arabian_castle_battlement_c = 880
spr_arabian_castle_battlement_d = 881
spr_arabian_castle_corner_a = 882
spr_arabian_castle_stairs = 883
spr_arabian_castle_stairs_b = 884
spr_arabian_castle_stairs_c = 885
spr_arabian_castle_battlement_section_a = 886
spr_arabian_castle_gate_house_a = 887
spr_arabian_castle_house_a = 888
spr_arabian_castle_house_b = 889
spr_arabian_castle_keep_a = 890
spr_arabian_house_a2 = 891
spr_arabian_village_house_a = 892
spr_arabian_village_house_b = 893
spr_arabian_village_house_c = 894
spr_arabian_village_house_d = 895
spr_arabian_village_stable = 896
spr_arabian_village_hut = 897
spr_arabian_village_stairs = 898
spr_tree_a01 = 899
spr_stairs_a = 900
spr_headquarters_flag_red = 901
spr_headquarters_flag_blue = 902
spr_headquarters_flag_gray = 903
spr_headquarters_flag_red_code_only = 904
spr_headquarters_flag_blue_code_only = 905
spr_headquarters_flag_gray_code_only = 906
spr_headquarters_pole_code_only = 907
spr_headquarters_flag_swadian = 908
spr_headquarters_flag_vaegir = 909
spr_headquarters_flag_khergit = 910
spr_headquarters_flag_nord = 911
spr_headquarters_flag_rhodok = 912
spr_headquarters_flag_sarranid = 913
spr_glow_a = 914
spr_glow_b = 915
spr_arabian_castle_corner_b = 916
spr_dummy_a_undestructable = 917
spr_cave_entrance_1 = 918
spr_pointer_arrow = 919
spr_fireplace_d_interior = 920
spr_ship_sail_off = 921
spr_ship_sail_off_b = 922
spr_ship_c_sail_off = 923
spr_ramp_small_a = 924
spr_castle_g_battlement_b = 925
spr_box_a_dynamic = 926
spr_desert_field = 927
spr_water_river = 928
spr_viking_house_a = 929
spr_viking_house_b = 930
spr_viking_house_c = 931
spr_viking_house_d = 932
spr_viking_house_e = 933
spr_viking_stable_a = 934
spr_viking_keep = 935
spr_viking_house_c_destroy = 936
spr_viking_house_b_destroy = 937
spr_harbour_a = 938
spr_sea_foam_a = 939
spr_viking_keep_destroy = 940
spr_viking_keep_destroy_door = 941
spr_earth_tower_small_b = 942
spr_earth_gate_house_b = 943
spr_earth_tower_a = 944
spr_earth_stairs_c = 945
spr_earth_sally_gate_left = 946
spr_earth_sally_gate_right = 947
spr_barrier_box = 948
spr_barrier_capsule = 949
spr_barrier_cone = 950
spr_barrier_sphere = 951
spr_viking_keep_destroy_sally_door_right = 952
spr_viking_keep_destroy_sally_door_left = 953
spr_castle_f_door_b = 954
spr_ctf_flag_kingdom_1 = 955
spr_ctf_flag_kingdom_2 = 956
spr_ctf_flag_kingdom_3 = 957
spr_ctf_flag_kingdom_4 = 958
spr_ctf_flag_kingdom_5 = 959
spr_ctf_flag_kingdom_6 = 960
spr_ctf_flag_kingdom_7 = 961
spr_headquarters_flag_rebel = 962
spr_arabian_lighthouse_a = 963
spr_arabian_ramp_a = 964
spr_arabian_ramp_b = 965
spr_winery_interior = 966
spr_winery_barrel_shelf = 967
spr_winery_wall_shelf = 968
spr_winery_huge_barrel = 969
spr_winery_wine_press = 970
spr_winery_middle_barrel = 971
spr_winery_wine_cart_small_loaded = 972
spr_winery_wine_cart_small_empty = 973
spr_winery_wine_cart_empty = 974
spr_winery_wine_cart_loaded = 975
spr_weavery_interior = 976
spr_weavery_loom_a = 977
spr_weavery_spinning_wheel = 978
spr_mill_interior = 979
spr_mill_flour_sack = 980
spr_mill_flour_sack_desk_a = 981
spr_mill_flour_sack_desk_b = 982
spr_smithy_interior = 983
spr_smithy_grindstone_wheel = 984
spr_smithy_forge_bellows = 985
spr_smithy_forge = 986
spr_smithy_anvil = 987
spr_tannery_hide_a = 988
spr_tannery_hide_b = 989
spr_tannery_pools_a = 990
spr_tannery_pools_b = 991
spr_fountain = 992
spr_rhodok_houses_a = 993
spr_rhodok_houses_b = 994
spr_rhodok_houses_c = 995
spr_rhodok_houses_d = 996
spr_rhodok_houses_e = 997
spr_rhodok_house_passage_a = 998
spr_bridge_b = 999
spr_brewery_pool = 1000
spr_brewery_big_bucket = 1001
spr_brewery_interior = 1002
spr_brewery_bucket_platform_a = 1003
spr_brewery_bucket_platform_b = 1004
spr_weavery_dye_pool_r = 1005
spr_weavery_dye_pool_y = 1006
spr_weavery_dye_pool_b = 1007
spr_weavery_dye_pool_p = 1008
spr_weavery_dye_pool_g = 1009
spr_oil_press_interior = 1010
spr_city_swad_01 = 1011
spr_city_swad_02 = 1012
spr_city_swad_03 = 1013
spr_city_swad_04 = 1014
spr_city_swad_passage_01 = 1015
spr_city_swad_05 = 1016
spr_arena_block_j_a = 1017
spr_arena_underway_a = 1018
spr_arena_circle_a = 1019
spr_rope_bridge_15m = 1020
spr_tree_house_a = 1021
spr_tree_house_guard_a = 1022
spr_tree_house_guard_b = 1023
spr_tree_shelter_a = 1024
spr_yellow_fall_leafs_a = 1025
spr_rock_bridge_a = 1026
spr_suspension_bridge_a = 1027
spr_mine_a = 1028
