itm_no_item = 0
itm_tutorial_spear = 1
itm_tutorial_club = 2
itm_tutorial_battle_axe = 3
itm_tutorial_arrows = 4
itm_tutorial_bolts = 5
itm_tutorial_short_bow = 6
itm_tutorial_crossbow = 7
itm_tutorial_throwing_daggers = 8
itm_tutorial_saddle_horse = 9
itm_tutorial_shield = 10
itm_tutorial_staff_no_attack = 11
itm_tutorial_staff = 12
itm_tutorial_sword = 13
itm_tutorial_axe = 14
itm_tutorial_dagger = 15
itm_horse_meat = 16
itm_practice_sword = 17
itm_heavy_practice_sword = 18
itm_practice_dagger = 19
itm_practice_axe = 20
itm_arena_axe = 21
itm_arena_sword = 22
itm_arena_sword_two_handed = 23
itm_arena_lance = 24
itm_practice_staff = 25
itm_practice_lance = 26
itm_practice_shield = 27
itm_practice_bow = 28
itm_practice_crossbow = 29
itm_practice_javelin = 30
itm_practice_javelin_melee = 31
itm_practice_throwing_daggers = 32
itm_practice_throwing_daggers_100_amount = 33
itm_practice_horse = 34
itm_practice_arrows = 35
itm_practice_bolts = 36
itm_practice_arrows_10_amount = 37
itm_practice_arrows_100_amount = 38
itm_practice_bolts_9_amount = 39
itm_practice_boots = 40
itm_red_tourney_armor = 41
itm_blue_tourney_armor = 42
itm_green_tourney_armor = 43
itm_gold_tourney_armor = 44
itm_red_tourney_helmet = 45
itm_blue_tourney_helmet = 46
itm_green_tourney_helmet = 47
itm_gold_tourney_helmet = 48
itm_arena_shield_red = 49
itm_arena_shield_blue = 50
itm_arena_shield_green = 51
itm_arena_shield_yellow = 52
itm_arena_armor_white = 53
itm_arena_armor_red = 54
itm_arena_armor_blue = 55
itm_arena_armor_green = 56
itm_arena_armor_yellow = 57
itm_arena_tunic_white = 58
itm_arena_tunic_red = 59
itm_arena_tunic_blue = 60
itm_arena_tunic_green = 61
itm_arena_tunic_yellow = 62
itm_arena_helmet_red = 63
itm_arena_helmet_blue = 64
itm_arena_helmet_green = 65
itm_arena_helmet_yellow = 66
itm_steppe_helmet_white = 67
itm_steppe_helmet_red = 68
itm_steppe_helmet_blue = 69
itm_steppe_helmet_green = 70
itm_steppe_helmet_yellow = 71
itm_tourney_helm_white = 72
itm_tourney_helm_red = 73
itm_tourney_helm_blue = 74
itm_tourney_helm_green = 75
itm_tourney_helm_yellow = 76
itm_arena_turban_red = 77
itm_arena_turban_blue = 78
itm_arena_turban_green = 79
itm_arena_turban_yellow = 80
itm_book_tactics = 81
itm_book_persuasion = 82
itm_book_leadership = 83
itm_book_intelligence = 84
itm_book_trade = 85
itm_book_weapon_mastery = 86
itm_book_engineering = 87
itm_book_wound_treatment_reference = 88
itm_book_training_reference = 89
itm_book_surgery_reference = 90
itm_spice = 91
itm_salt = 92
itm_oil = 93
itm_pottery = 94
itm_raw_flax = 95
itm_linen = 96
itm_wool = 97
itm_wool_cloth = 98
itm_raw_silk = 99
itm_raw_dyes = 100
itm_velvet = 101
itm_iron = 102
itm_tools = 103
itm_raw_leather = 104
itm_leatherwork = 105
itm_raw_date_fruit = 106
itm_furs = 107
itm_wine = 108
itm_ale = 109
itm_smoked_fish = 110
itm_cheese = 111
itm_honey = 112
itm_sausages = 113
itm_cabbages = 114
itm_dried_meat = 115
itm_apples = 116
itm_raw_grapes = 117
itm_raw_olives = 118
itm_grain = 119
itm_cattle_meat = 120
itm_bread = 121
itm_chicken = 122
itm_pork = 123
itm_butter = 124
itm_siege_supply = 125
itm_quest_wine = 126
itm_quest_ale = 127
itm_tutorial_sword = 128
itm_tutorial_axe = 129
itm_tutorial_spear = 130
itm_tutorial_club = 131
itm_tutorial_battle_axe = 132
itm_tutorial_arrows = 133
itm_tutorial_bolts = 134
itm_tutorial_short_bow = 135
itm_tutorial_crossbow = 136
itm_tutorial_throwing_daggers = 137
itm_tutorial_saddle_horse = 138
itm_tutorial_shield = 139
itm_tutorial_staff_no_attack = 140
itm_tutorial_staff = 141
itm_sumpter_horse = 142
itm_saddle_horse = 143
itm_steppe_horse = 144
itm_arabian_horse_a = 145
itm_courser = 146
itm_arabian_horse_b = 147
itm_hunter = 148
itm_warhorse = 149
itm_charger = 150
itm_arrows = 151
itm_khergit_arrows = 152
itm_barbed_arrows = 153
itm_bodkin_arrows = 154
itm_bolts = 155
itm_steel_bolts = 156
itm_cartridges = 157
itm_pilgrim_disguise = 158
itm_pilgrim_hood = 159
itm_leather_gloves = 160
itm_mail_mittens = 161
itm_scale_gauntlets = 162
itm_lamellar_gauntlets = 163
itm_gauntlets = 164
itm_wrapping_boots = 165
itm_woolen_hose = 166
itm_blue_hose = 167
itm_hunter_boots = 168
itm_hide_boots = 169
itm_ankle_boots = 170
itm_nomad_boots = 171
itm_leather_boots = 172
itm_splinted_leather_greaves = 173
itm_mail_chausses = 174
itm_splinted_greaves = 175
itm_mail_boots = 176
itm_iron_greaves = 177
itm_black_greaves = 178
itm_khergit_leather_boots = 179
itm_sarranid_boots_a = 180
itm_sarranid_boots_b = 181
itm_sarranid_boots_c = 182
itm_sarranid_boots_d = 183
itm_sarranid_head_cloth = 184
itm_sarranid_head_cloth_b = 185
itm_sarranid_felt_head_cloth = 186
itm_sarranid_felt_head_cloth_b = 187
itm_lady_dress_ruby = 188
itm_lady_dress_green = 189
itm_lady_dress_blue = 190
itm_red_dress = 191
itm_brown_dress = 192
itm_green_dress = 193
itm_khergit_lady_dress = 194
itm_khergit_lady_dress_b = 195
itm_sarranid_lady_dress = 196
itm_sarranid_lady_dress_b = 197
itm_sarranid_common_dress = 198
itm_sarranid_common_dress_b = 199
itm_courtly_outfit = 200
itm_nobleman_outfit = 201
itm_nomad_armor = 202
itm_khergit_armor = 203
itm_leather_jacket = 204
itm_rawhide_coat = 205
itm_leather_armor = 206
itm_fur_coat = 207
itm_coat = 208
itm_leather_coat = 209
itm_mail_coat = 210
itm_long_mail_coat = 211
itm_mail_with_tunic_red = 212
itm_mail_with_tunic_green = 213
itm_hide_coat = 214
itm_merchant_outfit = 215
itm_homespun_dress = 216
itm_thick_coat = 217
itm_coat_with_cape = 218
itm_steppe_outfit = 219
itm_nordic_outfit = 220
itm_nordic_armor = 221
itm_hide_armor = 222
itm_cloaked_tunic = 223
itm_sleeveless_tunic = 224
itm_sleeveless_leather_tunic = 225
itm_linen_shirt = 226
itm_wool_coat = 227
itm_dress = 228
itm_blue_dress = 229
itm_peasant_dress = 230
itm_woolen_dress = 231
itm_shirt = 232
itm_linen_tunic = 233
itm_short_tunic = 234
itm_red_shirt = 235
itm_red_tunic = 236
itm_green_tunic = 237
itm_blue_tunic = 238
itm_robe = 239
itm_coarse_tunic = 240
itm_leather_apron = 241
itm_tabard = 242
itm_leather_vest = 243
itm_steppe_armor = 244
itm_gambeson = 245
itm_blue_gambeson = 246
itm_red_gambeson = 247
itm_padded_cloth = 248
itm_aketon_green = 249
itm_leather_jerkin = 250
itm_nomad_vest = 251
itm_ragged_outfit = 252
itm_padded_leather = 253
itm_tribal_warrior_outfit = 254
itm_nomad_robe = 255
itm_studded_leather_coat = 256
itm_byrnie = 257
itm_haubergeon = 258
itm_lamellar_vest = 259
itm_lamellar_vest_khergit = 260
itm_mail_shirt = 261
itm_mail_hauberk = 262
itm_mail_with_surcoat = 263
itm_surcoat_over_mail = 264
itm_brigandine_red = 265
itm_lamellar_armor = 266
itm_scale_armor = 267
itm_banded_armor = 268
itm_cuir_bouilli = 269
itm_coat_of_plates = 270
itm_coat_of_plates_red = 271
itm_plate_armor = 272
itm_black_armor = 273
itm_pelt_coat = 274
itm_khergit_elite_armor = 275
itm_vaegir_elite_armor = 276
itm_sarranid_elite_armor = 277
itm_sarranid_dress_a = 278
itm_sarranid_dress_b = 279
itm_sarranid_cloth_robe = 280
itm_sarranid_cloth_robe_b = 281
itm_skirmisher_armor = 282
itm_archers_vest = 283
itm_sarranid_leather_armor = 284
itm_sarranid_cavalry_robe = 285
itm_arabian_armor_b = 286
itm_sarranid_mail_shirt = 287
itm_mamluke_mail = 288
itm_burlap_tunic = 289
itm_heraldic_mail_with_surcoat = 290
itm_heraldic_mail_with_tunic = 291
itm_heraldic_mail_with_tunic_b = 292
itm_heraldic_mail_with_tabard = 293
itm_turret_hat_ruby = 294
itm_turret_hat_blue = 295
itm_turret_hat_green = 296
itm_head_wrappings = 297
itm_court_hat = 298
itm_wimple_a = 299
itm_wimple_with_veil = 300
itm_straw_hat = 301
itm_common_hood = 302
itm_hood_b = 303
itm_hood_c = 304
itm_hood_d = 305
itm_headcloth = 306
itm_woolen_hood = 307
itm_arming_cap = 308
itm_fur_hat = 309
itm_nomad_cap = 310
itm_nomad_cap_b = 311
itm_steppe_cap = 312
itm_padded_coif = 313
itm_woolen_cap = 314
itm_felt_hat = 315
itm_felt_hat_b = 316
itm_leather_cap = 317
itm_female_hood = 318
itm_leather_steppe_cap_a = 319
itm_leather_steppe_cap_b = 320
itm_leather_steppe_cap_c = 321
itm_leather_warrior_cap = 322
itm_skullcap = 323
itm_mail_coif = 324
itm_footman_helmet = 325
itm_nasal_helmet = 326
itm_norman_helmet = 327
itm_segmented_helmet = 328
itm_helmet_with_neckguard = 329
itm_flat_topped_helmet = 330
itm_kettle_hat = 331
itm_spiked_helmet = 332
itm_nordic_helmet = 333
itm_khergit_lady_hat = 334
itm_khergit_lady_hat_b = 335
itm_sarranid_felt_hat = 336
itm_turban = 337
itm_desert_turban = 338
itm_sarranid_warrior_cap = 339
itm_sarranid_horseman_helmet = 340
itm_sarranid_helmet1 = 341
itm_sarranid_mail_coif = 342
itm_sarranid_veiled_helmet = 343
itm_nordic_archer_helmet = 344
itm_nordic_veteran_archer_helmet = 345
itm_nordic_footman_helmet = 346
itm_nordic_fighter_helmet = 347
itm_nordic_huscarl_helmet = 348
itm_nordic_warlord_helmet = 349
itm_vaegir_fur_cap = 350
itm_vaegir_fur_helmet = 351
itm_vaegir_spiked_helmet = 352
itm_vaegir_lamellar_helmet = 353
itm_vaegir_noble_helmet = 354
itm_vaegir_war_helmet = 355
itm_vaegir_mask = 356
itm_bascinet = 357
itm_bascinet_2 = 358
itm_bascinet_3 = 359
itm_guard_helmet = 360
itm_black_helmet = 361
itm_full_helm = 362
itm_great_helmet = 363
itm_winged_great_helmet = 364
itm_wooden_stick = 365
itm_cudgel = 366
itm_hammer = 367
itm_club = 368
itm_winged_mace = 369
itm_spiked_mace = 370
itm_military_hammer = 371
itm_maul = 372
itm_sledgehammer = 373
itm_warhammer = 374
itm_pickaxe = 375
itm_spiked_club = 376
itm_fighting_pick = 377
itm_military_pick = 378
itm_morningstar = 379
itm_sickle = 380
itm_cleaver = 381
itm_knife = 382
itm_butchering_knife = 383
itm_dagger = 384
itm_falchion = 385
itm_scimitar = 386
itm_scimitar_b = 387
itm_arabian_sword_a = 388
itm_arabian_sword_b = 389
itm_sarranid_cavalry_sword = 390
itm_arabian_sword_d = 391
itm_great_sword = 392
itm_sword_of_war = 393
itm_hatchet = 394
itm_hand_axe = 395
itm_fighting_axe = 396
itm_axe = 397
itm_voulge = 398
itm_battle_axe = 399
itm_war_axe = 400
itm_sword_two_handed_b = 401
itm_sword_two_handed_a = 402
itm_khergit_sword_two_handed_a = 403
itm_khergit_sword_two_handed_b = 404
itm_two_handed_cleaver = 405
itm_military_cleaver_b = 406
itm_military_cleaver_c = 407
itm_military_sickle_a = 408
itm_bastard_sword_a = 409
itm_bastard_sword_b = 410
itm_one_handed_war_axe_a = 411
itm_one_handed_battle_axe_a = 412
itm_one_handed_war_axe_b = 413
itm_one_handed_battle_axe_b = 414
itm_one_handed_battle_axe_c = 415
itm_two_handed_axe = 416
itm_two_handed_battle_axe_2 = 417
itm_shortened_voulge = 418
itm_great_axe = 419
itm_long_axe = 420
itm_long_axe_alt = 421
itm_long_axe_b = 422
itm_long_axe_b_alt = 423
itm_long_axe_c = 424
itm_long_axe_c_alt = 425
itm_bardiche = 426
itm_great_bardiche = 427
itm_voulge = 428
itm_long_bardiche = 429
itm_great_long_bardiche = 430
itm_hafted_blade_b = 431
itm_hafted_blade_a = 432
itm_shortened_military_scythe = 433
itm_sword_medieval_a = 434
itm_sword_medieval_b = 435
itm_sword_medieval_b_small = 436
itm_sword_medieval_c = 437
itm_sword_medieval_c_small = 438
itm_sword_medieval_c_long = 439
itm_sword_medieval_d_long = 440
itm_sword_viking_1 = 441
itm_sword_viking_2 = 442
itm_sword_viking_2_small = 443
itm_sword_viking_3 = 444
itm_sword_viking_3_small = 445
itm_sword_khergit_1 = 446
itm_sword_khergit_2 = 447
itm_sword_khergit_3 = 448
itm_sword_khergit_4 = 449
itm_mace_1 = 450
itm_mace_2 = 451
itm_mace_3 = 452
itm_mace_4 = 453
itm_club_with_spike_head = 454
itm_long_spiked_club = 455
itm_long_hafted_knobbed_mace = 456
itm_long_hafted_spiked_mace = 457
itm_sarranid_two_handed_mace_1 = 458
itm_sarranid_mace_1 = 459
itm_sarranid_axe_a = 460
itm_sarranid_axe_b = 461
itm_sarranid_two_handed_axe_a = 462
itm_sarranid_two_handed_axe_b = 463
itm_scythe = 464
itm_pitch_fork = 465
itm_military_fork = 466
itm_battle_fork = 467
itm_boar_spear = 468
itm_jousting_lance = 469
itm_double_sided_lance = 470
itm_glaive = 471
itm_poleaxe = 472
itm_polehammer = 473
itm_staff = 474
itm_quarter_staff = 475
itm_iron_staff = 476
itm_shortened_spear = 477
itm_spear = 478
itm_bamboo_spear = 479
itm_war_spear = 480
itm_military_scythe = 481
itm_light_lance = 482
itm_lance = 483
itm_heavy_lance = 484
itm_great_lance = 485
itm_pike = 486
itm_ashwood_pike = 487
itm_awlpike = 488
itm_awlpike_long = 489
itm_bec_de_corbin_a = 490
itm_wooden_shield = 491
itm_nordic_shield = 492
itm_fur_covered_shield = 493
itm_steel_shield = 494
itm_plate_covered_round_shield = 495
itm_leather_covered_round_shield = 496
itm_hide_covered_round_shield = 497
itm_shield_heater_c = 498
itm_norman_shield_1 = 499
itm_norman_shield_2 = 500
itm_norman_shield_3 = 501
itm_norman_shield_4 = 502
itm_norman_shield_5 = 503
itm_norman_shield_6 = 504
itm_norman_shield_7 = 505
itm_norman_shield_8 = 506
itm_tab_shield_round_a = 507
itm_tab_shield_round_b = 508
itm_tab_shield_round_c = 509
itm_tab_shield_round_d = 510
itm_tab_shield_round_e = 511
itm_tab_shield_kite_a = 512
itm_tab_shield_kite_b = 513
itm_tab_shield_kite_c = 514
itm_tab_shield_kite_d = 515
itm_tab_shield_kite_cav_a = 516
itm_tab_shield_kite_cav_b = 517
itm_tab_shield_heater_a = 518
itm_tab_shield_heater_b = 519
itm_tab_shield_heater_c = 520
itm_tab_shield_heater_d = 521
itm_tab_shield_heater_cav_a = 522
itm_tab_shield_heater_cav_b = 523
itm_tab_shield_pavise_a = 524
itm_tab_shield_pavise_b = 525
itm_tab_shield_pavise_c = 526
itm_tab_shield_pavise_d = 527
itm_tab_shield_small_round_a = 528
itm_tab_shield_small_round_b = 529
itm_tab_shield_small_round_c = 530
itm_darts = 531
itm_war_darts = 532
itm_javelin = 533
itm_javelin_melee = 534
itm_throwing_spears = 535
itm_throwing_spear_melee = 536
itm_jarid = 537
itm_jarid_melee = 538
itm_stones = 539
itm_throwing_knives = 540
itm_throwing_daggers = 541
itm_light_throwing_axes = 542
itm_light_throwing_axes_melee = 543
itm_throwing_axes = 544
itm_throwing_axes_melee = 545
itm_heavy_throwing_axes = 546
itm_heavy_throwing_axes_melee = 547
itm_hunting_bow = 548
itm_short_bow = 549
itm_nomad_bow = 550
itm_long_bow = 551
itm_khergit_bow = 552
itm_strong_bow = 553
itm_war_bow = 554
itm_hunting_crossbow = 555
itm_light_crossbow = 556
itm_crossbow = 557
itm_heavy_crossbow = 558
itm_sniper_crossbow = 559
itm_flintlock_pistol = 560
itm_torch = 561
itm_lyre = 562
itm_lute = 563
itm_strange_armor = 564
itm_strange_boots = 565
itm_strange_helmet = 566
itm_strange_sword = 567
itm_strange_great_sword = 568
itm_strange_short_sword = 569
itm_court_dress = 570
itm_rich_outfit = 571
itm_khergit_guard_armor = 572
itm_felt_steppe_cap = 573
itm_khergit_war_helmet = 574
itm_khergit_helmet = 575
itm_khergit_guard_boots = 576
itm_khergit_guard_helmet = 577
itm_khergit_cavalry_helmet = 578
itm_black_hood = 579
itm_light_leather = 580
itm_light_leather_boots = 581
itm_mail_and_plate = 582
itm_light_mail_and_plate = 583
itm_byzantion_helmet_a = 584
itm_magyar_helmet_a = 585
itm_rus_helmet_a = 586
itm_sipahi_helmet_a = 587
itm_shahi = 588
itm_rabati = 589
itm_tunic_with_green_cape = 590
itm_keys = 591
itm_bride_dress = 592
itm_bride_crown = 593
itm_bride_shoes = 594
itm_practice_bow_2 = 595
itm_practice_arrows_2 = 596
itm_plate_boots = 597
itm_heraldic_mail_with_surcoat_for_tableau = 598
itm_mail_boots_for_tableau = 599
itm_warhorse_sarranid = 600
itm_warhorse_steppe = 601
itm_items_end = 602
