###################################################
# header_map_icons.py
# This file contains declarations for module_map_icons
# DO NOT EDIT THIS FILE!
###################################################

from smart_module.module_system.header_common import *

## map icon flags

mcn_no_shadow      = 0x00000001

