snd_click = 0
snd_tutorial_1 = 1
snd_tutorial_2 = 2
snd_gong = 3
snd_quest_taken = 4
snd_quest_completed = 5
snd_quest_succeeded = 6
snd_quest_concluded = 7
snd_quest_failed = 8
snd_quest_cancelled = 9
snd_rain = 10
snd_money_received = 11
snd_money_paid = 12
snd_sword_clash_1 = 13
snd_sword_clash_2 = 14
snd_sword_clash_3 = 15
snd_sword_swing = 16
snd_footstep_grass = 17
snd_footstep_wood = 18
snd_footstep_water = 19
snd_footstep_horse = 20
snd_footstep_horse_1b = 21
snd_footstep_horse_1f = 22
snd_footstep_horse_2b = 23
snd_footstep_horse_2f = 24
snd_footstep_horse_3b = 25
snd_footstep_horse_3f = 26
snd_footstep_horse_4b = 27
snd_footstep_horse_4f = 28
snd_footstep_horse_5b = 29
snd_footstep_horse_5f = 30
snd_jump_begin = 31
snd_jump_end = 32
snd_jump_begin_water = 33
snd_jump_end_water = 34
snd_horse_jump_begin = 35
snd_horse_jump_end = 36
snd_horse_jump_begin_water = 37
snd_horse_jump_end_water = 38
snd_release_bow = 39
snd_release_crossbow = 40
snd_throw_javelin = 41
snd_throw_axe = 42
snd_throw_knife = 43
snd_throw_stone = 44
snd_reload_crossbow = 45
snd_reload_crossbow_continue = 46
snd_pull_bow = 47
snd_pull_arrow = 48
snd_arrow_pass_by = 49
snd_bolt_pass_by = 50
snd_javelin_pass_by = 51
snd_stone_pass_by = 52
snd_axe_pass_by = 53
snd_knife_pass_by = 54
snd_bullet_pass_by = 55
snd_incoming_arrow_hit_ground = 56
snd_incoming_bolt_hit_ground = 57
snd_incoming_javelin_hit_ground = 58
snd_incoming_stone_hit_ground = 59
snd_incoming_axe_hit_ground = 60
snd_incoming_knife_hit_ground = 61
snd_incoming_bullet_hit_ground = 62
snd_outgoing_arrow_hit_ground = 63
snd_outgoing_bolt_hit_ground = 64
snd_outgoing_javelin_hit_ground = 65
snd_outgoing_stone_hit_ground = 66
snd_outgoing_axe_hit_ground = 67
snd_outgoing_knife_hit_ground = 68
snd_outgoing_bullet_hit_ground = 69
snd_draw_sword = 70
snd_put_back_sword = 71
snd_draw_greatsword = 72
snd_put_back_greatsword = 73
snd_draw_axe = 74
snd_put_back_axe = 75
snd_draw_greataxe = 76
snd_put_back_greataxe = 77
snd_draw_spear = 78
snd_put_back_spear = 79
snd_draw_crossbow = 80
snd_put_back_crossbow = 81
snd_draw_revolver = 82
snd_put_back_revolver = 83
snd_draw_dagger = 84
snd_put_back_dagger = 85
snd_draw_bow = 86
snd_put_back_bow = 87
snd_draw_shield = 88
snd_put_back_shield = 89
snd_draw_other = 90
snd_put_back_other = 91
snd_body_fall_small = 92
snd_body_fall_big = 93
snd_horse_body_fall_begin = 94
snd_horse_body_fall_end = 95
snd_hit_wood_wood = 96
snd_hit_metal_metal = 97
snd_hit_wood_metal = 98
snd_shield_hit_wood_wood = 99
snd_shield_hit_metal_metal = 100
snd_shield_hit_wood_metal = 101
snd_shield_hit_metal_wood = 102
snd_shield_broken = 103
snd_man_hit = 104
snd_man_die = 105
snd_woman_hit = 106
snd_woman_die = 107
snd_woman_yell = 108
snd_hide = 109
snd_unhide = 110
snd_neigh = 111
snd_gallop = 112
snd_battle = 113
snd_arrow_hit_body = 114
snd_metal_hit_low_armor_low_damage = 115
snd_metal_hit_low_armor_high_damage = 116
snd_metal_hit_high_armor_low_damage = 117
snd_metal_hit_high_armor_high_damage = 118
snd_wooden_hit_low_armor_low_damage = 119
snd_wooden_hit_low_armor_high_damage = 120
snd_wooden_hit_high_armor_low_damage = 121
snd_wooden_hit_high_armor_high_damage = 122
snd_mp_arrow_hit_target = 123
snd_blunt_hit = 124
snd_player_hit_by_arrow = 125
snd_pistol_shot = 126
snd_man_grunt = 127
snd_man_breath_hard = 128
snd_man_stun = 129
snd_man_grunt_long = 130
snd_man_yell = 131
snd_man_warcry = 132
snd_encounter_looters = 133
snd_encounter_bandits = 134
snd_encounter_farmers = 135
snd_encounter_sea_raiders = 136
snd_encounter_steppe_bandits = 137
snd_encounter_nobleman = 138
snd_encounter_vaegirs_ally = 139
snd_encounter_vaegirs_neutral = 140
snd_encounter_vaegirs_enemy = 141
snd_sneak_town_halt = 142
snd_horse_walk = 143
snd_horse_trot = 144
snd_horse_canter = 145
snd_horse_gallop = 146
snd_horse_breath = 147
snd_horse_snort = 148
snd_horse_low_whinny = 149
snd_block_fist = 150
snd_man_hit_blunt_weak = 151
snd_man_hit_blunt_strong = 152
snd_man_hit_pierce_weak = 153
snd_man_hit_pierce_strong = 154
snd_man_hit_cut_weak = 155
snd_man_hit_cut_strong = 156
snd_man_victory = 157
snd_fire_loop = 158
snd_torch_loop = 159
snd_dummy_hit = 160
snd_dummy_destroyed = 161
snd_gourd_destroyed = 162
snd_cow_moo = 163
snd_cow_slaughter = 164
snd_distant_dog_bark = 165
snd_distant_owl = 166
snd_distant_chicken = 167
snd_distant_carpenter = 168
snd_distant_blacksmith = 169
snd_arena_ambiance = 170
snd_town_ambiance = 171
snd_tutorial_fail = 172
snd_your_flag_taken = 173
snd_enemy_flag_taken = 174
snd_flag_returned = 175
snd_team_scored_a_point = 176
snd_enemy_scored_a_point = 177


