skl_trade = 0
skl_leadership = 1
skl_prisoner_management = 2
skl_reserved_1 = 3
skl_reserved_2 = 4
skl_reserved_3 = 5
skl_reserved_4 = 6
skl_persuasion = 7
skl_engineer = 8
skl_first_aid = 9
skl_surgery = 10
skl_wound_treatment = 11
skl_inventory_management = 12
skl_spotting = 13
skl_pathfinding = 14
skl_tactics = 15
skl_tracking = 16
skl_trainer = 17
skl_reserved_5 = 18
skl_reserved_6 = 19
skl_reserved_7 = 20
skl_reserved_8 = 21
skl_looting = 22
skl_horse_archery = 23
skl_riding = 24
skl_athletics = 25
skl_shield = 26
skl_weapon_master = 27
skl_reserved_9 = 28
skl_reserved_10 = 29
skl_reserved_11 = 30
skl_reserved_12 = 31
skl_reserved_13 = 32
skl_power_draw = 33
skl_power_throw = 34
skl_power_strike = 35
skl_ironflesh = 36
skl_reserved_14 = 37
skl_reserved_15 = 38
skl_reserved_16 = 39
skl_reserved_17 = 40
skl_reserved_18 = 41


