p_main_party = 0
p_temp_party = 1
p_camp_bandits = 2
p_temp_party_2 = 3
p_temp_casualties = 4
p_temp_casualties_2 = 5
p_temp_casualties_3 = 6
p_temp_wounded = 7
p_temp_killed = 8
p_main_party_backup = 9
p_encountered_party_backup = 10
p_collective_friends_backup = 11
p_player_casualties = 12
p_enemy_casualties = 13
p_ally_casualties = 14
p_collective_enemy = 15
p_collective_ally = 16
p_collective_friends = 17
p_total_enemy_casualties = 18
p_routed_enemies = 19
p_zendar = 20
p_town_1 = 21
p_town_2 = 22
p_town_3 = 23
p_town_4 = 24
p_town_5 = 25
p_town_6 = 26
p_town_7 = 27
p_town_8 = 28
p_town_9 = 29
p_town_10 = 30
p_town_11 = 31
p_town_12 = 32
p_town_13 = 33
p_town_14 = 34
p_town_15 = 35
p_town_16 = 36
p_town_17 = 37
p_town_18 = 38
p_town_19 = 39
p_town_20 = 40
p_town_21 = 41
p_town_22 = 42
p_castle_1 = 43
p_castle_2 = 44
p_castle_3 = 45
p_castle_4 = 46
p_castle_5 = 47
p_castle_6 = 48
p_castle_7 = 49
p_castle_8 = 50
p_castle_9 = 51
p_castle_10 = 52
p_castle_11 = 53
p_castle_12 = 54
p_castle_13 = 55
p_castle_14 = 56
p_castle_15 = 57
p_castle_16 = 58
p_castle_17 = 59
p_castle_18 = 60
p_castle_19 = 61
p_castle_20 = 62
p_castle_21 = 63
p_castle_22 = 64
p_castle_23 = 65
p_castle_24 = 66
p_castle_25 = 67
p_castle_26 = 68
p_castle_27 = 69
p_castle_28 = 70
p_castle_29 = 71
p_castle_30 = 72
p_castle_31 = 73
p_castle_32 = 74
p_castle_33 = 75
p_castle_34 = 76
p_castle_35 = 77
p_castle_36 = 78
p_castle_37 = 79
p_castle_38 = 80
p_castle_39 = 81
p_castle_40 = 82
p_castle_41 = 83
p_castle_42 = 84
p_castle_43 = 85
p_castle_44 = 86
p_castle_45 = 87
p_castle_46 = 88
p_castle_47 = 89
p_castle_48 = 90
p_village_1 = 91
p_village_2 = 92
p_village_3 = 93
p_village_4 = 94
p_village_5 = 95
p_village_6 = 96
p_village_7 = 97
p_village_8 = 98
p_village_9 = 99
p_village_10 = 100
p_village_11 = 101
p_village_12 = 102
p_village_13 = 103
p_village_14 = 104
p_village_15 = 105
p_village_16 = 106
p_village_17 = 107
p_village_18 = 108
p_village_19 = 109
p_village_20 = 110
p_village_21 = 111
p_village_22 = 112
p_village_23 = 113
p_village_24 = 114
p_village_25 = 115
p_village_26 = 116
p_village_27 = 117
p_village_28 = 118
p_village_29 = 119
p_village_30 = 120
p_village_31 = 121
p_village_32 = 122
p_village_33 = 123
p_village_34 = 124
p_village_35 = 125
p_village_36 = 126
p_village_37 = 127
p_village_38 = 128
p_village_39 = 129
p_village_40 = 130
p_village_41 = 131
p_village_42 = 132
p_village_43 = 133
p_village_44 = 134
p_village_45 = 135
p_village_46 = 136
p_village_47 = 137
p_village_48 = 138
p_village_49 = 139
p_village_50 = 140
p_village_51 = 141
p_village_52 = 142
p_village_53 = 143
p_village_54 = 144
p_village_55 = 145
p_village_56 = 146
p_village_57 = 147
p_village_58 = 148
p_village_59 = 149
p_village_60 = 150
p_village_61 = 151
p_village_62 = 152
p_village_63 = 153
p_village_64 = 154
p_village_65 = 155
p_village_66 = 156
p_village_67 = 157
p_village_68 = 158
p_village_69 = 159
p_village_70 = 160
p_village_71 = 161
p_village_72 = 162
p_village_73 = 163
p_village_74 = 164
p_village_75 = 165
p_village_76 = 166
p_village_77 = 167
p_village_78 = 168
p_village_79 = 169
p_village_80 = 170
p_village_81 = 171
p_village_82 = 172
p_village_83 = 173
p_village_84 = 174
p_village_85 = 175
p_village_86 = 176
p_village_87 = 177
p_village_88 = 178
p_village_89 = 179
p_village_90 = 180
p_village_91 = 181
p_village_92 = 182
p_village_93 = 183
p_village_94 = 184
p_village_95 = 185
p_village_96 = 186
p_village_97 = 187
p_village_98 = 188
p_village_99 = 189
p_village_100 = 190
p_village_101 = 191
p_village_102 = 192
p_village_103 = 193
p_village_104 = 194
p_village_105 = 195
p_village_106 = 196
p_village_107 = 197
p_village_108 = 198
p_village_109 = 199
p_village_110 = 200
p_salt_mine = 201
p_four_ways_inn = 202
p_test_scene = 203
p_battlefields = 204
p_dhorak_keep = 205
p_training_ground = 206
p_training_ground_1 = 207
p_training_ground_2 = 208
p_training_ground_3 = 209
p_training_ground_4 = 210
p_training_ground_5 = 211
p_bridge_1 = 212
p_bridge_2 = 213
p_bridge_3 = 214
p_bridge_4 = 215
p_bridge_5 = 216
p_bridge_6 = 217
p_bridge_7 = 218
p_bridge_8 = 219
p_bridge_9 = 220
p_bridge_10 = 221
p_bridge_11 = 222
p_bridge_12 = 223
p_bridge_13 = 224
p_bridge_14 = 225
p_looter_spawn_point = 226
p_steppe_bandit_spawn_point = 227
p_taiga_bandit_spawn_point = 228
p_forest_bandit_spawn_point = 229
p_mountain_bandit_spawn_point = 230
p_sea_raider_spawn_point_1 = 231
p_sea_raider_spawn_point_2 = 232
p_desert_bandit_spawn_point = 233
p_spawn_points_end = 234
p_reserved_1 = 235
p_reserved_2 = 236
p_reserved_3 = 237
p_reserved_4 = 238
p_reserved_5 = 239
