icon_player = 0
icon_player_horseman = 1
icon_gray_knight = 2
icon_vaegir_knight = 3
icon_flagbearer_a = 4
icon_flagbearer_b = 5
icon_peasant = 6
icon_khergit = 7
icon_khergit_horseman_b = 8
icon_axeman = 9
icon_woman = 10
icon_woman_b = 11
icon_town = 12
icon_town_steppe = 13
icon_town_desert = 14
icon_village_a = 15
icon_village_b = 16
icon_village_c = 17
icon_village_burnt_a = 18
icon_village_deserted_a = 19
icon_village_burnt_b = 20
icon_village_deserted_b = 21
icon_village_burnt_c = 22
icon_village_deserted_c = 23
icon_village_snow_a = 24
icon_village_snow_burnt_a = 25
icon_village_snow_deserted_a = 26
icon_camp = 27
icon_ship = 28
icon_ship_on_land = 29
icon_castle_a = 30
icon_castle_b = 31
icon_castle_c = 32
icon_castle_d = 33
icon_town_snow = 34
icon_castle_snow_a = 35
icon_castle_snow_b = 36
icon_mule = 37
icon_cattle = 38
icon_training_ground = 39
icon_bridge_a = 40
icon_bridge_b = 41
icon_bridge_snow_a = 42
icon_custom_banner_01 = 43
icon_custom_banner_02 = 44
icon_custom_banner_03 = 45
icon_banner_01 = 46
icon_banner_02 = 47
icon_banner_03 = 48
icon_banner_04 = 49
icon_banner_05 = 50
icon_banner_06 = 51
icon_banner_07 = 52
icon_banner_08 = 53
icon_banner_09 = 54
icon_banner_10 = 55
icon_banner_11 = 56
icon_banner_12 = 57
icon_banner_13 = 58
icon_banner_14 = 59
icon_banner_15 = 60
icon_banner_16 = 61
icon_banner_17 = 62
icon_banner_18 = 63
icon_banner_19 = 64
icon_banner_20 = 65
icon_banner_21 = 66
icon_banner_22 = 67
icon_banner_23 = 68
icon_banner_24 = 69
icon_banner_25 = 70
icon_banner_26 = 71
icon_banner_27 = 72
icon_banner_28 = 73
icon_banner_29 = 74
icon_banner_30 = 75
icon_banner_31 = 76
icon_banner_32 = 77
icon_banner_33 = 78
icon_banner_34 = 79
icon_banner_35 = 80
icon_banner_36 = 81
icon_banner_37 = 82
icon_banner_38 = 83
icon_banner_39 = 84
icon_banner_40 = 85
icon_banner_41 = 86
icon_banner_42 = 87
icon_banner_43 = 88
icon_banner_44 = 89
icon_banner_45 = 90
icon_banner_46 = 91
icon_banner_47 = 92
icon_banner_48 = 93
icon_banner_49 = 94
icon_banner_50 = 95
icon_banner_51 = 96
icon_banner_52 = 97
icon_banner_53 = 98
icon_banner_54 = 99
icon_banner_55 = 100
icon_banner_56 = 101
icon_banner_57 = 102
icon_banner_58 = 103
icon_banner_59 = 104
icon_banner_60 = 105
icon_banner_61 = 106
icon_banner_62 = 107
icon_banner_63 = 108
icon_banner_64 = 109
icon_banner_65 = 110
icon_banner_66 = 111
icon_banner_67 = 112
icon_banner_68 = 113
icon_banner_69 = 114
icon_banner_70 = 115
icon_banner_71 = 116
icon_banner_72 = 117
icon_banner_73 = 118
icon_banner_74 = 119
icon_banner_75 = 120
icon_banner_76 = 121
icon_banner_77 = 122
icon_banner_78 = 123
icon_banner_79 = 124
icon_banner_80 = 125
icon_banner_81 = 126
icon_banner_82 = 127
icon_banner_83 = 128
icon_banner_84 = 129
icon_banner_85 = 130
icon_banner_86 = 131
icon_banner_87 = 132
icon_banner_88 = 133
icon_banner_89 = 134
icon_banner_90 = 135
icon_banner_91 = 136
icon_banner_92 = 137
icon_banner_93 = 138
icon_banner_94 = 139
icon_banner_95 = 140
icon_banner_96 = 141
icon_banner_97 = 142
icon_banner_98 = 143
icon_banner_99 = 144
icon_banner_100 = 145
icon_banner_101 = 146
icon_banner_102 = 147
icon_banner_103 = 148
icon_banner_104 = 149
icon_banner_105 = 150
icon_banner_106 = 151
icon_banner_107 = 152
icon_banner_108 = 153
icon_banner_109 = 154
icon_banner_110 = 155
icon_banner_111 = 156
icon_banner_112 = 157
icon_banner_113 = 158
icon_banner_114 = 159
icon_banner_115 = 160
icon_banner_116 = 161
icon_banner_117 = 162
icon_banner_118 = 163
icon_banner_119 = 164
icon_banner_120 = 165
icon_banner_121 = 166
icon_banner_122 = 167
icon_banner_123 = 168
icon_banner_124 = 169
icon_banner_125 = 170
icon_banner_126 = 171
icon_banner_127 = 172
icon_banner_128 = 173
icon_banner_129 = 174
icon_banner_130 = 175
icon_banner_131 = 176
icon_banner_132 = 177
icon_banner_133 = 178
icon_banner_134 = 179
icon_banner_135 = 180
icon_map_flag_kingdom_a = 181
icon_map_flag_kingdom_b = 182
icon_map_flag_kingdom_c = 183
icon_map_flag_kingdom_d = 184
icon_map_flag_kingdom_e = 185
icon_map_flag_kingdom_f = 186
icon_banner_136 = 187
icon_bandit_lair = 188
