mesh_pic_bandits = 0
mesh_pic_mb_warrior_1 = 1
mesh_pic_messenger = 2
mesh_pic_prisoner_man = 3
mesh_pic_prisoner_fem = 4
mesh_pic_prisoner_wilderness = 5
mesh_pic_siege_sighted = 6
mesh_pic_siege_sighted_fem = 7
mesh_pic_camp = 8
mesh_pic_payment = 9
mesh_pic_escape_1 = 10
mesh_pic_escape_1_fem = 11
mesh_pic_victory = 12
mesh_pic_defeat = 13
mesh_pic_wounded = 14
mesh_pic_wounded_fem = 15
mesh_pic_steppe_bandits = 16
mesh_pic_mountain_bandits = 17
mesh_pic_sea_raiders = 18
mesh_pic_deserters = 19
mesh_pic_forest_bandits = 20
mesh_pic_cattle = 21
mesh_pic_looted_village = 22
mesh_pic_village_p = 23
mesh_pic_village_s = 24
mesh_pic_village_w = 25
mesh_pic_recruits = 26
mesh_pic_arms_swadian = 27
mesh_pic_arms_vaegir = 28
mesh_pic_arms_khergit = 29
mesh_pic_arms_nord = 30
mesh_pic_arms_rhodok = 31
mesh_pic_sarranid_arms = 32
mesh_pic_castle1 = 33
mesh_pic_castledes = 34
mesh_pic_castlesnow = 35
mesh_pic_charge = 36
mesh_pic_khergit = 37
mesh_pic_nord = 38
mesh_pic_rhodock = 39
mesh_pic_sally_out = 40
mesh_pic_siege_attack = 41
mesh_pic_swad = 42
mesh_pic_town1 = 43
mesh_pic_towndes = 44
mesh_pic_townriot = 45
mesh_pic_townsnow = 46
mesh_pic_vaegir = 47
mesh_pic_villageriot = 48
mesh_pic_sarranid_encounter = 49
mesh_mp_score_a = 50
mesh_mp_score_b = 51
mesh_portrait_blend_out = 52
mesh_load_window = 53
mesh_checkbox_off = 54
mesh_checkbox_on = 55
mesh_white_plane = 56
mesh_white_dot = 57
mesh_player_dot = 58
mesh_flag_infantry = 59
mesh_flag_archers = 60
mesh_flag_cavalry = 61
mesh_inv_slot = 62
mesh_mp_ingame_menu = 63
mesh_mp_inventory_left = 64
mesh_mp_inventory_right = 65
mesh_mp_inventory_choose = 66
mesh_mp_inventory_slot_glove = 67
mesh_mp_inventory_slot_horse = 68
mesh_mp_inventory_slot_armor = 69
mesh_mp_inventory_slot_helmet = 70
mesh_mp_inventory_slot_boot = 71
mesh_mp_inventory_slot_empty = 72
mesh_mp_inventory_slot_equip = 73
mesh_mp_inventory_left_arrow = 74
mesh_mp_inventory_right_arrow = 75
mesh_mp_ui_host_main = 76
mesh_mp_ui_host_maps_1 = 77
mesh_mp_ui_host_maps_2 = 78
mesh_mp_ui_host_maps_3 = 79
mesh_mp_ui_host_maps_4 = 80
mesh_mp_ui_host_maps_5 = 81
mesh_mp_ui_host_maps_6 = 82
mesh_mp_ui_host_maps_7 = 83
mesh_mp_ui_host_maps_8 = 84
mesh_mp_ui_host_maps_9 = 85
mesh_mp_ui_host_maps_10 = 86
mesh_mp_ui_host_maps_11 = 87
mesh_mp_ui_host_maps_12 = 88
mesh_mp_ui_host_maps_13 = 89
mesh_mp_ui_host_maps_randomp = 90
mesh_mp_ui_host_maps_randoms = 91
mesh_mp_ui_command_panel = 92
mesh_mp_ui_command_border_l = 93
mesh_mp_ui_command_border_r = 94
mesh_mp_ui_welcome_panel = 95
mesh_flag_project_sw = 96
mesh_flag_project_vg = 97
mesh_flag_project_kh = 98
mesh_flag_project_nd = 99
mesh_flag_project_rh = 100
mesh_flag_project_sr = 101
mesh_flag_projects_end = 102
mesh_flag_project_sw_miss = 103
mesh_flag_project_vg_miss = 104
mesh_flag_project_kh_miss = 105
mesh_flag_project_nd_miss = 106
mesh_flag_project_rh_miss = 107
mesh_flag_project_sr_miss = 108
mesh_flag_project_misses_end = 109
mesh_color_picker = 110
mesh_custom_map_banner_01 = 111
mesh_custom_map_banner_02 = 112
mesh_custom_map_banner_03 = 113
mesh_custom_banner_01 = 114
mesh_custom_banner_02 = 115
mesh_custom_banner_bg = 116
mesh_custom_banner_fg01 = 117
mesh_custom_banner_fg02 = 118
mesh_custom_banner_fg03 = 119
mesh_custom_banner_fg04 = 120
mesh_custom_banner_fg05 = 121
mesh_custom_banner_fg06 = 122
mesh_custom_banner_fg07 = 123
mesh_custom_banner_fg08 = 124
mesh_custom_banner_fg09 = 125
mesh_custom_banner_fg10 = 126
mesh_custom_banner_fg11 = 127
mesh_custom_banner_fg12 = 128
mesh_custom_banner_fg13 = 129
mesh_custom_banner_fg14 = 130
mesh_custom_banner_fg15 = 131
mesh_custom_banner_fg16 = 132
mesh_custom_banner_fg17 = 133
mesh_custom_banner_fg18 = 134
mesh_custom_banner_fg19 = 135
mesh_custom_banner_fg20 = 136
mesh_custom_banner_fg21 = 137
mesh_custom_banner_fg22 = 138
mesh_custom_banner_fg23 = 139
mesh_custom_banner_charge_01 = 140
mesh_custom_banner_charge_02 = 141
mesh_custom_banner_charge_03 = 142
mesh_custom_banner_charge_04 = 143
mesh_custom_banner_charge_05 = 144
mesh_custom_banner_charge_06 = 145
mesh_custom_banner_charge_07 = 146
mesh_custom_banner_charge_08 = 147
mesh_custom_banner_charge_09 = 148
mesh_custom_banner_charge_10 = 149
mesh_custom_banner_charge_11 = 150
mesh_custom_banner_charge_12 = 151
mesh_custom_banner_charge_13 = 152
mesh_custom_banner_charge_14 = 153
mesh_custom_banner_charge_15 = 154
mesh_custom_banner_charge_16 = 155
mesh_custom_banner_charge_17 = 156
mesh_custom_banner_charge_18 = 157
mesh_custom_banner_charge_19 = 158
mesh_custom_banner_charge_20 = 159
mesh_custom_banner_charge_21 = 160
mesh_custom_banner_charge_22 = 161
mesh_custom_banner_charge_23 = 162
mesh_custom_banner_charge_24 = 163
mesh_custom_banner_charge_25 = 164
mesh_custom_banner_charge_26 = 165
mesh_custom_banner_charge_27 = 166
mesh_custom_banner_charge_28 = 167
mesh_custom_banner_charge_29 = 168
mesh_custom_banner_charge_30 = 169
mesh_custom_banner_charge_31 = 170
mesh_custom_banner_charge_32 = 171
mesh_custom_banner_charge_33 = 172
mesh_custom_banner_charge_34 = 173
mesh_custom_banner_charge_35 = 174
mesh_custom_banner_charge_36 = 175
mesh_custom_banner_charge_37 = 176
mesh_custom_banner_charge_38 = 177
mesh_custom_banner_charge_39 = 178
mesh_custom_banner_charge_40 = 179
mesh_custom_banner_charge_41 = 180
mesh_custom_banner_charge_42 = 181
mesh_custom_banner_charge_43 = 182
mesh_custom_banner_charge_44 = 183
mesh_custom_banner_charge_45 = 184
mesh_custom_banner_charge_46 = 185
mesh_tableau_mesh_custom_banner = 186
mesh_tableau_mesh_custom_banner_square = 187
mesh_tableau_mesh_custom_banner_tall = 188
mesh_tableau_mesh_custom_banner_short = 189
mesh_tableau_mesh_shield_round_1 = 190
mesh_tableau_mesh_shield_round_2 = 191
mesh_tableau_mesh_shield_round_3 = 192
mesh_tableau_mesh_shield_round_4 = 193
mesh_tableau_mesh_shield_round_5 = 194
mesh_tableau_mesh_shield_small_round_1 = 195
mesh_tableau_mesh_shield_small_round_2 = 196
mesh_tableau_mesh_shield_small_round_3 = 197
mesh_tableau_mesh_shield_kite_1 = 198
mesh_tableau_mesh_shield_kite_2 = 199
mesh_tableau_mesh_shield_kite_3 = 200
mesh_tableau_mesh_shield_kite_4 = 201
mesh_tableau_mesh_shield_heater_1 = 202
mesh_tableau_mesh_shield_heater_2 = 203
mesh_tableau_mesh_shield_pavise_1 = 204
mesh_tableau_mesh_shield_pavise_2 = 205
mesh_heraldic_armor_bg = 206
mesh_tableau_mesh_heraldic_armor_a = 207
mesh_tableau_mesh_heraldic_armor_b = 208
mesh_tableau_mesh_heraldic_armor_c = 209
mesh_tableau_mesh_heraldic_armor_d = 210
mesh_outer_terrain_plain_1 = 211
mesh_banner_a01 = 212
mesh_banner_a02 = 213
mesh_banner_a03 = 214
mesh_banner_a04 = 215
mesh_banner_a05 = 216
mesh_banner_a06 = 217
mesh_banner_a07 = 218
mesh_banner_a08 = 219
mesh_banner_a09 = 220
mesh_banner_a10 = 221
mesh_banner_a11 = 222
mesh_banner_a12 = 223
mesh_banner_a13 = 224
mesh_banner_a14 = 225
mesh_banner_a15 = 226
mesh_banner_a16 = 227
mesh_banner_a17 = 228
mesh_banner_a18 = 229
mesh_banner_a19 = 230
mesh_banner_a20 = 231
mesh_banner_a21 = 232
mesh_banner_b01 = 233
mesh_banner_b02 = 234
mesh_banner_b03 = 235
mesh_banner_b04 = 236
mesh_banner_b05 = 237
mesh_banner_b06 = 238
mesh_banner_b07 = 239
mesh_banner_b08 = 240
mesh_banner_b09 = 241
mesh_banner_b10 = 242
mesh_banner_b11 = 243
mesh_banner_b12 = 244
mesh_banner_b13 = 245
mesh_banner_b14 = 246
mesh_banner_b15 = 247
mesh_banner_b16 = 248
mesh_banner_b17 = 249
mesh_banner_b18 = 250
mesh_banner_b19 = 251
mesh_banner_b20 = 252
mesh_banner_b21 = 253
mesh_banner_c01 = 254
mesh_banner_c02 = 255
mesh_banner_c03 = 256
mesh_banner_c04 = 257
mesh_banner_c05 = 258
mesh_banner_c06 = 259
mesh_banner_c07 = 260
mesh_banner_c08 = 261
mesh_banner_c09 = 262
mesh_banner_c10 = 263
mesh_banner_c11 = 264
mesh_banner_c12 = 265
mesh_banner_c13 = 266
mesh_banner_c14 = 267
mesh_banner_c15 = 268
mesh_banner_c16 = 269
mesh_banner_c17 = 270
mesh_banner_c18 = 271
mesh_banner_c19 = 272
mesh_banner_c20 = 273
mesh_banner_c21 = 274
mesh_banner_d01 = 275
mesh_banner_d02 = 276
mesh_banner_d03 = 277
mesh_banner_d04 = 278
mesh_banner_d05 = 279
mesh_banner_d06 = 280
mesh_banner_d07 = 281
mesh_banner_d08 = 282
mesh_banner_d09 = 283
mesh_banner_d10 = 284
mesh_banner_d11 = 285
mesh_banner_d12 = 286
mesh_banner_d13 = 287
mesh_banner_d14 = 288
mesh_banner_d15 = 289
mesh_banner_d16 = 290
mesh_banner_d17 = 291
mesh_banner_d18 = 292
mesh_banner_d19 = 293
mesh_banner_d20 = 294
mesh_banner_d21 = 295
mesh_banner_e01 = 296
mesh_banner_e02 = 297
mesh_banner_e03 = 298
mesh_banner_e04 = 299
mesh_banner_e05 = 300
mesh_banner_e06 = 301
mesh_banner_e07 = 302
mesh_banner_e08 = 303
mesh_banner_e09 = 304
mesh_banner_e10 = 305
mesh_banner_e11 = 306
mesh_banner_e12 = 307
mesh_banner_e13 = 308
mesh_banner_e14 = 309
mesh_banner_e15 = 310
mesh_banner_e16 = 311
mesh_banner_e17 = 312
mesh_banner_e18 = 313
mesh_banner_e19 = 314
mesh_banner_e20 = 315
mesh_banner_e21 = 316
mesh_banner_f01 = 317
mesh_banner_f02 = 318
mesh_banner_f03 = 319
mesh_banner_f04 = 320
mesh_banner_f05 = 321
mesh_banner_f06 = 322
mesh_banner_f07 = 323
mesh_banner_f08 = 324
mesh_banner_f09 = 325
mesh_banner_f10 = 326
mesh_banner_f11 = 327
mesh_banner_f12 = 328
mesh_banner_f13 = 329
mesh_banner_f14 = 330
mesh_banner_f15 = 331
mesh_banner_f16 = 332
mesh_banner_f17 = 333
mesh_banner_f18 = 334
mesh_banner_f19 = 335
mesh_banner_f20 = 336
mesh_banner_g01 = 337
mesh_banner_g02 = 338
mesh_banner_g03 = 339
mesh_banner_g04 = 340
mesh_banner_g05 = 341
mesh_banner_g06 = 342
mesh_banner_g07 = 343
mesh_banner_g08 = 344
mesh_banner_g09 = 345
mesh_banner_g10 = 346
mesh_banner_kingdom_a = 347
mesh_banner_kingdom_b = 348
mesh_banner_kingdom_c = 349
mesh_banner_kingdom_d = 350
mesh_banner_kingdom_e = 351
mesh_banner_kingdom_f = 352
mesh_banner_f21 = 353
mesh_arms_a01 = 354
mesh_arms_a02 = 355
mesh_arms_a03 = 356
mesh_arms_a04 = 357
mesh_arms_a05 = 358
mesh_arms_a06 = 359
mesh_arms_a07 = 360
mesh_arms_a08 = 361
mesh_arms_a09 = 362
mesh_arms_a10 = 363
mesh_arms_a11 = 364
mesh_arms_a12 = 365
mesh_arms_a13 = 366
mesh_arms_a14 = 367
mesh_arms_a15 = 368
mesh_arms_a16 = 369
mesh_arms_a17 = 370
mesh_arms_a18 = 371
mesh_arms_a19 = 372
mesh_arms_a20 = 373
mesh_arms_a21 = 374
mesh_arms_b01 = 375
mesh_arms_b02 = 376
mesh_arms_b03 = 377
mesh_arms_b04 = 378
mesh_arms_b05 = 379
mesh_arms_b06 = 380
mesh_arms_b07 = 381
mesh_arms_b08 = 382
mesh_arms_b09 = 383
mesh_arms_b10 = 384
mesh_arms_b11 = 385
mesh_arms_b12 = 386
mesh_arms_b13 = 387
mesh_arms_b14 = 388
mesh_arms_b15 = 389
mesh_arms_b16 = 390
mesh_arms_b17 = 391
mesh_arms_b18 = 392
mesh_arms_b19 = 393
mesh_arms_b20 = 394
mesh_arms_b21 = 395
mesh_arms_c01 = 396
mesh_arms_c02 = 397
mesh_arms_c03 = 398
mesh_arms_c04 = 399
mesh_arms_c05 = 400
mesh_arms_c06 = 401
mesh_arms_c07 = 402
mesh_arms_c08 = 403
mesh_arms_c09 = 404
mesh_arms_c10 = 405
mesh_arms_c11 = 406
mesh_arms_c12 = 407
mesh_arms_c13 = 408
mesh_arms_c14 = 409
mesh_arms_c15 = 410
mesh_arms_c16 = 411
mesh_arms_c17 = 412
mesh_arms_c18 = 413
mesh_arms_c19 = 414
mesh_arms_c20 = 415
mesh_arms_c21 = 416
mesh_arms_d01 = 417
mesh_arms_d02 = 418
mesh_arms_d03 = 419
mesh_arms_d04 = 420
mesh_arms_d05 = 421
mesh_arms_d06 = 422
mesh_arms_d07 = 423
mesh_arms_d08 = 424
mesh_arms_d09 = 425
mesh_arms_d10 = 426
mesh_arms_d11 = 427
mesh_arms_d12 = 428
mesh_arms_d13 = 429
mesh_arms_d14 = 430
mesh_arms_d15 = 431
mesh_arms_d16 = 432
mesh_arms_d17 = 433
mesh_arms_d18 = 434
mesh_arms_d19 = 435
mesh_arms_d20 = 436
mesh_arms_d21 = 437
mesh_arms_e01 = 438
mesh_arms_e02 = 439
mesh_arms_e03 = 440
mesh_arms_e04 = 441
mesh_arms_e05 = 442
mesh_arms_e06 = 443
mesh_arms_e07 = 444
mesh_arms_e08 = 445
mesh_arms_e09 = 446
mesh_arms_e10 = 447
mesh_arms_e11 = 448
mesh_arms_e12 = 449
mesh_arms_e13 = 450
mesh_arms_e14 = 451
mesh_arms_e15 = 452
mesh_arms_e16 = 453
mesh_arms_e17 = 454
mesh_arms_e18 = 455
mesh_arms_e19 = 456
mesh_arms_e20 = 457
mesh_arms_e21 = 458
mesh_arms_f01 = 459
mesh_arms_f02 = 460
mesh_arms_f03 = 461
mesh_arms_f04 = 462
mesh_arms_f05 = 463
mesh_arms_f06 = 464
mesh_arms_f07 = 465
mesh_arms_f08 = 466
mesh_arms_f09 = 467
mesh_arms_f10 = 468
mesh_arms_f11 = 469
mesh_arms_f12 = 470
mesh_arms_f13 = 471
mesh_arms_f14 = 472
mesh_arms_f15 = 473
mesh_arms_f16 = 474
mesh_arms_f17 = 475
mesh_arms_f18 = 476
mesh_arms_f19 = 477
mesh_arms_f20 = 478
mesh_arms_g01 = 479
mesh_arms_g02 = 480
mesh_arms_g03 = 481
mesh_arms_g04 = 482
mesh_arms_g05 = 483
mesh_arms_g06 = 484
mesh_arms_g07 = 485
mesh_arms_g08 = 486
mesh_arms_g09 = 487
mesh_arms_g10 = 488
mesh_arms_kingdom_a = 489
mesh_arms_kingdom_b = 490
mesh_arms_kingdom_c = 491
mesh_arms_kingdom_d = 492
mesh_arms_kingdom_e = 493
mesh_arms_kingdom_f = 494
mesh_arms_f21 = 495
mesh_banners_default_a = 496
mesh_banners_default_b = 497
mesh_banners_default_c = 498
mesh_banners_default_d = 499
mesh_banners_default_e = 500
mesh_troop_label_banner = 501
mesh_ui_kingdom_shield_1 = 502
mesh_ui_kingdom_shield_2 = 503
mesh_ui_kingdom_shield_3 = 504
mesh_ui_kingdom_shield_4 = 505
mesh_ui_kingdom_shield_5 = 506
mesh_ui_kingdom_shield_6 = 507
mesh_mouse_arrow_down = 508
mesh_mouse_arrow_right = 509
mesh_mouse_arrow_left = 510
mesh_mouse_arrow_up = 511
mesh_mouse_arrow_plus = 512
mesh_mouse_left_click = 513
mesh_mouse_right_click = 514
mesh_status_ammo_ready = 515
mesh_main_menu_background = 516
mesh_loading_background = 517
mesh_ui_quick_battle_a = 518
mesh_white_bg_plane_a = 519
mesh_cb_ui_icon_infantry = 520
mesh_cb_ui_icon_archer = 521
mesh_cb_ui_icon_horseman = 522
mesh_cb_ui_main = 523
mesh_cb_ui_maps_scene_01 = 524
mesh_cb_ui_maps_scene_02 = 525
mesh_cb_ui_maps_scene_03 = 526
mesh_cb_ui_maps_scene_04 = 527
mesh_cb_ui_maps_scene_05 = 528
mesh_cb_ui_maps_scene_06 = 529
mesh_cb_ui_maps_scene_07 = 530
mesh_cb_ui_maps_scene_08 = 531
mesh_cb_ui_maps_scene_09 = 532
mesh_mp_ui_host_maps_14 = 533
mesh_mp_ui_host_maps_15 = 534
mesh_quit_adv = 535
mesh_quit_adv_b = 536
mesh_ui_kingdom_shield_7 = 537
mesh_flag_project_rb = 538
mesh_flag_project_rb_miss = 539
mesh_mp_ui_host_maps_16 = 540
mesh_mp_ui_host_maps_17 = 541
mesh_mp_ui_host_maps_18 = 542
mesh_mp_ui_host_maps_19 = 543
mesh_mp_ui_host_maps_20 = 544


