anim_stand = 0
anim_stand_man = 1
anim_stand_player_first_person = 2
anim_jump = 3
anim_jump_loop = 4
anim_jump_end = 5
anim_jump_end_hard = 6
anim_stand_unarmed = 7
anim_stand_single = 8
anim_stand_greatsword = 9
anim_stand_staff = 10
anim_stand_crossbow = 11
anim_turn_right = 12
anim_turn_left = 13
anim_turn_right_single = 14
anim_turn_left_single = 15
anim_turn_right_staff = 16
anim_turn_left_staff = 17
anim_turn_right_greatsword = 18
anim_turn_left_greatsword = 19
anim_prepare_kick_0 = 20
anim_prepare_kick_1 = 21
anim_prepare_kick_2 = 22
anim_prepare_kick_3 = 23
anim_kick_right_leg = 24
anim_kick_left_leg = 25
anim_run_forward = 26
anim_run_forward_onehanded = 27
anim_run_forward_staff = 28
anim_run_forward_greatsword = 29
anim_run_forward_hips_right = 30
anim_run_forward_hips_left = 31
anim_run_forward_right = 32
anim_run_forward_right_onehanded = 33
anim_run_forward_right_staff = 34
anim_run_forward_right_greatsword = 35
anim_run_forward_right_hips_right = 36
anim_run_forward_right_hips_left = 37
anim_run_forward_left = 38
anim_run_forward_left_onehanded = 39
anim_run_forward_left_staff = 40
anim_run_forward_left_greatsword = 41
anim_run_forward_left_hips_right = 42
anim_run_forward_left_hips_left = 43
anim_run_backward = 44
anim_run_backward_onehanded = 45
anim_run_backward_staff = 46
anim_run_backward_greatsword = 47
anim_run_backward_hips_right = 48
anim_run_backward_hips_left = 49
anim_run_backward_right = 50
anim_run_backward_right_onehanded = 51
anim_run_backward_right_staff = 52
anim_run_backward_right_greatsword = 53
anim_run_backward_right_hips_right = 54
anim_run_backward_right_hips_left = 55
anim_run_backward_left = 56
anim_run_backward_left_onehanded = 57
anim_run_backward_left_staff = 58
anim_run_backward_left_greatsword = 59
anim_run_backward_left_hips_right = 60
anim_run_backward_left_hips_left = 61
anim_run_right = 62
anim_run_right_onehanded = 63
anim_run_right_twohanded = 64
anim_run_right_polearm = 65
anim_run_right_hips_right = 66
anim_run_right_hips_left = 67
anim_run_left = 68
anim_run_left_onehanded = 69
anim_run_left_twohanded = 70
anim_run_left_polearm = 71
anim_run_left_hips_right = 72
anim_run_left_hips_left = 73
anim_walk_forward = 74
anim_walk_forward_onehanded = 75
anim_walk_forward_staff = 76
anim_walk_forward_greatsword = 77
anim_walk_forward_hips_right = 78
anim_walk_forward_hips_left = 79
anim_walk_backward = 80
anim_walk_backward_onehanded = 81
anim_walk_backward_staff = 82
anim_walk_backward_greatsword = 83
anim_walk_backward_hips_right = 84
anim_walk_backward_hips_left = 85
anim_walk_right = 86
anim_walk_right_onehanded = 87
anim_walk_right_twohanded = 88
anim_walk_right_polearm = 89
anim_walk_right_hips_right = 90
anim_walk_right_hips_left = 91
anim_walk_left = 92
anim_walk_left_onehanded = 93
anim_walk_left_twohanded = 94
anim_walk_left_polearm = 95
anim_walk_left_hips_right = 96
anim_walk_left_hips_left = 97
anim_walk_forward_right = 98
anim_walk_forward_right_onehanded = 99
anim_walk_forward_right_twohanded = 100
anim_walk_forward_right_polearm = 101
anim_walk_forward_right_hips_right = 102
anim_walk_forward_right_hips_left = 103
anim_walk_forward_left = 104
anim_walk_forward_left_onehanded = 105
anim_walk_forward_left_twohanded = 106
anim_walk_forward_left_polearm = 107
anim_walk_forward_left_hips_right = 108
anim_walk_forward_left_hips_left = 109
anim_walk_backward_left = 110
anim_walk_backward_left_onehanded = 111
anim_walk_backward_left_twohanded = 112
anim_walk_backward_left_polearm = 113
anim_walk_backward_left_hips_right = 114
anim_walk_backward_left_hips_left = 115
anim_walk_backward_right = 116
anim_walk_backward_right_onehanded = 117
anim_walk_backward_right_twohanded = 118
anim_walk_backward_right_polearm = 119
anim_walk_backward_right_hips_right = 120
anim_walk_backward_right_hips_left = 121
anim_walk_forward_crouch = 122
anim_stand_to_crouch = 123
anim_crouch_to_stand = 124
anim_ride_0 = 125
anim_ride_1 = 126
anim_lancer_ride_1 = 127
anim_lancer_charge_parried = 128
anim_ride_2 = 129
anim_ride_3 = 130
anim_ride_4 = 131
anim_lancer_ride_4 = 132
anim_lancer_ride_4_no_shield = 133
anim_ride_rear = 134
anim_ride_spur = 135
anim_ride_jump = 136
anim_ride_jump_end = 137
anim_ride_turn_right = 138
anim_ride_turn_left = 139
anim_mount_horse = 140
anim_dismount_horse = 141
anim_lancer_ride_0 = 142
anim_equip_default = 143
anim_unequip_default = 144
anim_equip_sword = 145
anim_unequip_sword = 146
anim_equip_greatsword = 147
anim_unequip_greatsword = 148
anim_equip_axe_left_hip = 149
anim_unequip_axe_left_hip = 150
anim_equip_crossbow = 151
anim_unequip_crossbow = 152
anim_equip_spear = 153
anim_unequip_spear = 154
anim_equip_dagger_front_left = 155
anim_unequip_dagger_front_left = 156
anim_equip_dagger_front_right = 157
anim_unequip_dagger_front_right = 158
anim_equip_axe_back = 159
anim_unequip_axe_back = 160
anim_equip_revolver_right = 161
anim_unequip_revolver_right = 162
anim_equip_pistol_front_left = 163
anim_unequip_pistol_front_left = 164
anim_equip_katana = 165
anim_unequip_katana = 166
anim_equip_wakizashi = 167
anim_unequip_wakizashi = 168
anim_equip_shield = 169
anim_unequip_shield = 170
anim_equip_bow_back = 171
anim_unequip_bow_back = 172
anim_equip_bow_left_hip = 173
anim_unequip_bow_left_hip = 174
anim_cancel_attack_onehanded = 175
anim_cancel_attack_twohanded = 176
anim_cancel_attack_polearm = 177
anim_ready_bow = 178
anim_release_bow = 179
anim_ready_bow_mounted = 180
anim_release_bow_mounted = 181
anim_ready_crossbow = 182
anim_release_crossbow = 183
anim_reload_crossbow = 184
anim_reload_crossbow_horseback = 185
anim_ready_javelin = 186
anim_release_javelin = 187
anim_ready_throwing_knife = 188
anim_release_throwing_knife = 189
anim_ready_throwing_axe = 190
anim_release_throwing_axe = 191
anim_ready_stone = 192
anim_release_stone = 193
anim_ready_pistol = 194
anim_release_pistol = 195
anim_reload_pistol = 196
anim_ready_musket = 197
anim_release_musket = 198
anim_reload_musket = 199
anim_ready_swingright_fist = 200
anim_release_swingright_fist = 201
anim_release_swingright_fist_continue = 202
anim_blocked_swingright_fist = 203
anim_parried_swingright_fist = 204
anim_ready_swingleft_fist = 205
anim_release_swingleft_fist = 206
anim_release_swingleft_fist_continue = 207
anim_blocked_swingleft_fist = 208
anim_parried_swingleft_fist = 209
anim_ready_direct_fist = 210
anim_release_direct_fist = 211
anim_release_direct_fist_continue = 212
anim_blocked_direct_fist = 213
anim_parried_direct_fist = 214
anim_ready_uppercut_fist = 215
anim_release_uppercut_fist = 216
anim_release_uppercut_fist_continue = 217
anim_blocked_uppercut_fist = 218
anim_parried_uppercut_fist = 219
anim_ready_slashright_twohanded = 220
anim_release_slashright_twohanded = 221
anim_release_slashright_twohanded_continue = 222
anim_blocked_slashright_twohanded = 223
anim_parried_slashright_twohanded = 224
anim_ready_slashleft_twohanded = 225
anim_release_slashleft_twohanded = 226
anim_release_slashleft_twohanded_continue = 227
anim_blocked_slashleft_twohanded = 228
anim_parried_slashleft_twohanded = 229
anim_ready_thrust_twohanded = 230
anim_release_thrust_twohanded = 231
anim_release_thrust_twohanded_continue = 232
anim_blocked_thrust_twohanded = 233
anim_parried_thrust_twohanded = 234
anim_ready_overswing_twohanded = 235
anim_release_overswing_twohanded = 236
anim_release_overswing_twohanded_continue = 237
anim_blocked_overswing_twohanded = 238
anim_parried_overswing_twohanded = 239
anim_ready_thrust_onehanded = 240
anim_release_thrust_onehanded = 241
anim_release_thrust_onehanded_continue = 242
anim_blocked_thrust_onehanded = 243
anim_parried_thrust_onehanded = 244
anim_ready_thrust_onehanded_horseback = 245
anim_release_thrust_onehanded_horseback = 246
anim_release_thrust_onehanded_horseback_continue = 247
anim_blocked_thrust_onehanded_horseback = 248
anim_parried_thrust_onehanded_horseback = 249
anim_ready_thrust_onehanded_lance = 250
anim_release_thrust_onehanded_lance = 251
anim_release_thrust_onehanded_lance_continue = 252
anim_blocked_thrust_onehanded_lance = 253
anim_parried_thrust_onehanded_lance = 254
anim_ready_slashright_onehanded = 255
anim_release_slashright_onehanded = 256
anim_release_slashright_onehanded_continue = 257
anim_blocked_slashright_onehanded = 258
anim_parried_slashright_onehanded = 259
anim_ready_slashleft_onehanded = 260
anim_release_slashleft_onehanded = 261
anim_release_slashleft_onehanded_continue = 262
anim_blocked_slashleft_onehanded = 263
anim_parried_slashleft_onehanded = 264
anim_ready_overswing_onehanded = 265
anim_release_overswing_onehanded = 266
anim_release_overswing_onehanded_continue = 267
anim_blocked_overswing_onehanded = 268
anim_parried_overswing_onehanded = 269
anim_ready_slash_horseback_right = 270
anim_release_slash_horseback_right = 271
anim_release_slash_horseback_right_continue = 272
anim_blocked_slash_horseback_right = 273
anim_parried_slash_horseback_right = 274
anim_ready_slash_horseback_left = 275
anim_release_slash_horseback_left = 276
anim_release_slash_horseback_left_continue = 277
anim_blocked_slash_horseback_left = 278
anim_parried_slash_horseback_left = 279
anim_ready_slash_horseback_polearm_right = 280
anim_release_slash_horseback_polearm_right = 281
anim_release_slash_horseback_polearm_right_continue = 282
anim_blocked_slash_horseback_polearm_right = 283
anim_parried_slash_horseback_polearm_right = 284
anim_ready_slash_horseback_polearm_left = 285
anim_release_slash_horseback_polearm_left = 286
anim_release_slash_horseback_polearm_left_continue = 287
anim_blocked_slash_horseback_polearm_left = 288
anim_parried_slash_horseback_polearm_left = 289
anim_ready_overswing_staff = 290
anim_release_overswing_staff = 291
anim_release_overswing_staff_continue = 292
anim_blocked_overswing_staff = 293
anim_parried_overswing_staff = 294
anim_ready_thrust_staff = 295
anim_release_thrust_staff = 296
anim_release_thrust_staff_continue = 297
anim_blocked_thrust_staff = 298
anim_parried_thrust_staff = 299
anim_ready_slashleft_staff = 300
anim_release_slashleft_staff = 301
anim_release_slashleft_staff_continue = 302
anim_blocked_slashleft_staff = 303
anim_parried_slashleft_staff = 304
anim_ready_slashright_staff = 305
anim_release_slashright_staff = 306
anim_release_slashright_staff_continue = 307
anim_blocked_slashright_staff = 308
anim_parried_slashright_staff = 309
anim_defend_fist = 310
anim_defend_fist_keep = 311
anim_defend_fist_parry_1 = 312
anim_defend_fist_parry_2 = 313
anim_defend_fist_parry_3 = 314
anim_defend_shield_forward = 315
anim_defend_shield_up = 316
anim_defend_shield_right = 317
anim_defend_shield_left = 318
anim_defend_shield = 319
anim_defend_shield_keep = 320
anim_defend_shield_parry_1 = 321
anim_defend_shield_parry_2 = 322
anim_defend_shield_parry_3 = 323
anim_defend_forward_greatsword = 324
anim_defend_forward_greatsword_keep = 325
anim_defend_forward_greatsword_parry_1 = 326
anim_defend_forward_greatsword_parry_2 = 327
anim_defend_forward_greatsword_parry_3 = 328
anim_defend_up_twohanded = 329
anim_defend_up_twohanded_keep = 330
anim_defend_up_twohanded_parry_1 = 331
anim_defend_up_twohanded_parry_2 = 332
anim_defend_up_twohanded_parry_3 = 333
anim_defend_right_twohanded = 334
anim_defend_right_twohanded_keep = 335
anim_defend_right_twohanded_parry_1 = 336
anim_defend_right_twohanded_parry_2 = 337
anim_defend_right_twohanded_parry_3 = 338
anim_defend_left_twohanded = 339
anim_defend_left_twohanded_keep = 340
anim_defend_left_twohanded_parry_1 = 341
anim_defend_left_twohanded_parry_2 = 342
anim_defend_left_twohanded_parry_3 = 343
anim_defend_forward_onehanded = 344
anim_defend_forward_onehanded_keep = 345
anim_defend_forward_onehanded_parry_1 = 346
anim_defend_forward_onehanded_parry_2 = 347
anim_defend_forward_onehanded_parry_3 = 348
anim_defend_up_onehanded = 349
anim_defend_up_onehanded_keep = 350
anim_defend_up_onehanded_parry_1 = 351
anim_defend_up_onehanded_parry_2 = 352
anim_defend_up_onehanded_parry_3 = 353
anim_defend_right_onehanded = 354
anim_defend_right_onehanded_keep = 355
anim_defend_right_onehanded_parry_1 = 356
anim_defend_right_onehanded_parry_2 = 357
anim_defend_right_onehanded_parry_3 = 358
anim_defend_left_onehanded = 359
anim_defend_left_onehanded_keep = 360
anim_defend_left_onehanded_parry_1 = 361
anim_defend_left_onehanded_parry_2 = 362
anim_defend_left_onehanded_parry_3 = 363
anim_defend_forward_staff = 364
anim_defend_forward_staff_keep = 365
anim_defend_forward_staff_parry_1 = 366
anim_defend_forward_staff_parry_2 = 367
anim_defend_forward_staff_parry_3 = 368
anim_defend_up_staff = 369
anim_defend_up_staff_keep = 370
anim_defend_up_staff_parry_1 = 371
anim_defend_up_staff_parry_2 = 372
anim_defend_up_staff_parry_3 = 373
anim_defend_right_staff = 374
anim_defend_right_staff_keep = 375
anim_defend_right_staff_parry_1 = 376
anim_defend_right_staff_parry_2 = 377
anim_defend_right_staff_parry_3 = 378
anim_defend_left_staff = 379
anim_defend_left_staff_keep = 380
anim_defend_left_staff_parry_1 = 381
anim_defend_left_staff_parry_2 = 382
anim_defend_left_staff_parry_3 = 383
anim_strike_head_left = 384
anim_strike_head_right = 385
anim_strike_head_front = 386
anim_strike_head_back = 387
anim_strike_chest_left = 388
anim_strike_chest_right = 389
anim_strike_chest_front = 390
anim_strike_chest_back = 391
anim_strike_abdomen_left = 392
anim_strike_abdomen_right = 393
anim_strike_abdomen_front = 394
anim_strike_abdomen_back = 395
anim_strike_legs_left = 396
anim_strike_legs_right = 397
anim_strike_legs_front = 398
anim_strike_legs_back = 399
anim_strike2_head_left = 400
anim_strike2_head_right = 401
anim_strike2_head_front = 402
anim_strike2_head_back = 403
anim_strike2_chest_left = 404
anim_strike2_chest_right = 405
anim_strike2_chest_front = 406
anim_strike2_chest_back = 407
anim_strike2_abdomen_left = 408
anim_strike2_abdomen_right = 409
anim_strike2_abdomen_front = 410
anim_strike2_abdomen_back = 411
anim_strike2_legs_left = 412
anim_strike2_legs_right = 413
anim_strike2_legs_front = 414
anim_strike2_legs_back = 415
anim_strike3_head_left = 416
anim_strike3_head_right = 417
anim_strike3_head_front = 418
anim_strike3_head_back = 419
anim_strike3_chest_left = 420
anim_strike3_chest_right = 421
anim_strike3_chest_front = 422
anim_strike3_abdomen_left = 423
anim_strike3_abdomen_right = 424
anim_strike3_abdomen_front = 425
anim_strike3_abdomen_back = 426
anim_strike_head_front_left_reloc = 427
anim_fall_face_hold = 428
anim_fall_chest_front = 429
anim_fall_abdomen_hold_front = 430
anim_fall_head_front = 431
anim_fall_right_front = 432
anim_fall_body_back = 433
anim_fall_rider_right_forward = 434
anim_fall_rider_right = 435
anim_fall_rider_left = 436
anim_rider_fall_right = 437
anim_rider_fall_roll = 438
anim_strike_chest_front_stop = 439
anim_strike_fall_back_rise = 440
anim_strike_fall_back_rise_upper = 441
anim_cheer = 442
anim_cheer_stand = 443
anim_stand_townguard = 444
anim_stand_lady = 445
anim_stand_lord = 446
anim_dance = 447
anim_pose_1 = 448
anim_pose_2 = 449
anim_pose_3 = 450
anim_pose_4 = 451
anim_pose_5 = 452
anim_wedding_guest = 453
anim_wedding_guest_notr = 454
anim_wedding_guest_woman = 455
anim_wedding_dad_stairs = 456
anim_wedding_dad_walk = 457
anim_wedding_bride_stairs = 458
anim_wedding_bride_walk = 459
anim_wedding_groom_wait = 460
anim_wedding_groom_last = 461
anim_wedding_dad_last = 462
anim_wedding_bride_last = 463
anim_equip_bayonet = 464
anim_unequip_bayonet = 465
anim_crouch_unarmed = 466
anim_crouch_single = 467
anim_crouch_greatsword = 468
anim_crouch_staff = 469
anim_crouch_crossbow = 470
anim_crouch_ready_pistol = 471
anim_crouch_release_pistol = 472
anim_reload_musket_full = 473
anim_reload_musket_two_third = 474
anim_reload_musket_one_third = 475
anim_crouch_pike = 476
anim_crouch_pike_recover = 477
anim_ready_overswing_spear = 478
anim_release_overswing_spear = 479
anim_release_overswing_spear_continue = 480
anim_parried_overswing_spear = 481
anim_blocked_overswing_spear = 482
anim_reload_pistol_half = 483
anim_ready_overswing_musket = 484
anim_release_overswing_musket = 485
anim_release_overswing_musket_continue = 486
anim_parried_overswing_musket = 487
anim_blocked_overswing_musket = 488
anim_ready_thrust_musket = 489
anim_release_thrust_musket = 490
anim_release_thrust_musket_continue = 491
anim_parried_thrust_musket = 492
anim_blocked_thrust_musket = 493
anim_equip_pistol_melee = 494
anim_unequip_pistol_melee = 495
anim_unused_human_anim_44 = 496
anim_unused_human_anim_45 = 497
anim_unused_human_anim_46 = 498
anim_unused_human_anim_47 = 499
anim_unused_human_anim_48 = 500
anim_unused_human_anim_49 = 501
anim_unused_human_anim_50 = 502
anim_unused_human_anim_51 = 503
anim_unused_human_anim_52 = 504
anim_unused_human_anim_53 = 505
anim_unused_human_anim_54 = 506
anim_unused_human_anim_55 = 507
anim_unused_human_anim_56 = 508
anim_unused_human_anim_57 = 509
anim_unused_human_anim_58 = 510
anim_unused_human_anim_59 = 511
anim_unused_human_anim_60 = 512
anim_unused_human_anim_61 = 513
anim_unused_human_anim_62 = 514
anim_unused_human_anim_63 = 515
anim_unused_human_anim_64 = 516
anim_unused_human_anim_65 = 517
anim_unused_human_anim_66 = 518
anim_unused_human_anim_67 = 519
anim_unused_human_anim_68 = 520
anim_unused_human_anim_69 = 521
anim_unused_human_anim_70 = 522
anim_unused_human_anim_71 = 523
anim_unused_human_anim_72 = 524
anim_unused_human_anim_73 = 525
anim_unused_human_anim_74 = 526
anim_unused_human_anim_75 = 527
anim_unused_human_anim_76 = 528
anim_unused_human_anim_77 = 529
anim_unused_human_anim_78 = 530
anim_unused_human_anim_79 = 531
anim_unused_human_anim_80 = 532
anim_unused_human_anim_81 = 533
anim_unused_human_anim_82 = 534
anim_unused_human_anim_83 = 535
anim_unused_human_anim_84 = 536
anim_unused_human_anim_85 = 537
anim_unused_human_anim_86 = 538
anim_unused_human_anim_87 = 539
anim_unused_human_anim_88 = 540
anim_unused_human_anim_89 = 541
anim_unused_human_anim_90 = 542
anim_unused_human_anim_91 = 543
anim_unused_human_anim_92 = 544
anim_unused_human_anim_93 = 545
anim_unused_human_anim_94 = 546
anim_unused_human_anim_95 = 547
anim_unused_human_anim_96 = 548
anim_unused_human_anim_97 = 549
anim_unused_human_anim_98 = 550
anim_unused_human_anim_99 = 551
anim_unused_human_anim_100 = 552
anim_horse_stand = 553
anim_horse_pace_1 = 554
anim_horse_pace_2 = 555
anim_horse_pace_3 = 556
anim_horse_pace_4 = 557
anim_horse_walk_backward = 558
anim_horse_rear = 559
anim_horse_jump = 560
anim_horse_jump_end = 561
anim_horse_turn_right = 562
anim_horse_turn_left = 563
anim_horse_turn_right_head = 564
anim_horse_turn_left_head = 565
anim_horse_slow = 566
anim_horse_fall_in_place = 567
anim_horse_fall_right = 568
anim_horse_fall_roll = 569
anim_unused_horse_anim_1 = 570
anim_unused_horse_anim_2 = 571
anim_unused_horse_anim_3 = 572
anim_unused_horse_anim_4 = 573
anim_unused_horse_anim_5 = 574
anim_unused_horse_anim_6 = 575
anim_unused_horse_anim_7 = 576
anim_unused_horse_anim_8 = 577
anim_unused_horse_anim_9 = 578
anim_unused_horse_anim_10 = 579
anim_unused_horse_anim_11 = 580
anim_unused_horse_anim_12 = 581
anim_unused_horse_anim_13 = 582
anim_unused_horse_anim_14 = 583
anim_unused_horse_anim_15 = 584
anim_unused_horse_anim_16 = 585
anim_unused_horse_anim_17 = 586
anim_unused_horse_anim_18 = 587
anim_unused_horse_anim_19 = 588
anim_unused_horse_anim_20 = 589
anim_unused_horse_anim_21 = 590
anim_unused_horse_anim_22 = 591
anim_unused_horse_anim_23 = 592
anim_unused_horse_anim_24 = 593
anim_unused_horse_anim_25 = 594
anim_unused_horse_anim_26 = 595
anim_unused_horse_anim_27 = 596
anim_unused_horse_anim_28 = 597
anim_unused_horse_anim_29 = 598
anim_unused_horse_anim_30 = 599
anim_unused_horse_anim_31 = 600
anim_unused_horse_anim_32 = 601
anim_unused_horse_anim_33 = 602
anim_unused_horse_anim_34 = 603
anim_unused_horse_anim_35 = 604
anim_unused_horse_anim_36 = 605
anim_unused_horse_anim_37 = 606
anim_unused_horse_anim_38 = 607
anim_unused_horse_anim_39 = 608
anim_unused_horse_anim_40 = 609
anim_unused_horse_anim_41 = 610
anim_unused_horse_anim_42 = 611
anim_unused_horse_anim_43 = 612
anim_unused_horse_anim_44 = 613
anim_unused_horse_anim_45 = 614
anim_unused_horse_anim_46 = 615
anim_unused_horse_anim_47 = 616
anim_unused_horse_anim_48 = 617
anim_unused_horse_anim_49 = 618
anim_unused_horse_anim_50 = 619
anim_unused_horse_anim_51 = 620
anim_unused_horse_anim_52 = 621
anim_unused_horse_anim_53 = 622
anim_unused_horse_anim_54 = 623
anim_unused_horse_anim_55 = 624
anim_unused_horse_anim_56 = 625
anim_unused_horse_anim_57 = 626
anim_unused_horse_anim_58 = 627
anim_unused_horse_anim_59 = 628
anim_unused_horse_anim_60 = 629
anim_unused_horse_anim_61 = 630
anim_unused_horse_anim_62 = 631
anim_unused_horse_anim_63 = 632
anim_unused_horse_anim_64 = 633
anim_unused_horse_anim_65 = 634
anim_unused_horse_anim_66 = 635
anim_unused_horse_anim_67 = 636
anim_unused_horse_anim_68 = 637
anim_unused_horse_anim_69 = 638
anim_unused_horse_anim_70 = 639
anim_unused_horse_anim_71 = 640
anim_unused_horse_anim_72 = 641
anim_unused_horse_anim_73 = 642
anim_unused_horse_anim_74 = 643
anim_unused_horse_anim_75 = 644
anim_unused_horse_anim_76 = 645
anim_unused_horse_anim_77 = 646
anim_unused_horse_anim_78 = 647
anim_unused_horse_anim_79 = 648
anim_unused_horse_anim_80 = 649
anim_unused_horse_anim_81 = 650
anim_unused_horse_anim_82 = 651
anim_unused_horse_anim_83 = 652
anim_unused_horse_anim_84 = 653
anim_unused_horse_anim_85 = 654
anim_unused_horse_anim_86 = 655
anim_unused_horse_anim_87 = 656
anim_unused_horse_anim_88 = 657
anim_unused_horse_anim_89 = 658
anim_unused_horse_anim_90 = 659
anim_unused_horse_anim_91 = 660
anim_unused_horse_anim_92 = 661
anim_unused_horse_anim_93 = 662
anim_unused_horse_anim_94 = 663
anim_unused_horse_anim_95 = 664
anim_unused_horse_anim_96 = 665
anim_unused_horse_anim_97 = 666
anim_unused_horse_anim_98 = 667
anim_unused_horse_anim_99 = 668
anim_unused_horse_anim_100 = 669


