psys_game_rain = 0
psys_game_snow = 1
psys_game_blood = 2
psys_game_blood_2 = 3
psys_game_hoof_dust = 4
psys_game_hoof_dust_snow = 5
psys_game_hoof_dust_mud = 6
psys_game_water_splash_1 = 7
psys_game_water_splash_2 = 8
psys_game_water_splash_3 = 9
psys_torch_fire = 10
psys_fire_glow_1 = 11
psys_fire_glow_fixed = 12
psys_torch_smoke = 13
psys_flue_smoke_short = 14
psys_flue_smoke_tall = 15
psys_war_smoke_tall = 16
psys_ladder_dust_6m = 17
psys_ladder_dust_8m = 18
psys_ladder_dust_10m = 19
psys_ladder_dust_12m = 20
psys_ladder_dust_14m = 21
psys_ladder_straw_6m = 22
psys_ladder_straw_8m = 23
psys_ladder_straw_10m = 24
psys_ladder_straw_12m = 25
psys_ladder_straw_14m = 26
psys_torch_fire_sparks = 27
psys_fire_sparks_1 = 28
psys_pistol_smoke = 29
psys_brazier_fire_1 = 30
psys_cooking_fire_1 = 31
psys_cooking_smoke = 32
psys_food_steam = 33
psys_candle_light = 34
psys_candle_light_small = 35
psys_lamp_fire = 36
psys_dummy_smoke = 37
psys_dummy_straw = 38
psys_dummy_smoke_big = 39
psys_dummy_straw_big = 40
psys_gourd_smoke = 41
psys_gourd_piece_1 = 42
psys_gourd_piece_2 = 43
psys_fire_fly_1 = 44
psys_bug_fly_1 = 45
psys_moon_beam_1 = 46
psys_moon_beam_paricle_1 = 47
psys_night_smoke_1 = 48
psys_fireplace_fire_small = 49
psys_fireplace_fire_big = 50
psys_village_fire_big = 51
psys_village_fire_smoke_big = 52
psys_map_village_fire = 53
psys_map_village_fire_smoke = 54
psys_map_village_looted_smoke = 55
psys_dungeon_water_drops = 56
psys_wedding_rose = 57
psys_sea_foam_a = 58
psys_fall_leafs_a = 59
