tableau_game_character_sheet = 0
tableau_game_inventory_window = 1
tableau_game_profile_window = 2
tableau_game_party_window = 3
tableau_game_troop_label_banner = 4
tableau_round_shield_1 = 5
tableau_round_shield_2 = 6
tableau_round_shield_3 = 7
tableau_round_shield_4 = 8
tableau_round_shield_5 = 9
tableau_small_round_shield_1 = 10
tableau_small_round_shield_2 = 11
tableau_small_round_shield_3 = 12
tableau_kite_shield_1 = 13
tableau_kite_shield_2 = 14
tableau_kite_shield_3 = 15
tableau_kite_shield_4 = 16
tableau_heater_shield_1 = 17
tableau_heater_shield_2 = 18
tableau_pavise_shield_1 = 19
tableau_pavise_shield_2 = 20
tableau_heraldic_armor_a = 21
tableau_heraldic_armor_b = 22
tableau_heraldic_armor_c = 23
tableau_heraldic_armor_d = 24
tableau_troop_note_alpha_mask = 25
tableau_troop_note_color = 26
tableau_troop_character_alpha_mask = 27
tableau_troop_character_color = 28
tableau_troop_inventory_alpha_mask = 29
tableau_troop_inventory_color = 30
tableau_troop_profile_alpha_mask = 31
tableau_troop_profile_color = 32
tableau_troop_party_alpha_mask = 33
tableau_troop_party_color = 34
tableau_troop_note_mesh = 35
tableau_center_note_mesh = 36
tableau_faction_note_mesh_for_menu = 37
tableau_faction_note_mesh = 38
tableau_faction_note_mesh_banner = 39
tableau_2_factions_mesh = 40
tableau_color_picker = 41
tableau_custom_banner_square_no_mesh = 42
tableau_custom_banner_default = 43
tableau_custom_banner_tall = 44
tableau_custom_banner_square = 45
tableau_custom_banner_short = 46
tableau_background_selection = 47
tableau_positioning_selection = 48
tableau_retired_troop_alpha_mask = 49
tableau_retired_troop_color = 50
tableau_retirement_troop = 51
