###################################################
# header_skins.py
# This file contains declarations for skins
# DO NOT EDIT THIS FILE!
###################################################

voice_die        = 0
voice_hit        = 1
voice_grunt      = 2
voice_grunt_long = 3
voice_yell       = 4
voice_warcry     = 5
voice_victory    = 6
voice_stun       = 7

skf_use_morph_key_10 = 0x00000001
skf_use_morph_key_20 = 0x00000002
skf_use_morph_key_30 = 0x00000003
skf_use_morph_key_40 = 0x00000004
skf_use_morph_key_50 = 0x00000005
skf_use_morph_key_60 = 0x00000006
skf_use_morph_key_70 = 0x00000007
